@@ -253,34 +253,34 @@
 #include "forward_list"
 // ./core/clingutils/G__dequeDict.cxx
 #include "deque"
-// ./core/clingutils/G__listDict.cxx
-#include "list"
 // ./core/clingutils/G__vectorDict.cxx
 #include "vector"
-// ./core/clingutils/G__setDict.cxx
-#include "set"
+// ./core/clingutils/G__listDict.cxx
+#include "list"
 // ./core/clingutils/G__multisetDict.cxx
 #include "set"
+// ./core/clingutils/G__multimapDict.cxx
+#include "map"
+// ./core/clingutils/G__setDict.cxx
+#include "set"
+// ./core/clingutils/G__multimap2Dict.cxx
+#include "map"
+// ./core/clingutils/G__mapDict.cxx
+#include "map"
 // ./core/clingutils/G__unordered_setDict.cxx
 #include "unordered_set"
 // ./core/clingutils/G__unordered_multisetDict.cxx
 #include "unordered_set"
-// ./core/clingutils/G__multimap2Dict.cxx
-#include "map"
-// ./core/clingutils/G__multimapDict.cxx
-#include "map"
 // ./core/clingutils/G__map2Dict.cxx
 #include "map"
-// ./core/clingutils/G__mapDict.cxx
-#include "map"
+// ./core/clingutils/G__valarrayDict.cxx
+#include "valarray"
 // ./core/clingutils/G__complexDict.cxx
 #include "root_std_complex.h"
 // ./core/clingutils/G__unordered_multimapDict.cxx
 #include "unordered_map"
 // ./core/clingutils/G__unordered_mapDict.cxx
 #include "unordered_map"
-// ./core/clingutils/G__valarrayDict.cxx
-#include "valarray"
 // ./core/multiproc/G__MultiProc.cxx
 #include "MPCode.h"
 #include "MPSendRecv.h"
@@ -302,7 +302,6 @@
 #include "TAtomicCount.h"
 #include "TCondition.h"
 #include "TConditionImp.h"
-#include "ThreadLocalStorage.h"
 #include "TMutex.h"
 #include "TMutexImp.h"
 #include "TRWLock.h"
@@ -319,6 +318,7 @@
 #include "ROOT/TFuture.hxx"
 #include "ROOT/TTaskGroup.hxx"
 #include "ROOT/RTaskArena.hxx"
+#include "ROOT/RSlotStack.hxx"
 #include "ROOT/TExecutor.hxx"
 #include "ROOT/TThreadExecutor.hxx"
 // ./math/mathcore/G__MathCore.cxx
@@ -562,6 +562,7 @@
 #include "Minuit2/MnLineSearch.h"
 #include "Minuit2/MnMachinePrecision.h"
 #include "Minuit2/MnMatrix.h"
+#include "Minuit2/MnMatrixfwd.h"
 #include "Minuit2/MnMigrad.h"
 #include "Minuit2/MnMinimize.h"
 #include "Minuit2/MnMinos.h"
@@ -785,6 +786,7 @@
 #include "TFractionFitter.h"
 #include "THistRange.h"
 #include "TGraph2DErrors.h"
+#include "TGraph2DAsymmErrors.h"
 #include "TGraph2D.h"
 #include "TGraphAsymmErrors.h"
 #include "TGraphMultiErrors.h"
@@ -941,6 +943,7 @@
 #include "TVirtualIndex.h"
 #include "TVirtualTreePlayer.h"
 #include "ROOT/InternalTreeUtils.hxx"
+#include "ROOT/RFriendInfo.hxx"
 #include "ROOT/TIOFeatures.hxx"
 // ./tree/treeplayer/G__TreePlayer.cxx
 #include "ROOT/TTreeReaderFast.hxx"
@@ -989,6 +992,8 @@
 #include "TTreeViewer.h"
 #include "TTVLVContainer.h"
 #include "TTVSession.h"
+// ./tree/webviewer/G__ROOTTreeViewer.cxx
+#include "ROOT/RTreeViewer.hxx"
 // ./tree/dataframe/G__ROOTDataFrame.cxx
 #include "ROOT/RCsvDS.hxx"
 #include "ROOT/RDataFrame.hxx"
@@ -1006,9 +1011,9 @@
 #include "ROOT/RDF/GraphUtils.hxx"
 #include "ROOT/RDF/HistoModels.hxx"
 #include "ROOT/RDF/InterfaceUtils.hxx"
-#include "ROOT/RDF/InternalUtils.hxx"
 #include "ROOT/RDF/RActionBase.hxx"
 #include "ROOT/RDF/RAction.hxx"
+#include "ROOT/RDF/RActionImpl.hxx"
 #include "ROOT/RDF/RColumnRegister.hxx"
 #include "ROOT/RDF/RNewSampleNotifier.hxx"
 #include "ROOT/RDF/RSampleInfo.hxx"
@@ -1023,6 +1028,7 @@
 #include "ROOT/RDF/RFilterBase.hxx"
 #include "ROOT/RDF/RFilter.hxx"
 #include "ROOT/RDF/RInterface.hxx"
+#include "ROOT/RDF/RInterfaceBase.hxx"
 #include "ROOT/RDF/RJittedAction.hxx"
 #include "ROOT/RDF/RJittedDefine.hxx"
 #include "ROOT/RDF/RJittedFilter.hxx"
@@ -1030,11 +1036,12 @@
 #include "ROOT/RDF/RLazyDSImpl.hxx"
 #include "ROOT/RDF/RLoopManager.hxx"
 #include "ROOT/RDF/RMergeableValue.hxx"
+#include "ROOT/RDF/RMetaData.hxx"
 #include "ROOT/RDF/RNodeBase.hxx"
 #include "ROOT/RDF/RRangeBase.hxx"
 #include "ROOT/RDF/RRange.hxx"
 #include "ROOT/RDF/RResultMap.hxx"
-#include "ROOT/RDF/RSlotStack.hxx"
+#include "ROOT/RDF/RSample.hxx"
 #include "ROOT/RDF/RTreeColumnReader.hxx"
 #include "ROOT/RDF/RVariation.hxx"
 #include "ROOT/RDF/RVariationBase.hxx"
@@ -1074,6 +1081,8 @@
 #include "ROOT/RPageSourceFriends.hxx"
 #include "ROOT/RPageStorage.hxx"
 #include "ROOT/RPageStorageFile.hxx"
+// ./tree/ntupleutil/G__ROOTNTupleUtil.cxx
+#include "ROOT/RNTupleImporter.hxx"
 // ./io/io/G__RIO.cxx
 #include "ROOT/RRawFile.hxx"
 #include "ROOT/RRawFileUnix.hxx"
@@ -1673,6 +1682,7 @@
 #include "TMVA/RReader.hxx"
 #include "TMVA/RInferenceUtils.hxx"
 #include "TMVA/RBDT.hxx"
+#include "TMVA/RSofieReader.hxx"
 // ./tmva/tmvagui/G__TMVAGui.cxx
 #include "TMVA/BDT.h"
 #include "TMVA/BDTControlPlots.h"
@@ -1723,21 +1733,39 @@
 #include "TMVA/OperatorList.hxx"
 #include "TMVA/RModel.hxx"
 #include "TMVA/ROperator.hxx"
-#include "TMVA/ROperator_Add.hxx"
+#include "TMVA/ROperator_BasicUnary.hxx"
+#include "TMVA/ROperator_BasicBinary.hxx"
+#include "TMVA/ROperator_BasicNary.hxx"
 #include "TMVA/ROperator_BatchNormalization.hxx"
 #include "TMVA/ROperator_Conv.hxx"
+#include "TMVA/ROperator_ConvTranspose.hxx"
 #include "TMVA/ROperator_Gemm.hxx"
 #include "TMVA/ROperator_Relu.hxx"
+#include "TMVA/ROperator_Tanh.hxx"
+#include "TMVA/ROperator_LeakyRelu.hxx"
 #include "TMVA/ROperator_Reshape.hxx"
 #include "TMVA/ROperator_Selu.hxx"
 #include "TMVA/ROperator_Sigmoid.hxx"
 #include "TMVA/ROperator_Slice.hxx"
 #include "TMVA/ROperator_Transpose.hxx"
 #include "TMVA/ROperator_Pool.hxx"
+#include "TMVA/ROperator_Concat.hxx"
+#include "TMVA/ROperator_Identity.hxx"
+#include "TMVA/ROperator_Softmax.hxx"
+#include "TMVA/ROperator_Reduce.hxx"
+#include "TMVA/ROperator_Shape.hxx"
+#include "TMVA/ROperator_Cast.hxx"
+#include "TMVA/ROperator_Custom.hxx"
+#include "TMVA/ROperator_LayerNormalization.hxx"
+#include "TMVA/ROperator_Expand.hxx"
 #include "TMVA/SOFIE_common.hxx"
+#include "TMVA/SOFIEHelpers.hxx"
 // ./roofit/roofitcore/G__RooFitCore.cxx
+#include "RooFit/Config.h"
 #include "RooFit/Detail/DataMap.h"
+#include "RooFit/Detail/NormalizationHelpers.h"
 #include "RooFit/Floats.h"
+#include "RooFit/ModelConfig.h"
 #include "Roo1DTable.h"
 #include "RooAbsAnaConvPdf.h"
 #include "RooAbsArg.h"
@@ -1757,9 +1785,7 @@
 #include "RooAbsIntegrator.h"
 #include "RooAbsLValue.h"
 #include "RooAbsMCStudyModule.h"
-#include "RooAbsMinimizerFcn.h"
 #include "RooAbsMoment.h"
-#include "RooAbsNumGenerator.h"
 #include "RooAbsOptTestStatistic.h"
 #include "RooAbsPdf.h"
 #include "RooAbsProxy.h"
@@ -1771,7 +1797,6 @@
 #include "RooAbsString.h"
 #include "RooAbsStudy.h"
 #include "RooAbsTestStatistic.h"
-#include "RooAcceptReject.h"
 #include "RooAdaptiveIntegratorND.h"
 #include "RooAddGenContext.h"
 #include "RooAddition.h"
@@ -1796,6 +1821,7 @@
 #include "RooClassFactory.h"
 #include "RooCmdArg.h"
 #include "RooCmdConfig.h"
+#include "RooCollectionProxy.h"
 #include "RooCompositeDataStore.h"
 #include "RooConstraintSum.h"
 #include "RooConstVar.h"
@@ -1828,7 +1854,6 @@
 #include "RooFirstMoment.h"
 #include "RooFit.h"
 #include "RooFitResult.h"
-#include "RooFoamGenerator.h"
 #include "RooFormula.h"
 #include "RooFormulaVar.h"
 #include "RooFracRemainder.h"
@@ -1856,16 +1881,13 @@
 #include "RooLinkedList.h"
 #include "RooLinkedListIter.h"
 #include "RooLinTransBinning.h"
-#include "RooList.h"
 #include "RooListProxy.h"
 #include "RooMath.h"
 #include "RooMappedCategory.h"
 #include "RooMCIntegrator.h"
 #include "RooMCStudy.h"
-#include "RooMinimizerFcn.h"
 #include "RooMinimizer.h"
 #include "RooMoment.h"
-#include "RooMPSentinel.h"
 #include "RooMsgService.h"
 #include "RooMultiCategory.h"
 #include "RooMultiGenFunction.h"
@@ -1878,7 +1900,6 @@
 #include "RooNumConvolution.h"
 #include "RooNumConvPdf.h"
 #include "RooNumGenConfig.h"
-#include "RooNumGenFactory.h"
 #include "RooNumIntConfig.h"
 #include "RooNumIntFactory.h"
 #include "RooNumRunningInt.h"
@@ -1921,16 +1942,15 @@
 #include "RooSecondMoment.h"
 #include "RooSegmentedIntegrator1D.h"
 #include "RooSegmentedIntegrator2D.h"
-#include "RooSentinel.h"
 #include "RooSetProxy.h"
 #include "RooSharedProperties.h"
 #include "RooSimGenContext.h"
-#include "RooSimPdfBuilder.h"
 #include "RooSimSplitGenContext.h"
 #include "RooSimultaneous.h"
 #include "RooSimWSTool.h"
 #include "RooStreamParser.h"
 #include "RooStringVar.h"
+#include "RooStringView.h"
 #include "RooStudyManager.h"
 #include "RooStudyPackage.h"
 #include "RooSuperCategory.h"
@@ -1949,15 +1969,11 @@
 #include "RooXYChi2Var.h"
 #include "RooHelpers.h"
 #include "RooWrapperPdf.h"
-#include "RooNaNPacker.h"
 #include "RooBinSamplingPdf.h"
 #include "RooBinWidthFunction.h"
 #include "RooFitLegacy/RooCatTypeLegacy.h"
 #include "RooFitLegacy/RooCategorySharedProperties.h"
-#include "RooFitLegacy/RooHashTable.h"
 #include "RooFitLegacy/RooMinuit.h"
-#include "RooFitLegacy/RooNameSet.h"
-#include "RooFitLegacy/RooSetPair.h"
 #include "RooFitLegacy/RooTreeData.h"
 #include "RooFit/TestStatistics/LikelihoodGradientWrapper.h"
 #include "RooFit/TestStatistics/LikelihoodWrapper.h"
@@ -1994,6 +2010,8 @@
 #include "RooDecay.h"
 #include "RooDstD0BG.h"
 #include "RooExponential.h"
+#include "RooExpPoly.h"
+#include "RooPower.h"
 #include "RooFunctor1DBinding.h"
 #include "RooFunctorBinding.h"
 #include "RooGamma.h"
@@ -2055,13 +2073,11 @@
 #include "RooStats/Heaviside.h"
 #include "RooStats/HLFactory.h"
 #include "RooStats/HybridCalculator.h"
-#include "RooStats/HybridCalculatorOriginal.h"
 #include "RooStats/HybridPlot.h"
 #include "RooStats/HybridResult.h"
 #include "RooStats/HypoTestCalculatorGeneric.h"
 #include "RooStats/HypoTestCalculator.h"
 #include "RooStats/HypoTestInverter.h"
-#include "RooStats/HypoTestInverterOriginal.h"
 #include "RooStats/HypoTestInverterPlot.h"
 #include "RooStats/HypoTestInverterResult.h"
 #include "RooStats/HypoTestPlot.h"
@@ -2108,14 +2124,12 @@
 #include "RooStats/HistFactory/Asimov.h"
 #include "RooStats/HistFactory/Channel.h"
 #include "RooStats/HistFactory/Data.h"
-#include "RooStats/HistFactory/EstimateSummary.h"
+#include "RooStats/HistFactory/Detail/HistFactoryImpl.h"
 #include "RooStats/HistFactory/FlexibleInterpVar.h"
 #include "RooStats/HistFactory/HistFactoryException.h"
 #include "RooStats/HistFactory/HistFactoryModelUtils.h"
 #include "RooStats/HistFactory/HistFactoryNavigation.h"
-#include "RooStats/HistFactory/HistFactorySimultaneous.h"
 #include "RooStats/HistFactory/HistoToWorkspaceFactoryFast.h"
-#include "RooStats/HistFactory/HistoToWorkspaceFactory.h"
 #include "RooStats/HistFactory/HistRef.h"
 #include "RooStats/HistFactory/LinInterpVar.h"
 #include "RooStats/HistFactory/MakeModelAndMeasurementsFast.h"
@@ -2129,10 +2143,16 @@
 #include "RooStats/HistFactory/ConfigParser.h"
 // ./roofit/RDataFrameHelpers/G__RooFitRDataFrameHelpers.cxx
 #include "RooAbsDataHelper.h"
+// ./roofit/jsoninterface/G__RooFitJSONInterface.cxx
+#include "RooFit/Detail/JSONInterface.h"
 // ./roofit/hs3/G__RooFitHS3.cxx
+#include "RooFitHS3/JSONIO.h"
 #include "RooFitHS3/RooJSONFactoryWSTool.h"
 #include "RooFitHS3/HistFactoryJSONTool.h"
-#include "RooFitHS3/JSONInterface.h"
+// ./roofit/xroofit/G__RooFitXRooFit.cxx
+#include "RooBrowser.h"
+#include "RooFit/xRooFit/xRooNode.h"
+#include "RooFit/xRooFit/xRooBrowser.h"
 // ./core/G__Core.cxx
 #include "ROOT/TErrorDefaultHandler.hxx"
 #include "ROOT/TSequentialExecutor.hxx"
@@ -2267,6 +2287,7 @@
 #include "RStringView.h"
 #include "TClassEdit.h"
 #include "TError.h"
+#include "ThreadLocalStorage.h"
 #include "ROOT/RLogger.hxx"
 #include "ROOT/RNotFn.hxx"
 #include "ROOT/RRangeCast.hxx"
