@@ -22,6 +22,15 @@
 
 #define EXTRAICONPATH ""
 
+#define ROOT__cplusplus 201703L
+#if defined(__cplusplus) && (__cplusplus != ROOT__cplusplus)
+# if defined(_MSC_VER)
+#  pragma message("The C++ standard in this build does not match ROOT configuration (201703L); this might cause unexpected issues. And please make sure you are using the -Zc:__cplusplus compilation flag")
+# else
+#  warning "The C++ standard in this build does not match ROOT configuration (201703L); this might cause unexpected issues"
+# endif
+#endif
+
 #define R__HAS_SETRESUID   /**/
 #define R__HAS_MATHMORE   /**/
 #define R__HAS_PTHREAD    /**/
