@@ -1,9 +1,8 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
-
 // Provides miscellaneous utility functions that might be useful for any script
 sap.ui.define([
 	'jquery.sap.global',
@@ -220,14 +219,14 @@ sap.ui.define([
 			return merge.apply(this, args);
 		} else {
 			/*
-			 * The code in this function is taken from jQuery 2.2.3 "jQuery.extend" and got modified.
+			 * The code in this function is taken from jQuery 3.6.0 "jQuery.extend" and got modified.
 			 *
-			 * jQuery JavaScript Library v2.2.3
-			 * http://jquery.com/
+			 * jQuery JavaScript Library v3.6.0
+			 * https://jquery.com/
 			 *
-			 * Copyright jQuery Foundation and other contributors
+			 * Copyright OpenJS Foundation and other contributors
 			 * Released under the MIT license
-			 * http://jquery.org/license
+			 * https://jquery.org/license
 			 */
 			var copy, name, options,
 				target = arguments[0] || {},
@@ -248,7 +247,7 @@ sap.ui.define([
 					copy = options[name];
 
 					// Prevent never-ending loop
-					if (target === copy) {
+					if (name === "__proto__" || target === copy) {
 						continue;
 					}
 
@@ -268,7 +267,7 @@ sap.ui.define([
 	 * Use {@link jQuery.sap.getUriParameters} to create an instance of jQuery.sap.util.UriParameters.
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @since 0.9.0
 	 * @name jQuery.sap.util.UriParameters
 	 * @public
@@ -390,8 +389,8 @@ sap.ui.define([
 	};
 
 	/**
-	 * Substitute for <code>for(n in o)</code> loops which used to fix the 'Don'tEnum' bug of IE8.
-	 * As IE8 is not supported anymore this function is just a wrapper around the native for-in loop.
+	 * Substitute for <code>for(n in o)</code> loops.
+	 * This function is just a wrapper around the native for-in loop.
 	 *
 	 * Iterates over all enumerable properties of the given object and calls the
 	 * given callback function for each of them. The assumed signature of the
@@ -403,7 +402,7 @@ sap.ui.define([
 	 *
 	 * @param {object} oObject object to enumerate the properties of
 	 * @param {function} fnCallback function to call for each property name
-	 * @deprecated since 1.48.0 IE8 is not supported anymore, thus no special handling is required. Use native for-in loop instead.
+	 * @deprecated since 1.48.0. Use native for-in loop instead.
 	 * @since 1.7.1
 	 */
 	jQuery.sap.forIn = each;
