@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -12,7 +12,7 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 	 * Handles dragging of a control over a given grid container.
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 *
 	 * @extends sap.ui.base.Object
 	 *
@@ -61,9 +61,10 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 	 * @param {sap.ui.core.Control} oDragControl The control which is dragged
 	 * @param {sap.ui.core.Control} oDropContainer The drop container
 	 * @param {string} sTargetAggregation The name of the target aggregation inside the drop container
-	 * @returns {sap.f.dnd.GridDragOver} Self for method chaining
+	 * @param {sap.ui.core.DragSession} oCoreDragSession
+	 * @returns {this} Self for method chaining
 	 */
-	GridDragOver.prototype.setCurrentContext = function (oDragControl, oDropContainer, sTargetAggregation) {
+	GridDragOver.prototype.setCurrentContext = function (oDragControl, oDropContainer, sTargetAggregation, oCoreDragSession) {
 		if (this._oDragControl === oDragControl
 			&& this._oDropContainer === oDropContainer
 			&& this._sTargetAggregation === sTargetAggregation) {
@@ -80,6 +81,7 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 		this._oDragContainer = oDragControl.getParent();
 		this._oDropContainer = oDropContainer;
 		this._sTargetAggregation = sTargetAggregation;
+		this._oCoreDragSession = oCoreDragSession;
 
 		this._mDragItemDimensions = this._getDimensions(oDragControl);
 		this._bIsInSameContainer = this._oDragContainer === this._oDropContainer;
@@ -96,6 +98,8 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 
 		this._attachEventDelegates();
 
+		this._hideCoreDefaultIndicator();
+
 		return this;
 	};
 
@@ -111,6 +115,8 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 			return;
 		}
 
+		this._hideCoreDefaultIndicator();
+
 		// propose a drop position
 		var mDropPosition = this._calculateDropPosition(oDragEvent);
 
@@ -204,10 +210,7 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 
 		this._removeEventDelegates();
 
-		// fire private event for handling IE specific layout fixes
-		this._oDropContainer.fireEvent("_gridPolyfillAfterDragEnd", {
-			indicator: this._$indicator
-		});
+		this._resetCoreDefaultIndicator();
 
 		this._mDropIndicatorSize = null;
 		this._oDragControl = null;
@@ -218,11 +221,12 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 		this._iDropPositionHoldStart = null;
 		this._mLastDropPosition = null;
 		this._mFreezePosition = null;
+		this._oCoreDragSession = null;
 	};
 
 	/**
 	 * Is the drag still active or it has ended.
-	 * @returns {bool} True if the drag is still active, false if it was ended.
+	 * @returns {boolean} True if the drag is still active, false if it was ended.
 	 */
 	GridDragOver.prototype._isDragActive = function() {
 		return this._oDragControl && this._oDropContainer;
@@ -247,11 +251,6 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 			$insertTarget = $targetGridItem || oTargetControl.$();
 		}
 
-		if ($insertTarget && oDropContainer.isA("sap.f.GridContainer")) {
-			// todo: find better way to find the item wrapper when it is not grid item, needed for IE
-			$insertTarget = $insertTarget.closest(".sapFGridContainerItemWrapper");
-		}
-
 		if (this._mDropIndicatorSize) {
 			mStyles = {
 				"grid-row-start": "span " + this._mDropIndicatorSize.rows,
@@ -282,25 +281,6 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 
 		// when drop indicator is shown, it becomes the new "drag from"
 		this._iDragFromIndex = iTargetIndex;
-
-		/* IE Polyfill */
-
-		// Let the container decide the dimensions of the indicator.
-		var oEventData = {
-			indicator: this._$indicator,
-			indicatorIndex: this._iDragFromIndex
-		};
-
-		if (this._mDropIndicatorSize) {
-			oEventData.rows = this._mDropIndicatorSize.rows;
-			oEventData.columns = this._mDropIndicatorSize.columns;
-		} else {
-			oEventData.width = this._mDragItemDimensions.rect.width;
-			oEventData.height = this._mDragItemDimensions.rect.height;
-		}
-
-		// fire private event for handling IE specific layout fixes
-		this._oDropContainer.fireEvent("_gridPolyfillAfterDragOver", oEventData);
 	};
 
 	/**
@@ -309,7 +289,7 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 	GridDragOver.prototype._hideIndicator = function() {
 		this._$indicator.detach();
 
-		this._$indicator.attr("style", ""); // VirtualGrid sets position 'absolute' to the indicator, which breaks calculations in other containers, such as GridList
+		this._$indicator.attr("style", ""); // Clear styles of the indicator that are set by containers, like position "absolute"
 	};
 
 	/**
@@ -324,8 +304,6 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 
 		if ($gridItem && this._bIsInSameContainer) {
 			$gridItem.hide();
-		} else {
-			this._oDragContainer.fireEvent("_gridPolyfillDraggingInAnotherContainer");
 		}
 	};
 
@@ -347,6 +325,42 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 
 	};
 
+	/**
+	 * Hide original indicator
+	 * @param {jQuery.Event} oDragEvent The drag event
+	 */
+	GridDragOver.prototype._hideCoreDefaultIndicator = function() {
+		var oCoreDefaultIndicator = this._oCoreDragSession.getIndicator(),
+			mStyles = {
+				visibility: "hidden",
+				position: "relative" // this prevents a scroll to appear sometimes on the page
+			};
+
+		this._oCoreDragSession.setIndicatorConfig(mStyles);
+
+		if (oCoreDefaultIndicator) {
+			jQuery(oCoreDefaultIndicator).css(mStyles);
+		}
+	};
+
+	/**
+	 * Resets the indicator used by the core drag and drop.
+	 * @param {jQuery.Event} oDragEvent The drag event
+	 */
+	GridDragOver.prototype._resetCoreDefaultIndicator = function() {
+		var oCoreDefaultIndicator = this._oCoreDragSession.getIndicator(),
+			mStyles = {
+				visibility: "visible",
+				position: "absolute"
+			};
+
+		this._oCoreDragSession.setIndicatorConfig(mStyles);
+
+		if (oCoreDefaultIndicator) {
+			jQuery(oCoreDefaultIndicator).css(mStyles);
+		}
+	};
+
 	/**
 	 * Checks if the user holds the same drop position for some time.
 	 * @param {DropPosition} mDropPosition The suggested position
@@ -560,7 +574,7 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 	 * @returns {jQuery|null} The jQuery ref of the control which is on this position
 	 */
 	GridDragOver.prototype._findItemFromPoint = function(iPageX, iPageY) {
-		var oOverElement = document.elementFromPoint(iPageX, iPageY),
+		var oOverElement = document.elementFromPoint(iPageX - window.pageXOffset, iPageY - window.pageYOffset),
 			$closestItem = jQuery(oOverElement).closest(".sapUiDnDGridControl, .sapUiDnDGridIndicator");
 
 		if ($closestItem.hasClass("sapUiDnDGridIndicator")) {
@@ -644,7 +658,7 @@ sap.ui.define(['sap/ui/base/Object', "sap/ui/thirdparty/jquery", "sap/base/Log"]
 	 * @param {jQuery.Event} oEvent The jQuery dragleave event.
 	 */
 	GridDragOver.prototype._onDragLeave = function(oEvent) {
-		var oElement = document.elementFromPoint(oEvent.pageX, oEvent.pageY),
+		var oElement = document.elementFromPoint(oEvent.pageX - window.pageXOffset, oEvent.pageY - window.pageYOffset),
 			bIsElementWithinDropContainer = this._oDropContainer.getDomRef().contains(oElement);
 
 		// Check if element from point is inside the drop container, because dragleave
