@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 sap.ui.define([], function() {
@@ -32,11 +32,22 @@ sap.ui.define([], function() {
 						eventData: vData,
 						targetControl: oViewInfo.control,
 						view: oViewInfo.view,
-						layout: oRouteConfig.layout
+						layout: oRouteConfig.layout,
+						placeholderConfig: oViewInfo.placeholderConfig
 					});
 					return oViewInfo;
 				});
-			});
+			}, this._oOptions._name);
+
+		},
+		showPlaceholder : function(mSettings) {
+			return this._oTargetHandler.showPlaceholder(mSettings);
+		},
+		hidePlaceholder : function(mSettings) {
+		/**
+		 * Overriding the hidePlaceholder to empty function because the placeholder is removed
+		 * after all targets are displayed
+		 */
 		}
 	};
 }, /* bExport= */ true);
