@@ -1,11 +1,11 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
-sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/LabelEnablement', 'sap/ui/Device'],
-	function(Renderer, coreLibrary, LabelEnablement, Device) {
+sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/Core', 'sap/ui/core/library', 'sap/ui/core/ValueStateSupport', 'sap/ui/core/LabelEnablement', 'sap/ui/Device'],
+	function(Renderer, Core, coreLibrary, ValueStateSupport, LabelEnablement, Device) {
 	"use strict";
 
 	// shortcut for sap.ui.core.TextDirection
@@ -59,7 +59,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 			oRm.class("sapMInputBaseReadonly");
 		}
 
-		if (sValueState !== ValueState.None) {
+		if (sValueState !== ValueState.None && oControl.getEditable() && oControl.getEnabled()) {
 			oRm.class("sapMInputBaseState");
 		}
 
@@ -102,7 +102,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 			oRm.class("sapMInputBaseReadonlyWrapper");
 		}
 
-		if (sValueState !== ValueState.None) {
+		if (sValueState !== ValueState.None && oControl.getEditable() && oControl.getEnabled()) {
 			this.addValueStateClasses(oRm, oControl);
 		}
 
@@ -196,6 +196,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 		if (bAccessibility) {
 			this.renderAriaLabelledBy(oRm, oControl);
 			this.renderAriaDescribedBy(oRm, oControl);
+			this.renderValueStateAccDom(oRm, oControl);
 		}
 
 		// finish outer
@@ -206,6 +207,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Returns aria accessibility role for the control.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.Control} oControl an object representation of the control
 	 * @returns {String}
 	 */
@@ -217,6 +219,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Returns the inner aria labelledby ids for the accessibility.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.Control} oControl an object representation of the control.
 	 * @returns {String|undefined}
 	 */
@@ -230,6 +233,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Returns the inner aria labelledby announcement texts for the accessibility.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.Control} oControl an object representation of the control.
 	 * @returns {String}
 	 */
@@ -241,6 +245,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Renders the hidden aria labelledby node for the accessibility.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -260,6 +265,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Returns the inner aria describedby ids for the accessibility.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.Control} oControl an object representation of the control.
 	 * @returns {String|undefined}
 	 */
@@ -273,6 +279,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Returns the inner aria describedby announcement texts for the accessibility.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.Control} oControl an object representation of the control.
 	 * @returns {String}
 	 */
@@ -284,6 +291,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Renders the hidden aria labelledby node for the accessibility.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -299,10 +307,46 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 		}
 	};
 
+	/**
+	 * Renders the hidden aria describedby and errormessage nodes for the accessibility.
+	 *
+	 * @protected
+	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
+	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
+	 */
+	InputBaseRenderer.renderValueStateAccDom = function(oRm, oControl) {
+		var sValueState = oControl.getValueState();
+		if (sValueState === ValueState.None || !oControl.getEditable() || !oControl.getEnabled()) {
+			return;
+		}
+
+		var oFormattedValueStateText = oControl.getAggregation("_invisibleFormattedValueStateText");
+		var sValueStateTypeText;
+
+
+		sValueStateTypeText = Core.getLibraryResourceBundle("sap.m").getText("INPUTBASE_VALUE_STATE_" + sValueState.toUpperCase());
+
+		oRm.openStart("div", oControl.getValueStateMessageId() + "-sr")
+			.class("sapUiPseudoInvisibleText");
+
+		oRm.openEnd()
+			.text(sValueStateTypeText).text(" ");
+
+		if (oFormattedValueStateText) {
+			oRm.renderControl(oFormattedValueStateText);
+		} else {
+			// Flush previous value state text and populate it again even if the same as before to avoid the
+			// semantic renderer's DOM patching and update the live region
+			oRm.text(oControl.getValueStateText() || ValueStateSupport.getAdditionalText(oControl));
+		}
+		oRm.close("div");
+	};
+
 	/**
 	 * Returns the accessibility state of the control.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.Control} oControl an object representation of the control.
 	 * @returns {Object}
 	 */
@@ -310,14 +354,18 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 		var sAriaLabelledBy = this.getAriaLabelledBy(oControl),
 			sAriaDescribedBy = this.getAriaDescribedBy(oControl),
 			sRole = this.getAriaRole(oControl),
+			sValueStateAccNodeId = oControl.getValueStateMessageId() + "-sr",
 			mAccessibilityState = { };
 
 		if (sRole) {
 			mAccessibilityState.role = sRole;
 		}
 
-		if (oControl.getValueState() === ValueState.Error) {
+		if (oControl.getValueState() === ValueState.Error && oControl.getEditable() && oControl.getEnabled()) {
 			mAccessibilityState.invalid = true;
+			mAccessibilityState.errormessage = sValueStateAccNodeId;
+		} else if (oControl.getValueState() !== ValueState.None && oControl.getEditable() && oControl.getEnabled()) {
+			sAriaDescribedBy = sAriaDescribedBy ? sValueStateAccNodeId + " " + sAriaDescribedBy : sValueStateAccNodeId;
 		}
 
 		if (sAriaLabelledBy) {
@@ -343,6 +391,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Writes the accessibility state of the control.
 	 * Hook for the subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -353,6 +402,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Write the opening tag name of the input.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -363,6 +413,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Ends opened input tag.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -373,6 +424,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Write the value of the input.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -383,6 +435,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Add cursor class to input container.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -392,6 +445,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Add a padding class to input container.
 	 * May be overwritten by subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -402,6 +456,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived class to add extra styles for input container.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -410,6 +465,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived class to set width inline style
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -424,6 +480,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived classes to add extra classes for input container.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -432,6 +489,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived class to add extra attributes for input container.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -440,6 +498,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived classes to add extra styles for input element.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -448,6 +507,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived classes to add extra styles for input element.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -458,6 +518,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived classes to add extra classes for input element.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -466,6 +527,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived classes to add extra attributes for the input element.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -474,6 +536,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * This method is reserved for derived classes to prepend inner content.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -482,6 +545,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Write the value of the input.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -490,6 +554,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Renders icons from the icon aggregations.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 * @param {string} sPosition An aggregation from which the icon should be rendered - begin or end.
@@ -506,6 +571,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Write the decorations of the input - description and value-help icon.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -514,6 +580,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Write the closing tag name of the input.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -523,6 +590,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * This method is reserved for derived classes to add extra styles for the placeholder, if rendered as label.
 	 *
 	 * @deprecated
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -534,6 +602,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Note that this method should not be used anymore as native placeholder is used on all browsers
 	 *
 	 * @deprecated
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -543,6 +612,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	 * Add the CSS value state classes to the control's root element using the provided {@link sap.ui.core.RenderManager}.
 	 * To be overwritten by subclasses.
 	 *
+	 * @protected
 	 * @param {sap.ui.core.RenderManager} oRm The RenderManager that can be used for writing to the render output buffer.
 	 * @param {sap.ui.core.Control} oControl An object representation of the control that should be rendered.
 	 */
@@ -554,6 +624,7 @@ sap.ui.define(['sap/ui/core/Renderer', 'sap/ui/core/library', 'sap/ui/core/Label
 	/**
 	 * Defines the ID suffix of the inner element
 	 *
+	 * @protected
 	 * @returns {string} The inner element ID suffix.
 	 */
 	InputBaseRenderer.getInnerSuffix = function() {
