@@ -1,10 +1,10 @@
 /*
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
-sap.ui.define(['sap/ui/core/util/MockServer', 'sap/ui/model/odata/ODataModel'],
-	function(MockServer, ODataModel) {
+sap.ui.define(['sap/ui/model/odata/ODataModel'],
+	function(ODataModel) {
 		"use strict";
 		return {
 
@@ -13,6 +13,7 @@ sap.ui.define(['sap/ui/core/util/MockServer', 'sap/ui/model/odata/ODataModel'],
 					this._index = 0;
 				}
 				var sUri = "/annotationhandler" + this._index++ + "/";
+				var MockServer = sap.ui.require("sap/ui/core/util/MockServer");
 				var oMockStub = new MockServer({
 					rootUri: sUri,
 					requests: [{
