@@ -1,17 +1,19 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 // Provides object sap.ui.dt.OverlayUtil.
 sap.ui.define([
 	"sap/ui/dt/OverlayRegistry",
-	"sap/ui/dt/ElementUtil"
+	"sap/ui/dt/ElementUtil",
+	"sap/ui/core/UIArea"
 ],
 function(
 	OverlayRegistry,
-	ElementUtil
+	ElementUtil,
+	UIArea
 ) {
 	"use strict";
 
@@ -20,7 +22,7 @@ function(
 	 *
 	 * @class Utility functionality to work with overlays
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @static
 	 * @since 1.30
@@ -62,7 +64,7 @@ function(
 
 			return {
 				parent: oParent,
-				aggregation : sParentAggregationName,
+				aggregation: sParentAggregationName,
 				index: iIndex
 			};
 		}
@@ -136,7 +138,7 @@ function(
 					left: minLeft,
 					top: minTop
 				},
-				visible : true
+				visible: true
 			};
 		}
 	};
@@ -198,7 +200,7 @@ function(
 	/**
 	 * Returns all overlay children as ElementOverlay.
 	 *
-	 * @param {sap.ui.dt.ElementOverlay} oOverlay - Source overlay object
+	 * @param {sap.ui.dt.ElementOverlay} oElementOverlay - Source overlay object
 	 * @returns {array} Returns an array of child overlays {sap.ui.dt.ElementOverlay}
 	 * @private
 	 */
@@ -418,9 +420,9 @@ function(
 					return aFlattenedArray.concat(oCurrentValue);
 				}, []);
 			} else {
-				aRelevantOverlays = oOverlay.getParentElementOverlay()
-										.getAggregationOverlay(oOverlay.getParentAggregationOverlay().getAggregationName())
-										.getChildren();
+				var sAggregationName = oOverlay.getParentAggregationOverlay().getAggregationName();
+				var oAggregationOverlay = oParentOverlay.getAggregationOverlay(sAggregationName);
+				aRelevantOverlays = (oAggregationOverlay && oAggregationOverlay.getChildren()) || [];
 			}
 		}
 
@@ -432,13 +434,13 @@ function(
 	};
 
 	/**
-	 * Gets all the Overlays inside the relevant container which are in the same aggregations
-	 * and have DesignTime Metadata.
+	 * Gets all the Overlays with DesignTime Metadata inside the relevant container
 	 * @param {sap.ui.dt.ElementOverlay} oOverlay Overlay from which we get the aggregations
+	 * @param {boolean} bIncludeOtherAggregations Include also overlays from other aggregations from the parent
 	 * @returns {sap.ui.dt.ElementOverlay[]} Returns an array with all the overlays in it
 	 * @protected
 	 */
-	OverlayUtil.findAllOverlaysInContainer = function(oOverlay) {
+	OverlayUtil.findAllOverlaysInContainer = function(oOverlay, bIncludeOtherAggregations) {
 		// The root control has no relevant container, therefore we use the element itself
 		var oRelevantContainer = oOverlay.getRelevantContainer() || oOverlay.getElement();
 		var oRelevantContainerOverlay = OverlayRegistry.getOverlay(oRelevantContainer);
@@ -450,16 +452,17 @@ function(
 		}
 
 		// Get all the siblings and parents of the overlay
-		var mRelevantOverlays = OverlayUtil._findAllSiblingsAndParents(oOverlay, oRelevantContainerOverlay, 0);
+		var mRelevantOverlays = OverlayUtil._findAllSiblingsAndParents(oOverlay, oRelevantContainerOverlay, 0, bIncludeOtherAggregations);
 
 		if (mRelevantOverlays[0]) {
 			for (var iLevel in mRelevantOverlays) {
 				aRelevantOverlays = aRelevantOverlays.concat(mRelevantOverlays[iLevel]);
 			}
 
-			// the overlay and its siblings are on the first level of the relevantOverlays. From those overlays we also need to get the children
 			var aChildren = [];
-			mRelevantOverlays[0].forEach(function(oOverlay) {
+			var aOverlaysToGetChildrenFrom = bIncludeOtherAggregations ? aRelevantOverlays : mRelevantOverlays[0];
+
+			aOverlaysToGetChildrenFrom.forEach(function(oOverlay) {
 				aChildren = aChildren.concat(OverlayUtil._findAllChildrenInContainer(oOverlay, oRelevantContainer));
 			});
 
@@ -478,23 +481,49 @@ function(
 	};
 
 	/**
-	 * This function returns all the siblings and parents inside the relevant container. Siblings in different aggregations are ignored.
+	 * This function returns all the siblings and parents inside the relevant container.
 	 * @param {sap.ui.dt.ElementOverlay} oOverlay Overlay from which we get the aggregations
 	 * @param {sap.ui.dt.ElementOverlay} oRelevantContainerOverlay Relevant container overlay
 	 * @param {int} iLevel Current level in the hierarchy
+	 * @param {boolean} bIncludeOtherAggregations Include also overlays from other aggregations from the parent
 	 * @returns {object} Returns a map with all siblings sorted by the level
 	 * @private
 	 */
-	OverlayUtil._findAllSiblingsAndParents = function(oOverlay, oRelevantContainerOverlay, iLevel) {
-		var oParent = oOverlay.getParentElementOverlay();
-		if (!oParent) {
+	OverlayUtil._findAllSiblingsAndParents = function(oOverlay, oRelevantContainerOverlay, iLevel, bIncludeOtherAggregations) {
+		var oParentOverlay = oOverlay.getParentElementOverlay();
+		if (!oParentOverlay) {
 			return [];
 		}
 
-		if (oParent !== oRelevantContainerOverlay) {
-			var mParents = OverlayUtil._findAllSiblingsAndParents(oParent, oRelevantContainerOverlay, iLevel + 1);
-			var aOverlays = mParents[iLevel + 1].map(function(oParent) {
-				var oAggregationOverlay = oParent.getAggregationOverlay(oOverlay.getParentAggregationOverlay().getAggregationName());
+		function getChildrenFromAllAggregations(oParentOverlay) {
+			var aAllAggregationNames = oParentOverlay.getAggregationNames();
+			var aAllAggregationChildren = [];
+
+			// Collect children from all aggregations of the parent
+			aAllAggregationNames.forEach(function(sAggregationName) {
+				var oAggregationOverlay = oParentOverlay.getAggregationOverlay(sAggregationName);
+				var aAggregationChildren = oAggregationOverlay ? oAggregationOverlay.getChildren() : [];
+				aAllAggregationChildren = aAggregationChildren.concat(aAllAggregationChildren);
+			});
+
+			return aAllAggregationChildren;
+		}
+
+		if (oParentOverlay !== oRelevantContainerOverlay) {
+			var mParents;
+			var aOverlays;
+			mParents = OverlayUtil._findAllSiblingsAndParents(oParentOverlay, oRelevantContainerOverlay, iLevel + 1, bIncludeOtherAggregations);
+			if (bIncludeOtherAggregations) {
+				var aAllAggregationChildren = [];
+				mParents[iLevel + 1].forEach(function(oParent) {
+					aAllAggregationChildren.concat(getChildrenFromAllAggregations(oParent));
+				});
+				mParents[iLevel] = aAllAggregationChildren;
+				return mParents;
+			}
+			aOverlays = mParents[iLevel + 1].map(function(oParent) {
+				var sParentAggregationName = oOverlay.getParentAggregationOverlay().getAggregationName();
+				var oAggregationOverlay = oParent.getAggregationOverlay(sParentAggregationName);
 				return oAggregationOverlay ? oAggregationOverlay.getChildren() : [];
 			}).reduce(function(a, b) {
 				return a.concat(b);
@@ -503,7 +532,14 @@ function(
 			return mParents;
 		}
 
-		var aChildren = oOverlay.getParentElementOverlay().getAggregationOverlay(oOverlay.getParentAggregationOverlay().getAggregationName()).getChildren();
+		var aChildren = [];
+
+		if (bIncludeOtherAggregations) {
+			aChildren = getChildrenFromAllAggregations(oParentOverlay);
+		} else {
+			var sParentAggregationName = oOverlay.getParentAggregationOverlay().getAggregationName();
+			aChildren = oOverlay.getParentElementOverlay().getAggregationOverlay(sParentAggregationName).getChildren();
+		}
 		var mReturn = {};
 		mReturn[iLevel] = aChildren;
 		return mReturn;
@@ -547,5 +583,87 @@ function(
 		});
 	};
 
+	/**
+	 * Returns the index of an element in a parent aggregation
+	 * Only the elements of the aggregation which have overlays are counted
+	 * @param {object} oElement Element for which we want to find the index
+	 * @param {object} oParent Parent of the Element
+	 * @param {string} sAggregationName Name of the parent aggregation
+	 * @return {int} Returns the index
+	 */
+	OverlayUtil.getIndexInAggregation = function(oElement, oParent, sAggregationName) {
+		var aElements = ElementUtil.getAggregation(oParent, sAggregationName).filter(function(oCompareElement) {
+			return !!OverlayRegistry.getOverlay(oCompareElement) || oCompareElement === oElement;
+		});
+		return aElements.indexOf(oElement);
+	};
+
+	function findBoundControl(oOverlay, aStack) {
+		var sAggregationName;
+		var iIndex;
+		var oParentOverlay = oOverlay.getParent();
+		var bBoundControlFound = false;
+
+		if (oOverlay.isA("sap.ui.dt.ElementOverlay")) {
+			var oParentElementOverlay = oOverlay.getParentElementOverlay();
+
+			if (oParentOverlay) {
+				sAggregationName = oParentOverlay.getAggregationName();
+				iIndex = oParentOverlay.getChildren().indexOf(oOverlay);
+				bBoundControlFound = oParentElementOverlay
+					&& oParentElementOverlay.getAggregationOverlay(sAggregationName, "AggregationBindingTemplateOverlays");
+			} else {
+				iIndex = -1;
+			}
+
+			aStack.push({
+				overlayId: oOverlay.getId(),
+				aggregation: sAggregationName,
+				index: iIndex
+			});
+
+			if (bBoundControlFound) {
+				return {
+					overlayId: oParentElementOverlay.getId(),
+					aggregation: sAggregationName,
+					stack: aStack
+				};
+			}
+		}
+
+		if (!oParentOverlay || oParentOverlay instanceof UIArea) {
+			return {
+				overlayId: undefined,
+				aggregation: undefined,
+				stack: aStack
+			};
+		}
+		return findBoundControl(oParentOverlay, aStack);
+	}
+
+	/**
+	 * The AggregationBindingInfo contains the overlay ID and the aggregation name of the bound control together with stack containing
+	 * information about the traversed elements for an overlay which is part of an aggregation binding.
+	 * @typedef {Object} sap.ui.dt.OverlayUtil.AggregationBindingInfo
+	 * @property {string} overlayId - ID of the bound overlay that contains binding aggregation template overlays
+	 * @property {string} aggregation - Name of the bound aggregation
+	 * @property {Object[]} stack - Array of objects containing element, element type, aggregation name, and index of the element in
+	 *                              the aggregation for each traversed aggregation
+	 * @property {string} stack.overlayId - Overlay ID of an element overlay
+	 * @property {string} stack.aggregation - Aggregation name
+	 * @property {number} stack.index - Index of the overlay in parent aggregation
+	 */
+
+	/**
+	 * Returns the overlay ID and the aggregation name of the closest bound control for an overlay which is part of an aggregation binding.
+	 * In all cases there is also a stack of element overlays returned that describes the path from the selected / passed overlay up to the
+	 * closest bound control.
+	 * @param  {sap.ui.dt.ElementOverlay} oElementOverlay - Overlay being checked
+	 * @return {AggregationBindingInfo} {@link sap.ui.dt.OverlayUtil.AggregationBindingInfo} object
+	 */
+	 OverlayUtil.getClosestBoundControl = function(oElementOverlay) {
+		return findBoundControl(oElementOverlay, []);
+	};
+
 	return OverlayUtil;
 }, /* bExport= */true);
\ No newline at end of file
