@@ -1,7 +1,7 @@
 
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -20,7 +20,7 @@ sap.ui.define([
 	 *
 	 * @namespace sap.ui.fl.apply._internal.changes.descriptor.app.SetTitle
 	 * @experimental
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @ui5-restricted sap.ui.fl.apply._internal
 	 */
@@ -42,4 +42,4 @@ sap.ui.define([
 	};
 
 	return SetTitle;
-}, true);
\ No newline at end of file
+});
\ No newline at end of file
