@@ -1,37 +1,39 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([
-	"sap/ui/core/util/reflection/JsControlTreeModifier",
-	"sap/ui/fl/Variant",
-	"sap/ui/fl/Change",
-	"sap/ui/fl/Utils",
-	"sap/base/util/ObjectPath",
-	"sap/base/util/includes",
 	"sap/base/util/restricted/_omit",
-	"sap/base/Log",
-	"sap/ui/fl/LayerUtils",
-	"sap/ui/fl/apply/_internal/flexState/FlexState",
 	"sap/base/util/restricted/_pick",
+	"sap/base/util/includes",
+	"sap/base/util/isEmptyObject",
+	"sap/base/util/ObjectPath",
+	"sap/base/Log",
+	"sap/ui/core/util/reflection/JsControlTreeModifier",
 	"sap/ui/fl/apply/_internal/controlVariants/Utils",
-	"sap/base/util/isEmptyObject"
+	"sap/ui/fl/apply/_internal/flexObjects/States",
+	"sap/ui/fl/apply/_internal/flexState/FlexState",
+	"sap/ui/fl/Change",
+	"sap/ui/fl/LayerUtils",
+	"sap/ui/fl/Utils",
+	"sap/ui/fl/Variant"
 ], function(
-	JsControlTreeModifier,
-	Variant,
-	Change,
-	Utils,
-	ObjectPath,
-	includes,
 	_omit,
-	Log,
-	LayerUtils,
-	FlexState,
 	_pick,
+	includes,
+	isEmptyObject,
+	ObjectPath,
+	Log,
+	JsControlTreeModifier,
 	VariantsApplyUtil,
-	isEmptyObject
+	States,
+	FlexState,
+	Change,
+	LayerUtils,
+	Utils,
+	Variant
 ) {
 	"use strict";
 
@@ -41,13 +43,13 @@ sap.ui.define([
 	 * @namespace sap.ui.fl.apply._internal.flexState.controlVariants.VariantManagementState
 	 * @experimental Since 1.74
 	 * @since 1.74
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @ui5-restricted
 	 */
 	var VariantManagementState = {};
 
-	function _getReferencedChanges(mPropertyBag) {
+	function getReferencedChanges(mPropertyBag) {
 		var aReferencedVariantChanges = [];
 		if (mPropertyBag.variantData.content.variantReference) {
 			aReferencedVariantChanges = VariantManagementState.getControlChangesForVariant(Object.assign(
@@ -62,13 +64,13 @@ sap.ui.define([
 		return aReferencedVariantChanges;
 	}
 
-	function _getVariants(mPropertyBag) {
+	function getVariants(mPropertyBag) {
 		var oVariantsMap = VariantManagementState.getContent(mPropertyBag.reference);
 		var aVariants = ObjectPath.get([mPropertyBag.vmReference, "variants"], oVariantsMap);
 		return aVariants || [];
 	}
 
-	function _addChangeContentToVariantMap(oVariantObject, oChangeContent, bAdd) {
+	function addChangeContentToVariantMap(oVariantObject, oChangeContent, bAdd) {
 		var sChangeType = oChangeContent.changeType;
 		if (!oVariantObject) {
 			oVariantObject = {};
@@ -88,13 +90,13 @@ sap.ui.define([
 		});
 	}
 
-	function _addChange(oChangeContent, oFlexObjects) {
-		var sChangeCategory = _getVariantChangeCategory(oChangeContent);
+	function addChange(oChangeContent, oFlexObjects) {
+		var sChangeCategory = getVariantChangeCategory(oChangeContent);
 		oFlexObjects[sChangeCategory].push(oChangeContent);
 	}
 
-	function _deleteChange(oChangeContent, oFlexObjects) {
-		var sChangeCategory = _getVariantChangeCategory(oChangeContent);
+	function deleteChange(oChangeContent, oFlexObjects) {
+		var sChangeCategory = getVariantChangeCategory(oChangeContent);
 		var iChangeContentIndex = -1;
 		oFlexObjects[sChangeCategory].some(function(oExistingChangeContent, iIndex) {
 			if (oExistingChangeContent.fileName === oChangeContent.fileName) {
@@ -107,7 +109,7 @@ sap.ui.define([
 		}
 	}
 
-	function _getVariantChangeCategory(oChangeContent) {
+	function getVariantChangeCategory(oChangeContent) {
 		switch (oChangeContent.fileType) {
 			case "change":
 				return "variantDependentControlChanges";
@@ -125,7 +127,6 @@ sap.ui.define([
 	 * Returns variant management state for the passed component reference.
 	 *
 	 * @param {string} sReference - Component reference
-	 *
 	 * @returns {object} Variant management state
 	 * @private
 	 * @ui5-restricted
@@ -134,18 +135,27 @@ sap.ui.define([
 		return FlexState.getVariantsState(sReference);
 	};
 
+	VariantManagementState.addFakeStandardVariant = function(sReference, sComponentId, oStandardVariant) {
+		FlexState.setFakeStandardVariant(sReference, sComponentId, oStandardVariant);
+	};
+
+	VariantManagementState.clearFakedStandardVariants = function(sReference, sComponentId) {
+		FlexState.resetFakedStandardVariants(sReference, sComponentId);
+	};
+
 	/**
 	 * Resets variant management state
 	 *
 	 * @param {string} sReference - Component reference
+	 * @param {string} sComponentId - Component instance ID
 	 *
 	 * @private
 	 * @ui5-restricted
 	 */
-	VariantManagementState.resetContent = function(sReference) {
+	VariantManagementState.resetContent = function(sReference, sComponentId) {
 		// reset on component destroy() should be handled more centrally
 		// once all maps are prepared in flex state
-		FlexState.clearFilteredResponse(sReference);
+		FlexState.clearFilteredResponse(sReference, sComponentId);
 	};
 
 	/**
@@ -155,6 +165,7 @@ sap.ui.define([
 	 * @param {String} mPropertyBag.vmReference - Variant management reference
 	 * @param {String} mPropertyBag.vReference - ID of the variant
 	 * @param {string} mPropertyBag.reference - Component reference
+	 * @param {boolean} [mPropertyBag.includeDirtyChanges] - Whether dirty changes of the current session should be included, <code>true</code> by default
 	 * @param {boolean} [mPropertyBag.changeInstance] <code>true</code> if each change has to be an instance of <code>sap.ui.fl.Change</code>
 	 *
 	 * @returns {object[]|sap.ui.fl.Change[]} All changes of the variant
@@ -165,17 +176,15 @@ sap.ui.define([
 		var aResult = [];
 		var oVariant = VariantManagementState.getVariant(mPropertyBag);
 		if (oVariant) {
-			aResult = oVariant.controlChanges;
-			if (mPropertyBag.changeInstance) {
-				aResult = aResult.map(function(oChange, index) {
-					var oChangeInstance;
-					if (!oChange.getDefinition) {
-						oChangeInstance = new Change(oChange);
-						oVariant.controlChanges.splice(index, 1, oChangeInstance);
-					} else {
-						oChangeInstance = oChange;
-					}
-					return oChangeInstance;
+			aResult = oVariant.controlChanges.filter(function(oChange) {
+				return (
+					mPropertyBag.includeDirtyChanges !== false
+					|| oChange.getState() === Change.states.PERSISTED
+				);
+			});
+			if (!mPropertyBag.changeInstance) {
+				aResult = aResult.map(function(oChange) {
+					return oChange.getDefinition();
 				});
 			}
 		}
@@ -212,7 +221,7 @@ sap.ui.define([
 		var oVariant;
 		var oVariantsMap = VariantManagementState.getContent(mPropertyBag.reference);
 		mPropertyBag.vReference = mPropertyBag.vReference || oVariantsMap[mPropertyBag.vmReference].defaultVariant;
-		var aVariants = _getVariants(mPropertyBag);
+		var aVariants = getVariants(mPropertyBag);
 		aVariants.some(function(oCurrentVariant) {
 			if (oCurrentVariant.content.fileName === mPropertyBag.vReference) {
 				oVariant = oCurrentVariant;
@@ -255,7 +264,7 @@ sap.ui.define([
 	 * @param {string} mPropertyBag.vmReference - Variant management reference
 	 * @param {string} mPropertyBag.reference - Component reference
 	 *
-	 * @returns {integer} Index at which the variant was added
+	 * @returns {int} Index at which the variant was added
 	 * @private
 	 * @ui5-restricted
 	 */
@@ -266,7 +275,7 @@ sap.ui.define([
 
 		//Set the whole list of changes to the variant
 		if (mPropertyBag.variantData.content.variantReference) {
-			var aReferencedVariantChanges = _getReferencedChanges(mPropertyBag);
+			var aReferencedVariantChanges = getReferencedChanges(mPropertyBag);
 			mPropertyBag.variantData.controlChanges = aReferencedVariantChanges.concat(mPropertyBag.variantData.controlChanges);
 		}
 
@@ -283,7 +292,7 @@ sap.ui.define([
 	 * @param {string} mPropertyBag.vmReference - Variant management reference
 	 * @param {string} mPropertyBag.reference - Component reference
 	 *
-	 * @returns {integer} Index from which the variant was removed
+	 * @returns {int} Index from which the variant was removed
 	 * @private
 	 * @ui5-restricted
 	 */
@@ -311,9 +320,9 @@ sap.ui.define([
 	 * @param {object} mPropertyBag.variantData - Variant data
 	 * @param {string} mPropertyBag.vmReference - Variant management reference
 	 * @param {string} mPropertyBag.reference - Component reference
-	 * @param {integer} mPropertyBag.previousIndex - Previous index of variant object
+	 * @param {int} mPropertyBag.previousIndex - Previous index of variant object
 	 *
-	 * @returns {integer} The updated index for the passed variant data
+	 * @returns {int} The updated index for the passed variant data
 	 * @private
 	 * @ui5-restricted
 	 */
@@ -425,15 +434,14 @@ sap.ui.define([
 				|| !mPropertyBag.vmReference
 			) {
 				var sCurrentVReference = oVariantsMap[sVMReference].currentVariant ? "currentVariant" : "defaultVariant";
-				var mArguments = {
+				var mArguments = Object.assign({}, mPropertyBag, {
 					vmReference: sVMReference,
 					vReference: oVariantsMap[sVMReference][sCurrentVReference],
-					reference: mPropertyBag.reference,
-					changeInstance: mPropertyBag.changeInstance
-				};
+					includeDirtyChanges: false
+				});
 
 				// Concatenate with the previous flex changes
-				return aInitialChanges.concat(VariantManagementState.getControlChangesForVariant(Object.assign({}, mPropertyBag, mArguments)));
+				return aInitialChanges.concat(VariantManagementState.getControlChangesForVariant(mArguments));
 			}
 			return aInitialChanges;
 		}, []);
@@ -462,7 +470,7 @@ sap.ui.define([
 				if (oVariantsMap[sVMReference].currentVariant) {
 					oVariantData[sVMReference].currentVariant = oVariantsMap[sVMReference].currentVariant;
 				}
-				_getVariants(Object.assign(mPropertyBag, {vmReference: sVMReference}))
+				getVariants(Object.assign(mPropertyBag, {vmReference: sVMReference}))
 					.forEach(function(oVariant, index) {
 						oVariantData[sVMReference].variants[index] =
 							//JSON.parse(JSON.stringify()) used to remove undefined properties e.g. standard variant layer
@@ -474,7 +482,8 @@ sap.ui.define([
 									favorite: oVariant.content.content.favorite,
 									executeOnSelect: oVariant.content.content.executeOnSelect,
 									visible: oVariant.content.content.visible,
-									author: ObjectPath.get("content.support.user", oVariant)
+									author: ObjectPath.get("content.support.user", oVariant),
+									contexts: oVariant.content.contexts
 								})
 							);
 					});
@@ -500,11 +509,11 @@ sap.ui.define([
 		if (mPropertyBag.changeContent.fileType === "ctrl_variant_change") {
 			oVariantManagement.variants.some(function(oVariant) {
 				if (oVariant.content.fileName === mPropertyBag.changeContent.selector.id) {
-					_addChangeContentToVariantMap(oVariant.variantChanges, mPropertyBag.changeContent, mPropertyBag.add);
+					addChangeContentToVariantMap(oVariant.variantChanges, mPropertyBag.changeContent, mPropertyBag.add);
 				}
 			});
 		} else if (mPropertyBag.changeContent.fileType === "ctrl_variant_management_change") {
-			_addChangeContentToVariantMap(oVariantManagement.variantManagementChanges, mPropertyBag.changeContent, mPropertyBag.add);
+			addChangeContentToVariantMap(oVariantManagement.variantManagementChanges, mPropertyBag.changeContent, mPropertyBag.add);
 		}
 	};
 
@@ -551,12 +560,12 @@ sap.ui.define([
 		var oFlexObjects = FlexState.getFlexObjectsFromStorageResponse(mPropertyBag.reference);
 
 		if (mPropertyBag.changeToBeAddedOrDeleted) {
-			switch (mPropertyBag.changeToBeAddedOrDeleted.getPendingAction()) {
-				case "NEW":
-					_addChange(mPropertyBag.changeToBeAddedOrDeleted.getDefinition(), oFlexObjects);
+			switch (mPropertyBag.changeToBeAddedOrDeleted.getState()) {
+				case States.NEW:
+					addChange(mPropertyBag.changeToBeAddedOrDeleted.getDefinition(), oFlexObjects);
 					break;
-				case "DELETE":
-					_deleteChange(mPropertyBag.changeToBeAddedOrDeleted.getDefinition(), oFlexObjects);
+				case States.DELETE:
+					deleteChange(mPropertyBag.changeToBeAddedOrDeleted.getDefinition(), oFlexObjects);
 					break;
 				default:
 			}
@@ -579,22 +588,17 @@ sap.ui.define([
 			reference: mPropertyBag.reference,
 			changeInstance: true
 		});
-		var aSelectors = aCurrentVariantChanges.reduce(function(aCurrentSelectors, oChange) {
-			if (Utils.indexOfObject(aCurrentSelectors, oChange.getSelector()) === -1) {
-				aCurrentSelectors.push(oChange.getSelector());
-			}
-			return aCurrentSelectors;
-		}, []);
-		var aControls = [];
-		aSelectors.map(function(oSelector) {
+		var aControls = aCurrentVariantChanges.reduce(function(aCurrentControls, oChange) {
+			var oSelector = oChange.getSelector();
 			var oControl = JsControlTreeModifier.bySelector(oSelector, mPropertyBag.appComponent);
-			if (oControl) {
-				aControls.push(oControl);
+			if (oControl && Utils.indexOfObject(aCurrentControls, {selector: oControl}) === -1) {
+				aCurrentControls.push({selector: oControl});
 			}
-		});
+			return aCurrentControls;
+		}, []);
 
-		return mPropertyBag.flexController.waitForChangesToBeApplied(aControls);
+		return aControls.length ? mPropertyBag.flexController.waitForChangesToBeApplied(aControls) : Promise.resolve();
 	};
 
 	return VariantManagementState;
-}, true);
\ No newline at end of file
+});
\ No newline at end of file
