@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -38,7 +38,7 @@ sap.ui.define([
 	 * @namespace
 	 * @alias sap.ui.fl.descriptorRelated.api.DescriptorInlineChangeFactory
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @deprecated Since version 1.76
 	 * @ui5-restricted sap.ui.rta, smart business
@@ -385,7 +385,7 @@ sap.ui.define([
 	DescriptorInlineChangeFactory.create_app_setTitle = function(mParameters, mTexts) {
 		if (!mTexts) {
 			mTexts = {
-				"" : mParameters //property name = text key set when adding to descriptor variant
+				"": mParameters //property name = text key set when adding to descriptor variant
 			};
 			mParameters = {};
 		}
@@ -412,7 +412,7 @@ sap.ui.define([
 	DescriptorInlineChangeFactory.create_app_setSubTitle = function(mParameters, mTexts) {
 		if (!mTexts) {
 			mTexts = {
-				"" : mParameters //property name = text key set when adding to descriptor variant
+				"": mParameters //property name = text key set when adding to descriptor variant
 			};
 			mParameters = {};
 		}
@@ -440,7 +440,7 @@ sap.ui.define([
 	DescriptorInlineChangeFactory.create_app_setShortTitle = function(mParameters, mTexts) {
 		if (!mTexts) {
 			mTexts = {
-				"" : mParameters //property name = text key set when adding to descriptor variant
+				"": mParameters //property name = text key set when adding to descriptor variant
 			};
 			mParameters = {};
 		}
@@ -468,7 +468,7 @@ sap.ui.define([
 	DescriptorInlineChangeFactory.create_app_setDescription = function(mParameters, mTexts) {
 		if (!mTexts) {
 			mTexts = {
-				"" : mParameters //property name = text key set when adding to descriptor variant
+				"": mParameters //property name = text key set when adding to descriptor variant
 			};
 			mParameters = {};
 		}
@@ -496,7 +496,7 @@ sap.ui.define([
 	DescriptorInlineChangeFactory.create_app_setInfo = function(mParameters, mTexts) {
 		if (!mTexts) {
 			mTexts = {
-				"" : mParameters //property name = text key set when adding to descriptor variant
+				"": mParameters //property name = text key set when adding to descriptor variant
 			};
 			mParameters = {};
 		}
@@ -886,5 +886,22 @@ sap.ui.define([
 		return AppVariantInlineChangeFactory.create_ui5_setFlexExtensionPointEnabled(mPropertyBag);
 	};
 
+	/**
+	 * Creates an inline change of change type <code>appdescr_fiori_setAbstract</code>
+	 *
+	 * @param {object} mParameters - Parameters of the change type
+	 * @param {boolean} mParameters.abstract - Abstract property
+	 *
+	 * @return {Promise} Resolving when the descriptor inline change was created successfully (without back-end access)
+	 *
+	 * @private
+	 * @deprecated Since version 1.78
+	 * @ui5-restricted WebIDE
+	 */
+	 DescriptorInlineChangeFactory.create_fiori_setAbstract = function(mParameters) {
+		var mPropertyBag = _preparePropertyBag("appdescr_fiori_setAbstract", mParameters);
+		return AppVariantInlineChangeFactory.create_fiori_setAbstract(mPropertyBag);
+	};
+
 	return DescriptorInlineChangeFactory;
-}, true);
+});
