@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -16,7 +16,7 @@ sap.ui.define([
 	function _fillTextsFromContent(mPropertyBag) {
 		if (!mPropertyBag.texts) {
 			mPropertyBag.texts = {
-				"" : mPropertyBag.content //property name = text key set when adding to descriptor variant
+				"": mPropertyBag.content //property name = text key set when adding to descriptor variant
 			};
 			mPropertyBag.content = {};
 		}
@@ -33,7 +33,7 @@ sap.ui.define([
 	 * @namespace
 	 * @alias sap.ui.fl.write._internal.appVariant.AppVariantInlineChangeFactory
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @ui5-restricted sap.ui.rta, smart business
 	 */
@@ -744,6 +744,24 @@ sap.ui.define([
 		return _createAppVariantInlineChange(mPropertyBag);
 	};
 
+	/**
+	 * Creates an inline change of change type <code>appdescr_ui5_addComponentUsages</code>.
+	 *
+	 * @param {object} mPropertyBag Parameters of the change type
+	 * @param {string} mPropertyBag.changeType Inline change type of an app variant
+	 * @param {object} mPropertyBag.content Content of an inline change
+	 * @param {object} mPropertyBag.content.componentUsages component usages to be added
+	 *
+	 * @return {Promise} Resolving when creating the app variant inline change was successful (without back end access)
+	 *
+	 * @private
+	 * @ui5-restricted sap.ui.rta
+	 */
+	AppVariantInlineChangeFactory.create_ui5_addComponentUsages = function(mPropertyBag) {
+		Utils.checkParameterAndType(mPropertyBag.content, "componentUsages", "object");
+		return _createAppVariantInlineChange(mPropertyBag);
+	};
+
 	/**
 	 * Creates an inline change of change type <code>appdescr_ui5_setMinUI5Version</code>.
 	 *
@@ -908,5 +926,47 @@ sap.ui.define([
 		return _createAppVariantInlineChange(mPropertyBag);
 	};
 
+	/**
+	 * Creates an inline change of change type <code>appdescr_ui5_changeModel</code>.
+	 *
+	 * @param {object} mPropertyBag - Parameters of the change type
+	 * @param {string} mPropertyBag.changeType - Inline change type of an app variant
+	 * @param {object} mPropertyBag.content - Content of an inline change
+	 * @param {string} mPropertyBag.content.modelId - ID of the data source to be changed
+	 * @param {object|array} mPropertyBag.content.entityPropertyChange - Entity property change or an array of multiple changes
+	 * @param {object} mPropertyBag.content.entityPropertyChange.propertyPath - Property path inside the model (currently chaning settings/* is supported)
+	 * @param {object} mPropertyBag.content.entityPropertyChange.operation - Operation (INSERT, UPDATE, UPSERT, DELETE)
+	 * @param {object} mPropertyBag.content.entityPropertyChange.propertyValue - New property value
+	 *
+	 * @return {Promise} Resolving when creating the app variant inline change was successful (without back end access)
+	 *
+	 * @private
+	 * @ui5-restricted sap.ui.rta, smart business
+	 */
+	 AppVariantInlineChangeFactory.create_ui5_changeModel = function(mPropertyBag) {
+		Utils.checkParameterAndType(mPropertyBag.content, "modelId", "string");
+		Utils.checkEntityPropertyChange(mPropertyBag.content);
+		return _createAppVariantInlineChange(mPropertyBag);
+	};
+
+	/**
+	 * Creates an inline change of change type <code>appdescr_fiori_setAbstract</code>.
+	 *
+	 * @param {object} mPropertyBag - Parameters of the change type
+	 * @param {string} mPropertyBag.changeType - Inline change type of an app variant
+	 * @param {object} mPropertyBag.content - Content of an inline change
+	 * @param {boolean} mPropertyBag.content.abstract - Abstract property to be disabled (only allowd value is <code>false</code>)
+	 *
+	 * @return {Promise} Resolving when the descriptor inline change was created successfully (without back-end access)
+	 *
+	 * @private
+	 * @ui5-restricted WebIDE
+	 */
+	 AppVariantInlineChangeFactory.create_fiori_setAbstract = function(mPropertyBag) {
+		Utils.checkParameterAndType(mPropertyBag.content, "abstract", "boolean");
+		Utils.checkParameterAndType(mPropertyBag, "changeType", "string");
+		return _createAppVariantInlineChange(mPropertyBag);
+	};
+
 	return AppVariantInlineChangeFactory;
-}, true);
\ No newline at end of file
+});
\ No newline at end of file
