@@ -1,6 +1,6 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -45,12 +45,19 @@ sap.ui.define([
 		FLEX_INFO: "/flex/info/",
 		PUBLISH: "/actions/make_changes_transportable/",
 		CHANGES: "/changes/",
+		CONDENSE: "/actions/condense/",
 		VARIANTS: "/variants/",
 		SETTINGS: "/flex/settings",
 		TOKEN: "/actions/getcsrftoken/",
 		APPVARIANTS: "/appdescr_variants/",
 		APPVARIANTS_OVERVIEW: "/app_variant_overview/",
-		UI2PERSONALIZATION: "/ui2personalization/"
+		UI2PERSONALIZATION: "/ui2personalization/",
+		CONTEXTS: "/flex/contexts/",
+		VERSIONS: {
+			GET: "/flex/versions/",
+			ACTIVATE: "/flex/versions/activate/",
+			DISCARD: "/flex/versions/draft/"
+		}
 	};
 
 	/**
@@ -63,8 +70,11 @@ sap.ui.define([
 	 * @param {string} mPropertyBag.url Configured url for the connector
 	 * @param {string} [mPropertyBag.transport] The transport ID
 	 * @param {boolean} [mPropertyBag.isLegacyVariant] Whether the new flex data has file type .variant or not
-	 * @param {boolean} [mPropertyBag.isAppVariant] indicator whether this is an app variant
+	 * @param {boolean} [mPropertyBag.isAppVariant] Indicator whether this is an app variant
+	 * @param {boolean} [mPropertyBag.isContextSharing] Indicator whether this is a request for context sharing
 	 * @param {boolean} [mPropertyBag.skipIam=false] - Indicates whether the default IAM item creation and registration is skipped. This is S4/Hana specific flag passed by only Smart Business
+	 * @param {boolean} [mPropertyBag.isCondensingEnabled] Indicator whether this is a request for condensing
+	 * @param {boolean} [mPropertyBag.parentVersion] Indicates if changes should be written as a draft and on which version the changes should be based on
 	 * @private
 	 * @returns {Promise} Promise resolves as soon as the writing was completed
 	 */
@@ -74,13 +84,20 @@ sap.ui.define([
 			sRoute = ROUTES.VARIANTS;
 		} else if (mPropertyBag.isAppVariant) {
 			sRoute = ROUTES.APPVARIANTS;
+		} else if (mPropertyBag.isContextSharing) {
+			sRoute = ROUTES.CONTEXTS;
+		} else if (mPropertyBag.isCondensingEnabled) {
+			sRoute = ROUTES.CONDENSE;
 		} else {
 			sRoute = ROUTES.CHANGES;
 		}
-		var mParameters = mPropertyBag.transport ? {changelist : mPropertyBag.transport} : {};
+		var mParameters = mPropertyBag.transport ? {changelist: mPropertyBag.transport} : {};
 		if (mPropertyBag.skipIam) {
 			mParameters.skipIam = mPropertyBag.skipIam;
 		}
+		if (mPropertyBag.parentVersion) {
+			mParameters.parentVersion = mPropertyBag.parentVersion;
+		}
 		InitialUtils.addLanguageInfo(mParameters);
 		InitialConnector._addClientInfo(mParameters);
 		//single update --> fileName needs to be in the url
@@ -134,12 +151,18 @@ sap.ui.define([
 		});
 	};
 
+	function renameVersionNumberProperty(oVersion) {
+		oVersion.version = oVersion.versionId;
+		delete oVersion.versionId;
+		return oVersion;
+	}
+
 	/**
 	 * Connector for requesting data from an LRep-based back end.
 	 *
 	 * @namespace sap.ui.fl.write._internal.connectors.LrepConnector
 	 * @since 1.67
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @ui5-restricted sap.ui.fl.write._internal.Storage
 	 */
@@ -155,7 +178,6 @@ sap.ui.define([
 		 * @param {string} mPropertyBag.url Configured url for the connector
 		 * @param {string} mPropertyBag.changelist Transport Id
 		 * @param {sap.ui.fl.Change[]} mPropertyBag.changes Changes of the selected layer and flex reference
-		 * @param {string} [mPropertyBag.appVersion] Version of the application for which the reset takes place
 		 * @param {string} [mPropertyBag.generator] Generator with which the changes were created
 		 * @param {string} [mPropertyBag.selectorIds] Selector IDs of controls for which the reset should filter (comma-separated list)
 		 * @param {string} [mPropertyBag.changeTypes] Change types of the changes which should be reset (comma-separated list)
@@ -186,7 +208,7 @@ sap.ui.define([
 
 			return oTransportSelectionPromise.then(function() {
 				BusyIndicator.show(0); //Re-display the busy indicator in case it was hide by transport selection
-				var aParameters = ["reference", "layer", "appVersion", "changelist", "generator"];
+				var aParameters = ["reference", "layer", "changelist", "generator"];
 				var mParameters = _pick(mPropertyBag, aParameters);
 
 				InitialConnector._addClientInfo(mParameters);
@@ -232,7 +254,6 @@ sap.ui.define([
 		 * @param {string} mPropertyBag.transportDialogSettings.styleClass Style class name to be added in the TransportDialog
 		 * @param {string} mPropertyBag.layer Working layer
 		 * @param {string} mPropertyBag.reference Flex reference of the application
-		 * @param {string} mPropertyBag.appVersion Version of the application for which the reset takes place
 		 * @param {sap.ui.fl.Change[]} mPropertyBag.localChanges Local changes to  be published
 		 * @param {object[]} [mPropertyBag.appVariantDescriptors] An array of app variant descriptors which needs to be transported
 		 * @returns {Promise<string>} Promise that can resolve to the following strings:
@@ -258,30 +279,28 @@ sap.ui.define([
 
 			var oTransportSelection = new TransportSelection();
 			return oTransportSelection.openTransportSelection(null, mPropertyBag.transportDialogSettings.rootControl, mPropertyBag.transportDialogSettings.styleClass)
-				.then(function(oTransportInfo) {
-					if (oTransportSelection.checkTransportInfo(oTransportInfo)) {
-						BusyIndicator.show(0);
-						var oContentParameters = {
-							reference: mPropertyBag.reference,
-							appVersion: mPropertyBag.appVersion,
-							layer: mPropertyBag.layer
-						};
-						return oTransportSelection._prepareChangesForTransport(
-							oTransportInfo,
-							mPropertyBag.localChanges,
-							mPropertyBag.appVariantDescriptors,
-							oContentParameters
-						).then(function() {
-							BusyIndicator.hide();
-							if (oTransportInfo.transport === "ATO_NOTIFICATION") {
-								return oResourceBundle.getText("MSG_ATO_NOTIFICATION");
-							}
-							return oResourceBundle.getText("MSG_TRANSPORT_SUCCESS");
-						});
-					}
-					return "Cancel";
-				})
-				['catch'](fnHandleAllErrors);
+			.then(function(oTransportInfo) {
+				if (oTransportSelection.checkTransportInfo(oTransportInfo)) {
+					BusyIndicator.show(0);
+					var oContentParameters = {
+						reference: mPropertyBag.reference,
+						layer: mPropertyBag.layer
+					};
+					return oTransportSelection._prepareChangesForTransport(
+						oTransportInfo,
+						mPropertyBag.localChanges,
+						mPropertyBag.appVariantDescriptors,
+						oContentParameters
+					).then(function() {
+						BusyIndicator.hide();
+						if (oTransportInfo.transport === "ATO_NOTIFICATION") {
+							return oResourceBundle.getText("MSG_ATO_NOTIFICATION");
+						}
+						return oResourceBundle.getText("MSG_TRANSPORT_SUCCESS");
+					});
+				}
+				return "Cancel";
+			})['catch'](fnHandleAllErrors);
 		},
 
 		/**
@@ -293,11 +312,10 @@ sap.ui.define([
 		 * @param {sap.ui.fl.Layer} mPropertyBag.layer Layer
 		 * @param {string} mPropertyBag.reference Flex reference of the application
 		 * @param {string} mPropertyBag.url Configured url for the connector
-		 * @param {string} [mPropertyBag.appVersion] Version of the application
 		 * @returns {Promise} Promise resolves as soon as flex info has been retrieved
 		 */
 		getFlexInfo: function (mPropertyBag) {
-			var aParameters = ["layer", "appVersion"];
+			var aParameters = ["layer"];
 			var mParameters = _pick(mPropertyBag, aParameters);
 
 			InitialConnector._addClientInfo(mParameters);
@@ -308,6 +326,51 @@ sap.ui.define([
 			});
 		},
 
+		/**
+		 * Gets the variant management context information.
+		 *
+		 * @param {object} mPropertyBag Property bag
+		 * @param {string} mPropertyBag.type Type of context, currently only 'role' is supported
+		 * @param {string} [mPropertyBag.$skip] Offset for paginated request
+		 * @param {string} [mPropertyBag.$filter] Filters full raw data
+		 * @returns {Promise<object>} Promise resolves as soon as context has been retrieved
+		 */
+		getContexts: function (mPropertyBag) {
+			var aParameters = ["type", "$skip", "$filter"];
+			var mParameters = _pick(mPropertyBag, aParameters);
+
+			InitialConnector._addClientInfo(mParameters);
+
+			var sContextsUrl = InitialUtils.getUrl(ROUTES.CONTEXTS, mPropertyBag, mParameters);
+			return InitialUtils.sendRequest(sContextsUrl).then(function (oResult) {
+				return oResult.response;
+			});
+		},
+
+		/**
+		 * Loads the variant management context description in the correct language based on the browser configuration.
+		 *
+		 * @param {object} mPropertyBag Property bag
+		 * @param {string} mPropertyBag.flexObjects Payload for the post request
+		 * @returns {Promise<object>} Promise resolves as soon as context descriptions have been retrieved
+		 */
+		loadContextDescriptions: function (mPropertyBag) {
+			mPropertyBag.method = "POST";
+			mPropertyBag.isContextSharing = true;
+			return _doWrite(mPropertyBag).then(function (oResult) {
+				return oResult.response;
+			});
+		},
+
+		/**
+		 * Check if context sharing is enabled in the backend.
+		 *
+		 * @returns {Promise<boolean>} Promise resolves with true
+		 */
+		isContextSharingEnabled: function () {
+			return Promise.resolve(true);
+		},
+
 		/**
 		 * Called to get the flex features.
 		 *
@@ -328,6 +391,7 @@ sap.ui.define([
 			return InitialUtils.sendRequest(sFeaturesUrl).then(function (oResult) {
 				// ensure that even an enabled back end is not consumed in this version
 				oResult.response.isVersioningEnabled = false;
+				oResult.response.isVariantAdaptationEnabled = !!oResult.response.isPublicLayerAvailable;
 				return oResult.response;
 			});
 		},
@@ -343,11 +407,28 @@ sap.ui.define([
 		 * @param {boolean} [mPropertyBag.isLegacyVariant] Whether the new flex data has file type .variant or not
 		 * @returns {Promise} Promise resolves as soon as the writing was completed
 		 */
-		write:function (mPropertyBag) {
+		write: function (mPropertyBag) {
 			mPropertyBag.method = "POST";
 			return _doWrite(mPropertyBag);
 		},
 
+		/**
+		 * Write flex data into LRep back end; This method is called with a map of condensed changes
+		 * that also condense the stored changes on the backend.
+		 *
+		 * @param {object} mPropertyBag Property bag
+		 * @param {object} mPropertyBag.flexObjects Map of condensed changes
+		 * @param {string} mPropertyBag.url Configured url for the connector
+		 * @param {string} [mPropertyBag.transport] The transport ID
+		 * @param {boolean} [mPropertyBag.isLegacyVariant] Whether the new flex data has file type .variant or not
+		 * @returns {Promise} Promise resolves as soon as the writing was completed
+		 */
+		condense: function (mPropertyBag) {
+			mPropertyBag.method = "POST";
+			mPropertyBag.isCondensingEnabled = true;
+			return _doWrite(mPropertyBag);
+		},
+
 		/**
 		 * Update an existing flex data stored in LRep back end.
 		 *
@@ -404,7 +485,7 @@ sap.ui.define([
 				var sAppVariantManifestUrl = mPropertyBag.appVarUrl;
 				var oRequestOption = WriteUtils.getRequestOptions(
 					InitialConnector,
-					undefined,
+					Utils.getLrepUrl() + ROUTES.TOKEN,
 					undefined,
 					"application/json; charset=utf-8", "json"
 				);
@@ -414,7 +495,7 @@ sap.ui.define([
 				var sAppVariantUrl = InitialUtils.getUrl(ROUTES.APPVARIANTS, mPropertyBag);
 				var oRequestOption = WriteUtils.getRequestOptions(
 					InitialConnector,
-					undefined,
+					Utils.getLrepUrl() + ROUTES.TOKEN,
 					undefined,
 					"application/json; charset=utf-8", "json"
 				);
@@ -536,6 +617,47 @@ sap.ui.define([
 				});
 				return WriteUtils.sendRequest(sUrl, "DELETE");
 			}
+		},
+		versions: {
+			load: function (mPropertyBag) {
+				var oRequestOption = WriteUtils.getRequestOptions(
+					InitialConnector,
+					ROUTES.TOKEN
+				);
+				var mParameters = {};
+				InitialUtils.addLanguageInfo(mParameters);
+				mParameters.limit = mPropertyBag.limit;
+				var sVersionsUrl = InitialUtils.getUrl(ROUTES.VERSIONS.GET, mPropertyBag, mParameters);
+				return WriteUtils.sendRequest(sVersionsUrl, "GET", oRequestOption).then(function (oResult) {
+					return oResult.response.versions.map(function (oVersion) {
+						return renameVersionNumberProperty(oVersion);
+					});
+				});
+			},
+			activate: function (mPropertyBag) {
+				var oRequestOption = WriteUtils.getRequestOptions(
+					InitialConnector,
+					ROUTES.TOKEN,
+					{title: mPropertyBag.title},
+					"application/json; charset=utf-8",
+					"json"
+				);
+				var mParameters = {version: mPropertyBag.version};
+				InitialUtils.addLanguageInfo(mParameters);
+				var sVersionsUrl = InitialUtils.getUrl(ROUTES.VERSIONS.ACTIVATE, mPropertyBag, mParameters);
+				return WriteUtils.sendRequest(sVersionsUrl, "POST", oRequestOption).then(function (oResult) {
+					var oVersion = oResult.response;
+					return renameVersionNumberProperty(oVersion);
+				});
+			},
+			discardDraft: function (mPropertyBag) {
+				var oRequestOption = WriteUtils.getRequestOptions(
+					InitialConnector,
+					ROUTES.TOKEN
+				);
+				var sVersionsUrl = InitialUtils.getUrl(ROUTES.VERSIONS.DISCARD, mPropertyBag);
+				return WriteUtils.sendRequest(sVersionsUrl, "DELETE", oRequestOption);
+			}
 		}
 	});
-}, true);
+});
