@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 sap.ui.define([
@@ -23,11 +23,13 @@ sap.ui.define([
 	"sap/base/util/isPlainObject",
 	"sap/base/util/isEmptyObject",
 	"sap/base/util/restricted/_intersection",
+	"sap/base/util/restricted/_flatten",
 	"sap/base/util/restricted/_mergeWith",
 	"sap/base/util/restricted/_merge",
 	"sap/base/util/restricted/_omit",
 	"sap/base/util/restricted/_union",
 	"sap/base/util/restricted/_isNil",
+	"sap/base/util/restricted/_castArray",
 	"sap/ui/model/json/JSONModel",
 	"sap/base/i18n/ResourceBundle",
 	"sap/base/Log",
@@ -52,11 +54,13 @@ sap.ui.define([
 	isPlainObject,
 	isEmptyObject,
 	_intersection,
+	_flatten,
 	_mergeWith,
 	_merge,
 	_omit,
 	_union,
 	_isNil,
+	_castArray,
 	JSONModel,
 	ResourceBundle,
 	Log,
@@ -65,7 +69,6 @@ sap.ui.define([
 	"use strict";
 
 	var CUSTOM_PROPERTY_PREFIX = "customProperty--";
-	var SET_CONFIG_PROMISE = Promise.resolve();
 
 	/**
 	 * @class
@@ -127,13 +130,14 @@ sap.ui.define([
 	 * @alias sap.ui.integration.designtime.baseEditor.BaseEditor
 	 * @author SAP SE
 	 * @since 1.70.0
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @experimental since 1.70.0
 	 * @ui5-restricted
 	 */
 	var BaseEditor = Control.extend("sap.ui.integration.designtime.baseEditor.BaseEditor", {
 		metadata: {
+			library: "sap.ui.integration",
 			properties: {
 				/**
 				 * JSON to be changed in the editor. Note: If an object is passed as a parameter, it won't be mutated. <code>.getJson()</code> or
@@ -152,7 +156,7 @@ sap.ui.define([
 				 *     config.properties.<key>.path {string} that will be changed, relative to the context. Example: If the context is <code>root</code> and the path is <code>header/name</code>, the <code>json.root.header.name</code> field is to be changed
 				 *     config.properties.<key>.value {string|boolean} (Optional) value of the property. A binding relative to the context (model name) should be used. Example: <code>{context>header/name}</code> will create a binding <code>json.root.header.name</code>
 				 *     config.properties.<key>.tags {array} Strings to categorize the property
-				 *     config.properties.<key>.visible {string|boolean} Should be used as a binding relative to the context to define the conditions under which this property should be changeable, e.g. <code>{= ${context>anotherProperty} === 'someValue'}</code>
+				 *     config.properties.<key>.visible {string|boolean} Should be used as a binding relative to the context to define the conditions under which the editor for this property should be visible, e.g. <code>{= ${context>anotherProperty} === 'someValue'}</code>. Invisible editors won't receive value updates until they are activated again.
 				 *     config.properties.<key>.<other configurations> {any} It is possible to define additional configurations in this namespace. These configurations will be passed to the dedicated property editor. Binding strings relative to context model are supported as well, e.g. <code>{= ${context>someProperty} + ${context>anotherProperty}}</code>
 				 *   config.propertyEditors {Object<string,string>} Defines which property editors should be loaded. Key is the property type and value is the editor module path. Example: <code>propertyEditors: {"string": "sap/ui/integration/designtime/controls/propertyEditors/StringEditor"}</code> defines the module responsible for all properties with the type <code>string</code>
 				 *   config.i18n {string|array} Module path or array of paths for i18n property files. i18n binding, for example, <code>{i18n>key}</code> is available in the <code>/properties<code> section, e.g. for <code>label</code>
@@ -182,11 +186,11 @@ sap.ui.define([
 					defaultValue: "list"
 				}
 			},
-			defaultAggregation : "content",
+			defaultAggregation: "content",
 			aggregations: {
 				content: {
 					type: "sap.ui.core.Control",
-					multiple : true
+					multiple: true
 				}
 			},
 			events: {
@@ -210,19 +214,42 @@ sap.ui.define([
 						}
 					}
 				},
+				/**
+				 * Fired when config has been changed.
+				 */
+				configChange: {
+					parameters: {
+						config: {
+							type: "object"
+						}
+					}
+				},
 				/**
 				 * Fired when all property editors for the given JSON and configuration are created.
 				 * TODO: remove this public event.
 				 */
 				propertyEditorsReady: {
 					parameters: {
-						propertyEditors: {type: "array"}
+						propertyEditors: { type: "array" }
+					}
+				},
+				/**
+				 * Fires when the error state of one of the nested property editors changes
+				 */
+				 validationErrorChange: {
+					parameters: {
+						/**
+						 * Whether there is an error in one of the nested editors
+						 * @since 1.96.0
+						 */
+						hasError: { type: "boolean" }
 					}
 				}
 			}
 		},
 
-		constructor: function() {
+		constructor: function () {
+			this._oSetConfigPromise = Promise.resolve();
 			this._mObservableConfig = {};
 			this._mPropertyEditors = {};
 			this._aCancelHandlers = [];
@@ -244,18 +271,18 @@ sap.ui.define([
 			}, this);
 		},
 
-		renderer: function(oRm, oControl) {
+		renderer: function (oRm, oControl) {
 			var aContent = oControl.getContent();
 
 			oRm.openStart("div", oControl);
 			oRm.openEnd();
 
 			if (aContent.length) {
-				aContent.forEach(function(oChildControl) {
+				aContent.forEach(function (oChildControl) {
 					oRm.renderControl(oChildControl);
 				});
 			} else {
-				oControl.getPropertyEditorsSync().forEach(function(oPropertyEditor) {
+				oControl.getPropertyEditorsSync().forEach(function (oPropertyEditor) {
 					oRm.renderControl(oPropertyEditor);
 				});
 			}
@@ -264,7 +291,7 @@ sap.ui.define([
 		}
 	});
 
-	BaseEditor.prototype.init = function () {};
+	BaseEditor.prototype.init = function () { };
 
 	BaseEditor.prototype.exit = function () {
 		this._reset();
@@ -322,47 +349,72 @@ sap.ui.define([
 		}
 	};
 
+	BaseEditor.prototype.setPreventInitialization = function (bPreventInitialization) {
+		this._bPreventInitialization = bPreventInitialization;
+	};
+
 	BaseEditor.prototype.setConfig = function (oConfig, bIsDefaultConfig) {
 		this._bIsDefaultConfig = bIsDefaultConfig;
 		oConfig = oConfig || {};
-		SET_CONFIG_PROMISE = SET_CONFIG_PROMISE.then(function() {
-			PropertyEditorFactory.deregisterAllTypes();
-			return PropertyEditorFactory.registerTypes(oConfig.propertyEditors || {});
-		})
-			.then(function(mPropertyEditors) {
-				this._initValidators(oConfig.validators || {});
+		this._oSetConfigPromise = this._oSetConfigPromise
+			.then(this._registerPropertyEditorTypes.bind(this, oConfig.propertyEditors))
+			.then(this._setConfig.bind(this, oConfig, bIsDefaultConfig));
 
-				// Backwards compatibility. If no i18n configuration specified, we use default one.
-				var oTarget = {
-					propertyEditors: {},
-					properties: {}
-				};
-				if (!oConfig.i18n) {
-					oTarget.i18n = this.getMetadata().getProperty("config").getDefaultValue().i18n;
-				}
+		return this._oSetConfigPromise;
+	};
 
-				var oNewConfig = mergeConfig(oTarget, oConfig);
+	BaseEditor.prototype._registerPropertyEditorTypes = function (mPropertyEditors) {
+		PropertyEditorFactory.deregisterAllTypes();
+		return PropertyEditorFactory.registerTypes(mPropertyEditors || {});
+	};
 
-				if (this._oSpecificConfig) {
-					// If the provided config is the default config
-					// card specific config should always win
-					oNewConfig = bIsDefaultConfig
-						? this._oSpecificConfig
-						: mergeSpecificConfig(oNewConfig, this._oSpecificConfig, mPropertyEditors);
-				}
+	BaseEditor.prototype._setConfig = function (oConfig, bIsDefaultConfig, mPropertyEditors) {
+		this._initValidators(oConfig.validators || {});
 
+		// Backwards compatibility. If no i18n configuration specified, we use default one.
+		var oTarget = {
+			propertyEditors: {},
+			properties: {}
+		};
 
-				this.setProperty("config", oNewConfig, false);
-				this._initialize();
-			}.bind(this));
-		return SET_CONFIG_PROMISE;
+		var oNewConfig = mergeConfig(oTarget, oConfig);
+
+		if (this._oSpecificConfig) {
+			// If the provided config is the default config
+			// card specific config should always win
+			oNewConfig = bIsDefaultConfig
+				? this._oSpecificConfig
+				: mergeSpecificConfig(oNewConfig, this._oSpecificConfig, mPropertyEditors);
+		}
+
+		// Always include the default i18n file
+		oNewConfig.i18n = _union(
+			oNewConfig.i18n && _castArray(oNewConfig.i18n),
+			this.getMetadata().getProperty("config").getDefaultValue().i18n
+		);
+
+		this.setProperty("config", oNewConfig, false);
+		this.fireConfigChange({
+			config: deepClone(oNewConfig)
+		});
+
+		this.initialize();
 	};
 
 	BaseEditor.prototype.addConfig = function (oConfig, bIsDefaultConfig) {
-		return this.setConfig(
-			mergeConfig(this.getConfig(), oConfig),
-			bIsDefaultConfig
-		);
+		this._bIsDefaultConfig = bIsDefaultConfig;
+
+		this._oSetConfigPromise = this._oSetConfigPromise
+			.then(function () {
+				oConfig = mergeConfig(this.getConfig(), oConfig);
+				return oConfig.propertyEditors;
+			}.bind(this))
+			.then(this._registerPropertyEditorTypes)
+			.then(function (mPropertyEditors) {
+				this._setConfig(oConfig, bIsDefaultConfig, mPropertyEditors);
+			}.bind(this));
+
+		return this._oSetConfigPromise;
 	};
 
 	function mergeConfig(oTarget, oCurrentConfig) {
@@ -372,21 +424,40 @@ sap.ui.define([
 		return oResult;
 	}
 
-	BaseEditor.prototype._addSpecificConfig = function(oSpecificConfig) {
-		return SET_CONFIG_PROMISE.then(function() {
-			this._oSpecificConfig = oSpecificConfig;
+	BaseEditor.prototype._addSpecificConfig = function (oSpecificConfig) {
+		var oCurrentConfig;
+		this._oSetConfigPromise = this._oSetConfigPromise
+			.then(function () {
+				this._oSpecificConfig = oSpecificConfig;
 
-			addMissingPropertyEditors(this.getConfig(), oSpecificConfig);
-			return this.setConfig(this.getConfig(), this._bIsDefaultConfig);
-		}.bind(this));
+				oCurrentConfig = _merge({}, this.getConfig());
+				oCurrentConfig.propertyEditors = addMissingPropertyEditors(oCurrentConfig, oSpecificConfig);
+
+				return oCurrentConfig.propertyEditors;
+			}.bind(this))
+			.then(this._registerPropertyEditorTypes)
+			.then(function (mPropertyEditors) {
+				this._setConfig(oCurrentConfig, this._bIsDefaultConfig, mPropertyEditors);
+			}.bind(this));
+
+		return this._oSetConfigPromise;
 	};
 
 	function addMissingPropertyEditors(oCurrentConfig, oSpecificConfig) {
-		each(oSpecificConfig.propertyEditors, function(sEditorName, sEditorPath) {
-			if (!oCurrentConfig.propertyEditors[sEditorName]) {
-				oCurrentConfig.propertyEditors[sEditorName] = sEditorPath;
-			}
-		});
+		var oPropertyEditors = {};
+		var oCurrentEditors = oCurrentConfig.propertyEditors || {};
+		var oSpecificEditors = oSpecificConfig.propertyEditors || {};
+
+		_union(
+			Object.keys(oCurrentEditors),
+			Object.keys(oSpecificEditors)
+		)
+			.forEach(function (sEditorName) {
+				oPropertyEditors[sEditorName] = oSpecificEditors[sEditorName]
+					|| oCurrentEditors[sEditorName];
+			});
+
+		return oPropertyEditors;
 	}
 
 	function mergeSpecificConfig(oCurrentConfig, oSpecificConfig, mPropertyEditors) {
@@ -403,12 +474,12 @@ sap.ui.define([
 
 		// merge properties
 		oNewConfig.properties = {};
-		each(oCurrentConfig.properties, function(sPropertyName, oProperty) {
+		each(oCurrentConfig.properties, function (sPropertyName, oProperty) {
 			var sEditor = oCurrentConfig.propertyEditors[oProperty.type] && oCurrentConfig.propertyEditors[oProperty.type].split("/").join(".");
 			var oConfigMetadata = sEditor && mPropertyEditors[sEditor].configMetadata;
 
 			if (oConfigMetadata && oSpecificConfig.properties[sPropertyName]) {
-				each(oProperty, function(sKey, vTargetValue) {
+				each(oProperty, function (sKey, vTargetValue) {
 					var vNewValue;
 					var sMergeStrategy = oConfigMetadata[sKey] && oConfigMetadata[sKey].mergeStrategy;
 					if (sMergeStrategy) {
@@ -436,7 +507,7 @@ sap.ui.define([
 	}
 
 	BaseEditor.prototype.setDesigntimeMetadata = function (oDesigntimeMetadata, bIsInitialMetadata) {
-		var oNextMetadata = deepClone(oDesigntimeMetadata);
+		var oNextMetadata = deepClone(oDesigntimeMetadata, 15);
 		if (!deepEqual(oNextMetadata, this.getDesigntimeMetadata())) {
 			this.setProperty("designtimeMetadata", oNextMetadata);
 			this._oDesigntimeMetadataModel.setData(oNextMetadata);
@@ -506,6 +577,12 @@ sap.ui.define([
 		}
 	};
 
+	BaseEditor.prototype.initialize = function () {
+		if (!this._bPreventInitialization) {
+			this._initialize();
+		}
+	};
+
 	BaseEditor.prototype._initialize = function () {
 		this._reset();
 
@@ -641,6 +718,13 @@ sap.ui.define([
 		return oModel;
 	};
 
+	BaseEditor.prototype.getI18nProperty = function (sName, aPlaceholders) {
+		if (this.getModel("i18n")) {
+			return this.getModel("i18n").getResourceBundle().getText(sName, aPlaceholders);
+		}
+		return sName;
+	};
+
 	/**
 	 * Loads i18n bundles.
 	 *
@@ -758,7 +842,7 @@ sap.ui.define([
 						return oPropertyEditor.ready();
 					})
 			)
-			.then(this._checkReady.bind(this))
+				.then(this._checkReady.bind(this))
 		);
 	};
 
@@ -809,12 +893,17 @@ sap.ui.define([
 		}
 
 		// Getting back already resolved config!
-		var vValue = ObjectPath.get(sKey, this._oConfigObserver.getObject()).value;
+		var vValue = ObjectPath.get([sKey], this._oConfigObserver.getObject()).value;
 
 		oPropertyEditor.setValue(vValue);
 		oPropertyEditor.attachValueChange(this._onValueChange, this);
 		oPropertyEditor.attachDesigntimeMetadataChange(this._onDesigntimeMetadataChange, this);
 		oPropertyEditor.attachReady(this._checkReady, this);
+		oPropertyEditor.attachValidationErrorChange(function() {
+			this.fireValidationErrorChange({
+				hasError: this.hasError()
+			});
+		}.bind(this));
 	};
 
 	/**
@@ -850,7 +939,7 @@ sap.ui.define([
 		this._bIsReady = bReadyState;
 		if (bPreviousReadyState !== true && bReadyState === true) {
 			// If the editor was not ready before, fire the ready event
-			this.firePropertyEditorsReady({propertyEditors: this.getPropertyEditorsSync()});
+			this.firePropertyEditorsReady({ propertyEditors: this.getPropertyEditorsSync() });
 		}
 	};
 
@@ -903,6 +992,12 @@ sap.ui.define([
 		}.bind(this));
 	};
 
+	BaseEditor.prototype.hasError = function () {
+		return _flatten(Object.values(this._mPropertyEditors || {})).some(function(oPropertyEditor) {
+			return oPropertyEditor.hasError();
+		});
+	};
+
 	BaseEditor.prototype._createPromise = function (fn) {
 		var mPromise = createPromise(fn);
 		this._aCancelHandlers.push(mPromise.cancel);
@@ -924,7 +1019,7 @@ sap.ui.define([
 	 */
 	BaseEditor.prototype.getPropertyConfigByName = function (sPropertyName) {
 		return _omit(
-			ObjectPath.get(sPropertyName, this._oConfigObserver.getObject()),
+			ObjectPath.get([sPropertyName], this._oConfigObserver.getObject()),
 			"value"
 		);
 	};
@@ -942,9 +1037,9 @@ sap.ui.define([
 				fnResolve();
 			}
 		}.bind(this))
-		.then(function () {
-			return this.getPropertyEditorsByNameSync(sPropertyName);
-		}.bind(this));
+			.then(function () {
+				return this.getPropertyEditorsByNameSync(sPropertyName);
+			}.bind(this));
 	};
 
 	/**
@@ -962,7 +1057,7 @@ sap.ui.define([
 	 * @param {string|string[]} vTag - List of tags
 	 * @returns {Promise<sap.ui.integration.designtime.baseEditor.PropertyEditor[]|sap.ui.integration.designtime.baseEditor.propertyEditor.BasePropertyEditor[]|null>} List of property editors for the specified tags
 	 */
-	BaseEditor.prototype.getPropertyEditorsByTag = function(vTag) {
+	BaseEditor.prototype.getPropertyEditorsByTag = function (vTag) {
 		return new Promise(function (fnResolve) {
 			if (!this._mPropertyEditors || Object.keys(this._mPropertyEditors).length === 0) {
 				this.attachEventOnce("propertyEditorsReady", fnResolve);
@@ -970,9 +1065,9 @@ sap.ui.define([
 				fnResolve();
 			}
 		}.bind(this))
-		.then(function () {
-			return this.getPropertyEditorsByTagSync(vTag);
-		}.bind(this));
+			.then(function () {
+				return this.getPropertyEditorsByTagSync(vTag);
+			}.bind(this));
 	};
 
 	/**
@@ -998,7 +1093,7 @@ sap.ui.define([
 	 * @returns {sap.ui.integration.designtime.baseEditor.PropertyEditor[]|sap.ui.integration.designtime.baseEditor.propertyEditor.BasePropertyEditor[]|null} List of property editors for the specified tags
 	 */
 	BaseEditor.prototype.getPropertyEditorsByTagSync = function (vTag) {
-		return this.getPropertyEditorsSync().filter(function(oPropertyEditor) {
+		return this.getPropertyEditorsSync().filter(function (oPropertyEditor) {
 			return hasTag(oPropertyEditor.getConfig(), vTag);
 		});
 	};
