@@ -1,11 +1,17 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 sap.ui.define(function () {
 	"use strict";
 
+	function loadCardEditor() {
+		return new Promise(function (fnResolve, fnReject) {
+			sap.ui.require(["sap/ui/integration/designtime/cardEditor/BASEditor"], fnResolve, fnReject);
+		});
+	}
+
 	/**
 	 * Loads Card Editor preload bundle
 	 *
@@ -24,10 +30,8 @@ sap.ui.define(function () {
 	 * @public
 	 */
 	return function () {
-		return sap.ui.loader._.loadJSResourceAsync("sap-ui-integration-cardEditor.js").then(function () {
-			return new Promise(function (fnResolve, fnReject) {
-				sap.ui.require(["sap/ui/integration/designtime/cardEditor/CardEditor"], fnResolve, fnReject);
-			});
-		});
+		return sap.ui.loader._.loadJSResourceAsync("sap-ui-integration-cardEditor.js")
+			.then(loadCardEditor)
+			.catch(loadCardEditor);
 	};
 });
\ No newline at end of file
