@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 sap.ui.define([
@@ -31,17 +31,17 @@ sap.ui.define([
 
 		/**
 		 *
-		 * @class JSON based Model for sap.ui.mdc.FilterField controls. The model stores the entered values as condition objects.
+		 * @class JSON based Model for {@link sap.ui.mdc.FilterField FilterField} controls. The model stores the entered values as {@link sap.ui.mdc.condition.ConditionObject ConditionObjects}.
 		 * @extends sap.ui.model.json.JSONModel
 		 *
 		 * @author SAP SE
-		 * @version 1.82.2
+		 * @version 1.98.0
 		 * @since 1.48.0
 		 * @alias sap.ui.mdc.condition.ConditionModel
 		 *
 		 * @private
-		 * @experimental
-		 * @ui5-restricted
+		 * @ui5-restricted sap.ui.mdc
+		 * @experimental As of version 1.48
 		 */
 		var ConditionModel = JSONModel.extend("sap.ui.mdc.condition.ConditionModel", {
 			constructor: function () {
@@ -99,10 +99,11 @@ sap.ui.define([
 
 
 		/**
-		 * creates a clone of the ConditionModel which contains the conditions for the sFieldPath
+		 * creates a clone of the <code>ConditionModel</code> which contains the conditions for the <code>sFieldPath</code> parameter
 		 * @param {string} sFieldPath specifies which conditions should be copied into the clone. If not specified all conditions will be copied.
-		 * @returns {sap.ui.mdc.condition.ConditionModel} instance of new ConditionModel
-		 * @public
+		 * @returns {sap.ui.mdc.condition.ConditionModel} instance of new <code>ConditionModel</code>
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.clone = function (sFieldPath) {
 			var oCM = new ConditionModel();
@@ -129,11 +130,12 @@ sap.ui.define([
 		};
 
 		/**
-		 * merge conditions from the source conditionModel into this instance
-		 * @param {string} sFieldPath specifies which conditions should be removed and replaced by the conditions from the source ConditionModel
-		 * @param {sap.ui.mdc.condition.ConditionModel} oSourceConditionModel source ConditionModel.
+		 * merge conditions from the source <code>ConditionModel</code> into this instance
+		 * @param {string} sFieldPath specifies which conditions should be removed and replaced by the conditions from the source <code>ConditionModel</code>
+		 * @param {sap.ui.mdc.condition.ConditionModel} oSourceConditionModel source <code>ConditionModel</code>.
 		 * @param {string} sSourceFieldPath specifies which conditions from the source should be merged.
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.merge = function (sFieldPath, oSourceConditionModel, sSourceFieldPath) {
 			this.removeAllConditions(sFieldPath);
@@ -154,11 +156,12 @@ sap.ui.define([
 
 
 		/**
-		 * Returns conditions for a specified FieldPath.
+		 * Returns conditions for a specified <codeFieldPath</code>.
 		 *
 		 * @param {string} sFieldPath fieldPath of the condition
-		 * @returns {object[]} array of conditions
-		 * @public
+		 * @returns {sap.ui.mdc.condition.ConditionObject[]} array of conditions
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.getConditions = function (sFieldPath) {
 			//TODO: only works for simple flat condition model content
@@ -188,7 +191,8 @@ sap.ui.define([
 		 *
 		 * @param {string|string[]} vFieldPath fieldPath for that conditions are requested
 		 * @returns {object} object with array of conditions for each FieldPath
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.getAllConditions = function (vFieldPath) {
 
@@ -212,21 +216,24 @@ sap.ui.define([
 		};
 
 		/**
-		 * Determines the index of a condition for a specified FieldPath.
+		 * Determines the index of a condition for a specified <code>FieldPath</code>.
 		 *
 		 * @param {string} sFieldPath fieldPath of the condition
-		 * @param {object} oCondition condition to be searched
-		 * @returns {object} index of condition (-1 if not found)
-		 * @public
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition condition to be searched
+		 * @param {function(Object): Object} [fnNormalizeCondition] normalization method for condition comparison
+		 * @returns {int} index of condition (-1 if not found)
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
-		ConditionModel.prototype.indexOf = function (sFieldPath, oCondition) {
+		ConditionModel.prototype.indexOf = function (sFieldPath, oCondition, fnNormalizeCondition) {
 
 			if (typeof sFieldPath !== "string") {
 				throw new Error("sFieldPath must be a string " + this);
 			}
 
 			var aConditions = this.getConditions(sFieldPath);
-			var iIndex = FilterOperatorUtil.indexOfCondition(oCondition, aConditions);
+			var aArgs = fnNormalizeCondition ? [fnNormalizeCondition(oCondition), aConditions.map(fnNormalizeCondition)] : [oCondition, aConditions];
+			var iIndex = FilterOperatorUtil.indexOfCondition.apply(FilterOperatorUtil, aArgs);
 			return iIndex;
 
 		};
@@ -240,11 +247,12 @@ sap.ui.define([
 		};
 
 		/**
-		 * Sets conditions. All already existing conditions will be removed
+		 * Sets conditions. All already existing conditions will be removed.
 		 *
 		 * @param {object} oConditions object of conditions for corresponding fieldPaths
-		 * @returns {sap.ui.mdc.condition.ConditionModel} Reference to <code>this</code> to allow method chaining.
-		 * @public
+		 * @returns {this} Reference to <code>this</code> to allow method chaining.
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.setConditions = function (oConditions) {
 
@@ -274,13 +282,14 @@ sap.ui.define([
 		};
 
 		/**
-		 * Adds a condition for a specified FieldPath.
+		 * Adds a condition for a specified <code>FieldPath</code>.
 		 *
 		 * @param {string} sFieldPath fieldPath of the condition
-		 * @param {object} oCondition condition to be added
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition condition to be added
 		 * @param {boolean} bForce if set the condition will be added even if it already exist
-		 * @returns {sap.ui.mdc.condition.ConditionModel} Reference to <code>this</code> to allow method chaining.
-		 * @public
+		 * @returns {this} Reference to <code>this</code> to allow method chaining.
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.addCondition = function (sFieldPath, oCondition, bForce) {
 
@@ -292,14 +301,15 @@ sap.ui.define([
 		};
 
 		/**
-		 * Inserts a condition for a specified FieldPath.
+		 * Inserts a condition for a specified <code>FieldPath</code>.
 		 *
 		 * @param {string} sFieldPath fieldPath of the condition
 		 * @param {int} iIndex index where the condition should be inserted
-		 * @param {object} oCondition condition to be inserted
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition condition to be inserted
 		 * @param {boolean} bForce if set the condition will be inserted even if it already exist
-		 * @returns {sap.ui.mdc.condition.ConditionModel} Reference to <code>this</code> to allow method chaining.
-		 * @public
+		 * @returns {this} Reference to <code>this</code> to allow method chaining.
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.insertCondition = function (sFieldPath, iIndex, oCondition, bForce) {
 
@@ -341,13 +351,14 @@ sap.ui.define([
 		};
 
 		/**
-		 * creates a condition instance for the Item condition
+		 * creates a condition instance for the item-condition
 		 *
-		 * @param {string} sFieldPath the fieldPath name of the condition
+		 * @param {string} sFieldPath the <code>FieldPath</code> name of the condition
 		 * @param {string} sKey the operator for the condition
 		 * @param {string} sDescription the description of the operator
-		 * @returns {object} the new condition object with the given fieldPath, the operator EQ and the sKey and sDescription as aValues.
-		 * @public
+		 * @returns {sap.ui.mdc.condition.ConditionObject} the new condition object with the given fieldPath, the operator EQ and the sKey and sDescription as aValues.
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 * @deprecated use the sap.ui.mdc.condition.Condition.createItemCondition
 		 */
 		ConditionModel.prototype.createItemCondition = function (sFieldPath, sKey, sDescription) {
@@ -356,13 +367,14 @@ sap.ui.define([
 		};
 
 		/**
-		 * creates a condition instance for the condition model
+		 * creates a condition instance
 		 *
-		 * @param {string} sFieldPath the fieldPath name of the condition
+		 * @param {string} sFieldPath the <code>FieldPath</code> name of the condition
 		 * @param {string} sOperator the operator for the condition
 		 * @param {any[]} aValues the array of values for the condition
-		 * @returns {object} the new condition object with the given fieldPath, operator and values.
-		 * @public
+		 * @returns {sap.ui.mdc.condition.ConditionObject} the new condition object with the given fieldPath, operator and values.
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 * @deprecated use the sap.ui.mdc.condition.Condition.createCondition
 		 */
 		ConditionModel.prototype.createCondition = function (sFieldPath, sOperator, aValues) {
@@ -371,12 +383,13 @@ sap.ui.define([
 		};
 
 		/**
-		 * Removes a condition for a specified FieldPath.
+		 * Removes a condition for a specified <code>FieldPath</code>.
 		 *
 		 * @param {string} sFieldPath fieldPath of the condition
-		 * @param {int | object} vCondition condition or index of the condition
+		 * @param {int|{sap.ui.mdc.condition.ConditionObject} vCondition condition or index of the condition
 		 * @returns {boolean} flag if condition was removed.
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.removeCondition = function (sFieldPath, vCondition) {
 
@@ -407,11 +420,12 @@ sap.ui.define([
 		};
 
 		/**
-		 * Removes all conditions for a specified FieldPath.
+		 * Removes all conditions for a specified <code>FieldPath</code>.
 		 *
 		 * @param {string} sFieldPath fieldPath of the condition
-		 * @returns {sap.ui.mdc.condition.ConditionModel} Reference to <code>this</code> to allow method chaining.
-		 * @public
+		 * @returns {this} Reference to <code>this</code> to allow method chaining.
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		ConditionModel.prototype.removeAllConditions = function (sFieldPath) {
 
@@ -668,4 +682,4 @@ sap.ui.define([
 		}
 
 		return ConditionModel;
-		});
+	});
