@@ -1,6 +1,6 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -9,8 +9,8 @@
 // ---------------------------------------------------------------------------------------
 // ---------------------------------------------------------------------------------------
 sap.ui.define([
-	'./ODataMetaModelUtil', 'sap/ui/mdc/enum/FieldDisplay', "sap/ui/fl/Utils", "sap/ui/mdc/FilterBarDelegate", 'sap/base/util/ObjectPath', 'sap/base/util/merge', 'sap/ui/mdc/odata/v4/TypeUtil', 'sap/ui/mdc/condition/FilterOperatorUtil', "sap/ui/model/FilterOperator", "sap/ui/model/Filter", 'sap/ui/mdc/util/IdentifierUtil', 'sap/ui/core/util/reflection/JsControlTreeModifier'
-	], function (ODataMetaModelUtil, FieldDisplay, FlUtils, FilterBarDelegate, ObjectPath, merge, TypeUtil, FilterOperatorUtil, ModelOperator, Filter, IdentifierUtil, JsControlTreeModifier) {
+	'./ODataMetaModelUtil', 'sap/ui/mdc/enum/FieldDisplay', "sap/ui/fl/Utils", "sap/ui/mdc/FilterBarDelegate", 'sap/base/util/ObjectPath', 'sap/base/util/merge', 'sap/ui/mdc/odata/v4/TypeUtil', 'sap/ui/mdc/condition/FilterOperatorUtil', "sap/ui/model/FilterOperator", "sap/ui/model/Filter", 'sap/ui/mdc/util/IdentifierUtil', 'sap/ui/core/util/reflection/JsControlTreeModifier', 'sap/base/Log'
+	], function (ODataMetaModelUtil, FieldDisplay, FlUtils, FilterBarDelegate, ObjectPath, merge, TypeUtil, FilterOperatorUtil, ModelOperator, Filter, IdentifierUtil, JsControlTreeModifier, Log) {
 	"use strict";
 
 	/**
@@ -48,47 +48,52 @@ sap.ui.define([
 
 
 
-	ODataFilterBarDelegate._fetchPropertiesByMetadata = function(oFilterBar, mPropertyBag) {
+	ODataFilterBarDelegate._fetchPropertiesByMetadata = function(oControl, mPropertyBag) {
 
 		var oDelegate, sModelName, sCollectionName, oModel, sFilterBarId;
 
-		if (mPropertyBag) {
-			var oModifier = mPropertyBag.modifier;
+		return Promise.resolve()
+			.then(function() {
+				if (mPropertyBag) {
+					var oModifier = mPropertyBag.modifier;
 
-			oDelegate = oModifier.getProperty(oFilterBar, "delegate");
-			sModelName =  oDelegate.payload.modelName === null ? undefined : oDelegate.payload.modelName;
-			sCollectionName = oDelegate.payload.collectionName;
-			oModel = mPropertyBag.appComponent.getModel(sModelName);
-		} else {
-
-			oDelegate = oFilterBar.getProperty("delegate");
-			sModelName =  oDelegate.payload.modelName === null ? undefined : oDelegate.payload.modelName;
-			sCollectionName = oDelegate.payload.collectionName;
-			oModel = oFilterBar.getModel(sModelName);
-		}
-
-		sFilterBarId = oFilterBar.getId ? oFilterBar.getId() :  oFilterBar.id;
-
-		var oObj = {
-				getDelegate: function() {
-					return {
-						payload : {
-							modelName : sModelName,
-							collectionName: sCollectionName
-						}
-					};
-				},
-
-				getModel : function (s) {
-					return oModel;
-				},
-
-				getId : function() {
-					return sFilterBarId;
+					return Promise.resolve()
+						.then(oModifier.getProperty.bind(oModifier, oControl, "delegate"))
+						.then(function(oDelegate) {
+							sModelName =  oDelegate.payload.modelName === null ? undefined : oDelegate.payload.modelName;
+							sCollectionName = oDelegate.payload.collectionName;
+							oModel = mPropertyBag.appComponent.getModel(sModelName);
+						});
 				}
-		};
+				oDelegate = oControl.getProperty("delegate");
+				sModelName =  oDelegate.payload.modelName === null ? undefined : oDelegate.payload.modelName;
+				sCollectionName = oDelegate.payload.collectionName;
+				oModel = oControl.getModel(sModelName);
+			})
+			.then(function() {
+				sFilterBarId = oControl.getId ? oControl.getId() :  oControl.id;
 
-		return this.fetchProperties(oObj);
+				var oObj = {
+						getDelegate: function() {
+							return {
+								payload : {
+									modelName : sModelName,
+									collectionName: sCollectionName
+								}
+							};
+						},
+
+						getModel : function (s) {
+							return oModel;
+						},
+
+						getId : function() {
+							return sFilterBarId;
+						}
+				};
+
+				return mPropertyBag ? this.fetchProperties(oObj) : oControl.getControlDelegate().fetchProperties(oControl);
+			}.bind(this));
 	};
 
 	ODataFilterBarDelegate._ensureSingleRangeEQOperators = function() {
@@ -157,7 +162,7 @@ sap.ui.define([
 	ODataFilterBarDelegate._createFilterField = function(oProperty, oFilterBar, mPropertyBag) {
 		var oModifier = mPropertyBag ? mPropertyBag.modifier : JsControlTreeModifier;
 		var oAppComponent = mPropertyBag ? mPropertyBag.appComponent : FlUtils.getAppComponentForControl(oFilterBar);
-		var oView = mPropertyBag ? mPropertyBag.view : FlUtils.getViewForControl(oFilterBar);
+		var oView = (mPropertyBag && mPropertyBag.view ) ? mPropertyBag.view : FlUtils.getViewForControl(oFilterBar);
 		var sViewId = mPropertyBag ? mPropertyBag.viewId : null;
 		var sName = oProperty.path || oProperty.name;
 		var oSelector = {};
@@ -178,50 +183,51 @@ sap.ui.define([
 			return Promise.resolve(oExistingFilterField);
 		}
 
-		return oModifier.createControl("sap.ui.mdc.FilterField", oAppComponent, oView, sId, {
-			dataType: oProperty.typeConfig.className,
-			conditions: "{$filters>/conditions/" + sName + '}',
-			required: oProperty.required,
-			label: oProperty.label || oProperty.name,
-			maxConditions: oProperty.maxConditions,
-			delegate: {name: "sap/ui/mdc/odata/v4/FieldBaseDelegate", payload: {}}
-		}, true).then(function(oFilterField) {
-			if (oProperty.fieldHelp) {
+		return Promise.resolve()
+			.then(oModifier.createControl.bind(oModifier, "sap.ui.mdc.FilterField", oAppComponent, oView, sId, {
+				dataType: oProperty.typeConfig.className,
+				conditions: "{$filters>/conditions/" + sName + '}',
+				required: oProperty.required,
+				label: oProperty.label || oProperty.name,
+				maxConditions: oProperty.maxConditions,
+				delegate: {name: "sap/ui/mdc/odata/v4/FieldBaseDelegate", payload: {}}
+			})).then(function(oFilterField) {
+				if (oProperty.fieldHelp) {
 
-				var sFieldHelp = oProperty.fieldHelp;
-				if (!sViewId) { // viewId is only set during xmlTree processing
-					sFieldHelp = oView.createId(oProperty.fieldHelp);
-				} else {
-					sFieldHelp = sViewId + "--" + oProperty.fieldHelp;
+					var sFieldHelp = oProperty.fieldHelp;
+					if (!sViewId) { // viewId is only set during xmlTree processing
+						sFieldHelp = oView.createId(oProperty.fieldHelp);
+					} else {
+						sFieldHelp = sViewId + "--" + oProperty.fieldHelp;
+					}
+					oModifier.setAssociation(oFilterField, "fieldHelp", sFieldHelp);
 				}
-				oModifier.setAssociation(oFilterField, "fieldHelp", sFieldHelp);
-			}
 
-			if (oProperty.filterOperators) {
-				if (oFilterBar.getId) {
-					oModifier.setProperty(oFilterField, "operators", oProperty.filterOperators);
-				} else {
-					oModifier.setProperty(oFilterField, "operators", oProperty.filterOperators.join(','));
+				if (oProperty.filterOperators) {
+					if (oFilterBar.getId) {
+						oModifier.setProperty(oFilterField, "operators", oProperty.filterOperators);
+					} else {
+						oModifier.setProperty(oFilterField, "operators", oProperty.filterOperators.join(','));
+					}
 				}
-			}
 
-			if (oProperty.tooltip) {
-				oModifier.setProperty(oFilterField, "tooltip", oProperty.tooltip);
-			}
+				if (oProperty.tooltip) {
+					oModifier.setProperty(oFilterField, "tooltip", oProperty.tooltip);
+				}
 
-			if (oProperty.constraints) {
-				oModifier.setProperty(oFilterField, "dataTypeConstraints", oProperty.constraints);
-			}
+				if (oProperty.constraints) {
+					oModifier.setProperty(oFilterField, "dataTypeConstraints", oProperty.constraints);
+				}
 
-			if (oProperty.formatOptions) {
-				oModifier.setProperty(oFilterField, "dataTypeFormatOptions", oProperty.formatOptions);
-			}
+				if (oProperty.formatOptions) {
+					oModifier.setProperty(oFilterField, "dataTypeFormatOptions", oProperty.formatOptions);
+				}
 
-			if (oProperty.display) {
-				oModifier.setProperty(oFilterField, "display", oProperty.display);
-			}
-			return oFilterField;
-		});
+				if (oProperty.display) {
+					oModifier.setProperty(oFilterField, "display", oProperty.display);
+				}
+				return oFilterField;
+			});
 	};
 
 	ODataFilterBarDelegate._createFilter = function(sPropertyName, oFilterBar, mPropertyBag) {
@@ -295,6 +301,10 @@ sap.ui.define([
 			}
 		}
 
+		var bIsUpperCase = false;
+		if (oMetaModel.getObject(sEntitySetPath + "/" + sKey + "@com.sap.vocabularies.Common.v1.IsUpperCase")) {
+			bIsUpperCase = true;
+		}
 
 		var sLabel = oMetaModel.getObject(sEntitySetPath + "/" + sKey + "@com.sap.vocabularies.Common.v1.Label") || sKey;
 		var sTooltip = oMetaModel.getObject(sEntitySetPath + "/" + sKey + "@com.sap.vocabularies.Common.v1.QuickInfo") || null;
@@ -337,28 +347,26 @@ sap.ui.define([
 				name: sKey,
 				label: sLabel,
 				tooltip: sTooltip,
-				hiddenFilter: bHiddenFilter
+				hiddenFilter: bHiddenFilter,
+				caseSensitive: !bIsUpperCase
 		};
 
 		if (sDisplay) {
 			oProperty.display = sDisplay;
 		}
 
-		if (oObj.$Type === "Edm.DateTimeOffset") {
-			if (!oConstraints) {
-				oConstraints = {};
-			}
+		// if (oObj.$Type === "Edm.DateTimeOffset") {
+		// 	if (!oConstraints) {
+		// 		oConstraints = {};
+		// 	}
 
-			oConstraints.V4 = true;
-		}
+		// 	oConstraints.V4 = true;
+		// }
 
 		if (oConstraints) {
 			oProperty.constraints = oConstraints;
 		}
 
-		//TODO: what should be considered for format options ???
-		//oProperty.formatOptions = ;
-
 		if (oFilterDefaultValue) {
 			oProperty.defaultFilterConditions = [{ fieldPath: sKey, operator: "EQ", values: [oFilterDefaultValue] }];
 		}
@@ -463,6 +471,16 @@ sap.ui.define([
 						if (oMetaModel.getObject(sEntitySetPath + "/" + sKey + "@com.sap.vocabularies.UI.v1.Hidden")) {
 							continue;
 						}
+
+						// ignore (as for now) all complex properties
+						// not clear if they might be nesting (complex in complex)
+						// not clear how they are represented in non-filterable annotation
+						// etc.
+						if (oObj.$isCollection) {
+							Log.warning("Complex property with type " + oObj.$Type + " has been ignored");
+							continue;
+						}
+
 						oPropertyInfo = ODataFilterBarDelegate._fetchPropertyInfo(oMetaModel, sEntitySetPath, sNavigationPropertyName, oObj, sKey, oParameterInfo);
 						if (oPropertyInfo) {
 							oPropertyInfo.group = sGroup;
@@ -507,37 +525,36 @@ sap.ui.define([
 	};
 
 
-	ODataFilterBarDelegate._setModel = function () {
-		var sModelName = this.getPayload().modelName;
-		sModelName = sModelName === null ? undefined : sModelName;
-		var oModel = this.getModel(sModelName);
-		if (oModel) {
-			this.detachModelContextChange(ODataFilterBarDelegate._setModel, this);
-			ODataFilterBarDelegate._fModelProvided(oModel);
-		}
-	};
-
 	ODataFilterBarDelegate._waitForMetaModel = function (oFilterBar, sPassedModelName) {
 
 		return new Promise(function(resolve, reject) {
-			var sModelName = sPassedModelName === null ? undefined : sPassedModelName;
 
-			var oModel = oFilterBar.getModel(sModelName);
-			if (oModel) {
-				resolve(oModel);
+			var resolveMetaModel = function () {
+				var sModelName = sPassedModelName === null ? undefined : sPassedModelName;
+				var oModel = oFilterBar.getModel(sModelName);
+				if (oModel) {
+					resolve(oModel);
+				}
+				return oModel;
+			};
+
+			var handleContextChange = function () {
+				if (resolveMetaModel()) {
+					oFilterBar.detachModelContextChange(handleContextChange);
+				}
+			};
+
+			if (!resolveMetaModel()) {
+				if (!oFilterBar.attachModelContextChange) {
+					reject();
+					return;
+				}
+				oFilterBar.attachModelContextChange(handleContextChange);
 			}
-
-			if (!oFilterBar.attachModelContextChange) {
-				reject();
-			}
-
-			ODataFilterBarDelegate._fModelProvided = resolve;
-
-			oFilterBar.attachModelContextChange(ODataFilterBarDelegate._setModel, oFilterBar);
-
 		});
 	};
 
+
 	/**
 	 * Fetches the relevant metadata for a given payload and returns property info array.
 	 * @param {object} oFilterBar - the instance of filter bar
@@ -596,6 +613,15 @@ sap.ui.define([
 								});
 							}
 
+							var mProperties = aProperties.reduce(function(mMap, oProp){
+								mMap[oProp.name] = oProp;
+								return mMap;
+							}, {});
+
+							aProperties = Object.keys(mProperties).map(function(sName) {
+								return mProperties[sName];
+							});
+
 							mMainEntitySet[sCachKey] = aProperties;
 							resolve(aProperties);
 						});
