@@ -1,16 +1,16 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 // Provides basic internal functions for sap.ui.model.odata.AnnotationHelper
 sap.ui.define([
 	"sap/base/Log",
+	"sap/base/util/extend",
 	"sap/ui/base/BindingParser",
-	"sap/ui/performance/Measurement",
-	"sap/ui/thirdparty/jquery"
-], function (Log, BindingParser, Measurement, jQuery) {
+	"sap/ui/performance/Measurement"
+], function (Log, extend, BindingParser, Measurement) {
 	'use strict';
 
 	var sAnnotationHelper = "sap.ui.model.odata.AnnotationHelper",
@@ -68,7 +68,7 @@ sap.ui.define([
 		 *   if the result is not of the expected type
 		 */
 		descend : function (oPathValue, vProperty, vExpectedType) {
-			var oTarget = jQuery.extend({}, oPathValue);
+			var oTarget = extend({}, oPathValue);
 
 			Basics.expectType(oPathValue, typeof vProperty === "number" ? "array" : "object");
 			oTarget.path = oPathValue.path + "/" + vProperty;
@@ -118,6 +118,7 @@ sap.ui.define([
 			if (sExpectedType === "array") {
 				bError = !Array.isArray(vValue);
 			} else {
+				// eslint-disable-next-line valid-typeof
 				bError = typeof vValue !== sExpectedType
 					|| vValue === null
 					|| Array.isArray(vValue);
@@ -184,36 +185,38 @@ sap.ui.define([
 			}
 			aParts = sPath.split("/");
 
-			while (sPath && aParts.length && sContextPath) {
-				sSegment = aParts[0];
-				iIndexOfAt = sSegment.indexOf("@");
-				if (iIndexOfAt === 0) {
-					// term cast
-					sContextPath += "/" + sSegment.slice(1);
-					aParts.shift();
-					continue;
-//				} else if (iIndexOfAt > 0) { // annotation of a navigation property
-//					sSegment = sSegment.slice(0, iIndexOfAt);
-				}
-
-				oType = oModel.getObject(sContextPath);
-				oAssociationEnd = oModel.getODataAssociationEnd(oType, sSegment);
-				if (oAssociationEnd) {
-					// navigation property
-					oResult.associationSetEnd
-						= oModel.getODataAssociationSetEnd(oType, sSegment);
-					oResult.navigationProperties.push(sSegment);
-					if (oResult.isMultiple) {
-						oResult.navigationAfterMultiple = true;
+			if (sPath) {
+				while (aParts.length && sContextPath) {
+					sSegment = aParts[0];
+					iIndexOfAt = sSegment.indexOf("@");
+					if (iIndexOfAt === 0) {
+						// term cast
+						sContextPath += "/" + sSegment.slice(1);
+						aParts.shift();
+						continue;
+//					} else if (iIndexOfAt > 0) { // annotation of a navigation property
+//						sSegment = sSegment.slice(0, iIndexOfAt);
 					}
-					oResult.isMultiple = oAssociationEnd.multiplicity === "*";
-					sContextPath = oModel.getODataEntityType(oAssociationEnd.type, true);
-					aParts.shift();
-					continue;
-				}
 
-				// structural properties or some unsupported case
-				sContextPath = oModel.getODataProperty(oType, aParts, true);
+					oType = oModel.getObject(sContextPath);
+					oAssociationEnd = oModel.getODataAssociationEnd(oType, sSegment);
+					if (oAssociationEnd) {
+						// navigation property
+						oResult.associationSetEnd
+							= oModel.getODataAssociationSetEnd(oType, sSegment);
+						oResult.navigationProperties.push(sSegment);
+						if (oResult.isMultiple) {
+							oResult.navigationAfterMultiple = true;
+						}
+						oResult.isMultiple = oAssociationEnd.multiplicity === "*";
+						sContextPath = oModel.getODataEntityType(oAssociationEnd.type, true);
+						aParts.shift();
+						continue;
+					}
+
+					// structural properties or some unsupported case
+					sContextPath = oModel.getODataProperty(oType, aParts, true);
+				}
 			}
 
 			oResult.resolvedPath = sContextPath;
@@ -326,18 +329,21 @@ sap.ui.define([
 		 *   formatOptions: {object} optional type format options when result is "binding"
 		 *   parameters: {object} optional binding parameters when result is "binding"
 		 * @param {boolean} bExpression
-		 *   if true the value is to be embedded into a binding expression, otherwise in a
-		 *   composite binding
+		 *   if <code>true</code> the value is to be embedded into a binding expression,
+		 *   otherwise in a composite binding
 		 * @param {boolean} [bWithType=false]
-		 *  if this is <code>true</code>, <code>oResult.result</code> is "binding" and
-		 *  <code>oResult.type</code> maps to a UI5 type, then both type and constraint information,
-		 *  as well as format options, are written to the resulting binding string; if this is
-		 *  <code>false</code> and <code>oResult.result</code> is "binding", then binding parameters
-		 *  are written to the resulting binding string if present
+		 *   if <code>true</code>, <code>oResult.result</code> is "binding" and
+		 *   <code>oResult.type</code> maps to a UI5 type, then both type and constraint
+		 *   information, as well as format options, are written to the resulting binding string;
+		 *   if this is <code>false</code> and <code>oResult.result</code> is "binding",
+		 *   then binding parameters are written to the resulting binding string if present
+		 * @param {boolean} [bRaw=false]
+		 *   if <code>true</code> and <code>oResult.result</code> is "binding", the resulting
+		 *   string will contain the raw value instead of being formatted with the type
 		 * @returns {string}
 		 *   the resulting string to embed into a composite binding or a binding expression
 		 */
-		resultToString : function (oResult, bExpression, bWithType) {
+		resultToString : function (oResult, bExpression, bWithType, bRaw) {
 			var vValue = oResult.value;
 
 			function binding(bAddType) {
@@ -383,31 +389,38 @@ sap.ui.define([
 			}
 
 			switch (oResult.result) {
-			case "binding":
-				return (bExpression ?  "$" : "") + binding(bWithType);
+				case "binding":
+					if (bExpression) {
+						return (bRaw ? "%" : "$") + binding(bWithType);
+					}
+					return binding(bWithType);
 
-			case "composite":
-				if (bExpression) {
-					throw new Error(
-						"Trying to embed a composite binding into an expression binding");
-				}
-				return vValue; // Note: it's already a composite binding string
+				case "composite":
+					if (bExpression) {
+						throw new Error(
+							"Trying to embed a composite binding into an expression binding");
+					}
+					return vValue; // Note: it's already a composite binding string
 
-			case "constant":
-				if (oResult.type === "edm:Null") {
-					return bExpression ? "null" : null;
-				}
-				if (bExpression) {
-					return constant(oResult);
-				}
-				return typeof vValue === "string"
-					? BindingParser.complexParser.escape(vValue)
-					: String(vValue);
+				case "constant":
+					if (oResult.type === "edm:Null") {
+						if (oResult.value === undefined) {
+							return bExpression ? "undefined" : undefined;
+						}
+						return bExpression ? "null" : null;
+					}
+					if (bExpression) {
+						return constant(oResult);
+					}
+					return typeof vValue === "string"
+						? BindingParser.complexParser.escape(vValue)
+						: String(vValue);
 
-			case "expression":
-				return bExpression ? vValue : "{=" + vValue + "}";
+				case "expression":
+					return bExpression ? vValue : "{=" + vValue + "}";
 
-			// no default
+				default:
+					return undefined;
 			}
 		},
 
@@ -487,4 +500,4 @@ sap.ui.define([
 
 	return Basics;
 
-}, /* bExport= */ false);
\ No newline at end of file
+});
\ No newline at end of file
