@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 //Provides mixin sap.ui.model.odata.v4.ODataBinding for classes extending sap.ui.model.Binding
@@ -13,12 +13,24 @@ sap.ui.define([
 ], function (_Helper, SyncPromise, ChangeReason, OperationMode, Context) {
 	"use strict";
 
-	var aChangeReasonPrecedence = [ChangeReason.Change, ChangeReason.Refresh, ChangeReason.Sort,
-			ChangeReason.Filter],
+	var aChangeReasonPrecedence = [ChangeReason.Context, ChangeReason.Change, ChangeReason.Refresh,
+			ChangeReason.Sort, ChangeReason.Filter],
 		sClassName = "sap.ui.model.odata.v4.ODataBinding",
 		// Whether a path segment is an index or contains a transient predicate
 		rIndexOrTransientPredicate = /\/\d|\(\$uid=/;
 
+	/*
+	 * Tells whether the first given change reason has precedence over the second one.
+	 *
+	 * @param {string} sChangeReason0 - A change reason
+	 * @param {string} sChangeReason1  - A change reason
+	 * @returns {boolean} Whether the first given change reason has precedence over the second one
+	 */
+	function hasPrecedenceOver(sChangeReason0, sChangeReason1) {
+		return aChangeReasonPrecedence.indexOf(sChangeReason0)
+			> aChangeReasonPrecedence.indexOf(sChangeReason1);
+	}
+
 	/**
 	 * A mixin for all OData V4 bindings.
 	 *
@@ -47,24 +59,23 @@ sap.ui.define([
 
 	/**
 	 * Adjusts the paths of all contexts of this binding by replacing the given transient predicate
-	 * with the given predicate and adjusts all contexts of child bindings.
+	 * with the given predicate. Recursively adjusts all child bindings.
 	 *
 	 * @param {string} sTransientPredicate - The transient predicate to be replaced
 	 * @param {string} sPredicate - The new predicate
-	 * @param {sap.ui.model.odata.v4.Context} [oContext] - The only context that changed
 	 *
-	 * @abstract
-	 * @function
-	 * @name sap.ui.model.odata.v4.ODataBinding#adjustPredicate
 	 * @private
 	 */
+	ODataBinding.prototype.adjustPredicate = function (sTransientPredicate, sPredicate) {
+		this.sReducedPath = this.sReducedPath.replace(sTransientPredicate, sPredicate);
+	};
 
 	/**
-	 * Throws an Error that the response is discarded if the current cache not the expected one.
-	 * The error has the property <code>canceled : true</code>
+	 * Throws an error that the response is being ignored if the current cache is not the expected
+	 * one. The error has the property <code>canceled : true</code>
 	 *
-	 * @param {sap.ui.model.odata.v4.lib_Cache} oExpectedCache - The expected cache
-	 * @throws {Error} If the cache has changed
+	 * @param {sap.ui.model.odata.v4.lib._Cache} oExpectedCache - The expected cache
+	 * @throws {Error} If the current cache is not the expected one
 	 *
 	 * @private
 	 */
@@ -72,7 +83,8 @@ sap.ui.define([
 		var oError;
 
 		if (this.oCache !== oExpectedCache) {
-			oError = new Error("Response discarded: cache is inactive");
+			oError = new Error(this + " is ignoring response from inactive cache: "
+				+ oExpectedCache);
 			oError.canceled = true;
 			throw oError;
 		}
@@ -143,9 +155,9 @@ sap.ui.define([
 						throw new Error("Unsupported binding parameter $$inheritExpandSelect: "
 							+ "binding is not an operation binding");
 					}
-					if (mParameters.$expand || mParameters.$select) {
+					if (mParameters.$expand) {
 						throw new Error("Must not set parameter $$inheritExpandSelect on a binding "
-							+ "which has a $expand or $select binding parameter");
+							+ "which has a $expand binding parameter");
 					}
 					break;
 				case "$$operationMode":
@@ -172,14 +184,19 @@ sap.ui.define([
 	/**
 	 * Throws an Error if the binding's root binding is suspended.
 	 *
-	 * @throws {Error} If the binding's root binding is suspended
+	 * @param {boolean} [bIfNoResumeChangeReason]
+	 *   Whether to accept a suspended root binding as long as no <code>sResumeChangeReason</code>
+	 *   is known for this binding (which must not be a root itself) or any of its dependents
+	 * @throws {Error} If the binding's root binding is suspended, except if
+	 *   <code>bIfNoResumeChangeReason</code> is used as described
 	 *
 	 * @private
 	 */
-	ODataBinding.prototype.checkSuspended = function () {
+	ODataBinding.prototype.checkSuspended = function (bIfNoResumeChangeReason) {
 		var oRootBinding = this.getRootBinding();
 
-		if (oRootBinding && oRootBinding.isSuspended()) {
+		if (oRootBinding && oRootBinding.isSuspended()
+				&& (!bIfNoResumeChangeReason || this.isRoot() || this.getResumeChangeReason())) {
 			throw new Error("Must not call method when the binding's root binding is suspended: "
 				+ this);
 		}
@@ -197,15 +214,13 @@ sap.ui.define([
 	 */
 	// @override sap.ui.model.Binding#checkUpdate
 	ODataBinding.prototype.checkUpdate = function (bForceUpdate) {
-		var that = this;
-
 		if (arguments.length > 1) {
 			throw new Error("Only the parameter bForceUpdate is supported");
 		}
 
-		this.checkUpdateInternal(bForceUpdate).catch(function (oError) {
-			that.oModel.reportError("Failed to update " + that, sClassName, oError);
-		});
+		this.checkUpdateInternal(bForceUpdate).catch(this.oModel.getReporter());
+		// do not rethrow, ManagedObject doesn't react on this either
+		// throwing an error would cause "Uncaught (in promise)" in Chrome
 	};
 
 	/**
@@ -217,7 +232,7 @@ sap.ui.define([
 	 *   Whether the change event is fired in any case (only allowed for property bindings)
 	 * @returns {sap.ui.base.SyncPromise}
 	 *   A promise resolving without a defined result when the check is finished, or rejecting in
-	 *   case of an error (e.g. thrown by the change event handler of a control)
+	 *   case of an error
 	 * @throws {Error} If called with illegal parameters
 	 *
 	 * @abstract
@@ -238,36 +253,60 @@ sap.ui.define([
 	 *   The resource path
 	 * @param {sap.ui.model.Context} [oContext]
 	 *   The context instance to be used, undefined for absolute bindings
-	 * @returns {sap.ui.model.odata.lib._Cache}
-	 *   The cache
+	 * @param {boolean} [bOldCacheReadOnly]
+	 *   Whether the old cache is read-only and must be kept intact - not reset and reused!
+	 * @param {sap.ui.model.odata.v4.lib._Cache} [oOldCache]
+	 *   The old cache, in case it may be reused
+	 * @returns {sap.ui.model.odata.v4.lib._Cache}
+	 *   The cache or <code>null</code> if the binding is relative and the given context is
+	 *   transient
 	 *
 	 * @private
 	 */
-	ODataBinding.prototype.createAndSetCache = function (mQueryOptions, sResourcePath, oContext) {
-		var oCache, sDeepResourcePath, iReturnValueContextId;
+	ODataBinding.prototype.createAndSetCache = function (mQueryOptions, sResourcePath, oContext,
+			bOldCacheReadOnly, oOldCache) {
+		var oCache, sDeepResourcePath, iGeneration;
 
 		this.mCacheQueryOptions = Object.assign({}, this.oModel.mUriParameters, mQueryOptions);
 		if (this.bRelative) { // quasi-absolute or relative binding
+			// The parent has to be persisted in order to know the key predicates when creating the
+			// child's own cache. Context#isTransient cannot be used exclusively here because it
+			// returns true for ODLB#create w/o bSkipRefresh, unless the refresh for the created
+			// entity is resolved too - but the entity's key predicates are already available.
+			if (oContext.isTransient && oContext.isTransient()
+				&& oContext.getProperty("@$ui5.context.isTransient")) {
+				// Note: sResourcePath is kind of preliminary here, no use to remember it!
+				this.oCache = null;
+				return null;
+			}
+
 			// mCacheByResourcePath has to be reset if parameters are changing
 			oCache = this.mCacheByResourcePath && this.mCacheByResourcePath[sResourcePath];
-			iReturnValueContextId = oContext.getReturnValueContextId
-				&& oContext.getReturnValueContextId();
-			if (oCache && oCache.$returnValueContextId === iReturnValueContextId) {
+			iGeneration = oContext.getGeneration && oContext.getGeneration() || 0;
+			if (oCache && oCache.$generation >= iGeneration) {
 				oCache.setActive(true);
 			} else {
-				sDeepResourcePath = _Helper.buildPath(oContext.getPath(), this.sPath).slice(1);
+				sDeepResourcePath = this.oModel.resolve(this.sPath, oContext).slice(1);
 				oCache = this.doCreateCache(sResourcePath, this.mCacheQueryOptions, oContext,
-					sDeepResourcePath);
+					sDeepResourcePath, bOldCacheReadOnly, oOldCache);
 				if (!(this.mParameters && this.mParameters.$$sharedRequest)) {
 					this.mCacheByResourcePath = this.mCacheByResourcePath || {};
 					this.mCacheByResourcePath[sResourcePath] = oCache;
 				}
 				oCache.$deepResourcePath = sDeepResourcePath;
-				oCache.$resourcePath = sResourcePath;
-				oCache.$returnValueContextId = iReturnValueContextId;
+				oCache.$generation = iGeneration;
 			}
 		} else { // absolute binding
-			oCache = this.doCreateCache(sResourcePath, this.mCacheQueryOptions);
+			oCache = this.doCreateCache(sResourcePath, this.mCacheQueryOptions, undefined,
+				undefined, bOldCacheReadOnly, oOldCache);
+		}
+		if (oOldCache !== oCache) {
+			if (oOldCache) {
+				oOldCache.setActive(false);
+			}
+			if (this.mLateQueryOptions) {
+				oCache.setLateQueryOptions(this.mLateQueryOptions);
+			}
 		}
 		this.oCache = oCache;
 
@@ -308,6 +347,10 @@ sap.ui.define([
 	 *   The context instance to be used, must be <code>undefined</code> for absolute bindings
 	 * @param {string} [sDeepResourcePath=sResourcePath]
 	 *   The deep resource path to be used to build the target path for bound messages
+	 * @param {boolean} [bOldCacheReadOnly]
+	 *   Whether the old cache is read-only and must be kept intact - not reset and reused!
+	 * @param {sap.ui.model.odata.v4.lib._Cache} [oOldCache]
+	 *   The old cache, in case it may be reused
 	 * @returns {sap.ui.model.odata.v4.lib._Cache}
 	 *   The new cache instance
 	 *
@@ -331,6 +374,21 @@ sap.ui.define([
 		this.oCache.deregisterChange(sPath, oListener);
 	};
 
+	/**
+	 * Hook method for {@link #fetchQueryOptionsForOwnCache} to determine the query options for this
+	 * binding.
+	 *
+	 * @param {sap.ui.model.Context} oContext
+	 *   The context instance to be used
+	 * @returns {sap.ui.base.SyncPromise}
+	 *   A promise resolving with the binding's query options
+	 *
+	 * @abstract
+	 * @function
+	 * @name sap.ui.model.odata.v4.ODataBinding#doFetchQueryOptions
+	 * @private
+	 */
+
 	/**
 	 * Creates a cache for this binding if a cache is needed and updates <code>oCachePromise</code>.
 	 *
@@ -340,12 +398,25 @@ sap.ui.define([
 	 *   Whether the parent cache is ignored and a new cache shall be created. This is for example
 	 *   needed during the resume process in case this binding has changed but its parent
 	 *   binding has not (see {@link sap.ui.model.odata.v4.ODataListBinding#resumeInternal})
+	 * @param {boolean} [bKeepQueryOptions]
+	 *   Whether to keep existing (late) query options and not to run auto-$expand/$select again
+	 *   (cannot be combined with <code>bIgnoreParentCache</code>!)
+	 * @param {boolean} [bKeepCacheOnError]
+	 *   If <code>true</code>, the binding data remains unchanged if the refresh fails. This implies
+	 *   that the old cache must be kept intact - not reset and reused!
+	 * @throws {Error}
+	 *   If auto-$expand/$select is still running and query options shall be kept (this case is just
+	 *   not yet implemented and should not be needed)
 	 *
 	 * @private
 	 */
-	ODataBinding.prototype.fetchCache = function (oContext, bIgnoreParentCache) {
-		var oCachePromise,
-			oCallToken = {},
+	ODataBinding.prototype.fetchCache = function (oContext, bIgnoreParentCache, bKeepQueryOptions,
+		bKeepCacheOnError) {
+		var oCache = this.oCache,
+			oCallToken = {
+				// propagate old cache from first call of fetchCache to the latest call
+				oOldCache : oCache === undefined ? this.oFetchCacheCallToken.oOldCache : oCache
+			},
 			aPromises,
 			that = this;
 
@@ -353,18 +424,30 @@ sap.ui.define([
 			oContext = undefined;
 		}
 
-		if (this.oCache) {
-			// if oCachePromise is pending no cache will be created because of oFetchCacheCallToken
-			this.oCache.setActive(false);
+		if (!oCache && bKeepQueryOptions) {
+			if (oCache === undefined) {
+				throw new Error("Unsupported bKeepQueryOptions while oCachePromise is pending");
+			}
+			return;
 		}
+
 		this.oCache = undefined;
+		this.oFetchCacheCallToken = oCallToken;
+		if (bKeepQueryOptions) {
+			// asynchronously re-create an equivalent cache
+			this.oCachePromise = SyncPromise.resolve(Promise.resolve()).then(function () {
+				return that.createAndSetCache(that.mCacheQueryOptions, oCache.getResourcePath(),
+					oContext, bKeepCacheOnError, oCache);
+			});
+			return;
+		}
+
 		aPromises = [
 			this.fetchQueryOptionsForOwnCache(oContext, bIgnoreParentCache),
 			this.oModel.oRequestor.ready()
 		];
 		this.mCacheQueryOptions = undefined;
-		this.mLateQueryOptions = undefined;
-		oCachePromise = SyncPromise.all(aPromises).then(function (aResult) {
+		this.oCachePromise = SyncPromise.all(aPromises).then(function (aResult) {
 			var mQueryOptions = aResult[0].mQueryOptions;
 
 			that.sReducedPath = aResult[0].sReducedPath;
@@ -375,25 +458,24 @@ sap.ui.define([
 					var oError;
 
 					// create cache only for the latest call to fetchCache
-					if (oCachePromise && that.oFetchCacheCallToken !== oCallToken) {
+					if (that.oFetchCacheCallToken !== oCallToken) {
 						oError = new Error("Cache discarded as a new cache has been created");
 						oError.canceled = true;
 						throw oError;
 					}
-					return that.createAndSetCache(mQueryOptions, sResourcePath, oContext);
+					return that.createAndSetCache(mQueryOptions, sResourcePath, oContext,
+						bKeepCacheOnError, oCallToken.oOldCache);
 				});
 			}
 			that.oCache = null;
 			return null;
 		});
-		oCachePromise.catch(function (oError) {
+		this.oCachePromise.catch(function (oError) {
 			//Note: this may also happen if the promise to read data for the canonical path's
 			// key predicate is rejected with a canceled error
 			that.oModel.reportError("Failed to create cache for binding " + that, sClassName,
 				oError);
 		});
-		this.oCachePromise = oCachePromise;
-		this.oFetchCacheCallToken = oCallToken;
 	};
 
 	/**
@@ -470,7 +552,7 @@ sap.ui.define([
 		}
 
 		// parent cache is ignored or (quasi-)absolute binding
-		if (bIgnoreParentCache || !this.bRelative || !oContext.fetchValue)  {
+		if (bIgnoreParentCache || !this.bRelative || !oContext.fetchValue) {
 			// the binding shall create its own cache
 			return wrapQueryOptions(oQueryOptionsPromise);
 		}
@@ -596,7 +678,7 @@ sap.ui.define([
 	 *
 	 * @param {string} sPath
 	 *   A path (absolute or relative to this binding)
-	 * @returns {string}
+	 * @returns {string|undefined}
 	 *   The given path, if it is already relative; otherwise the path relative to the binding's
 	 *   resolved path or return value context path; <code>undefined</code> if the path does not
 	 *   start with either of these paths.
@@ -607,8 +689,7 @@ sap.ui.define([
 		var sRelativePath;
 
 		if (sPath[0] === "/") {
-			sRelativePath = _Helper.getRelativePath(sPath,
-				this.oModel.resolve(this.sPath, this.oContext));
+			sRelativePath = _Helper.getRelativePath(sPath, this.getResolvedPath());
 			if (sRelativePath === undefined && this.oReturnValueContext) {
 				sRelativePath = _Helper.getRelativePath(sPath, this.oReturnValueContext.getPath());
 			}
@@ -621,10 +702,36 @@ sap.ui.define([
 		return sPath;
 	};
 
+	/**
+	 * Returns the "strongest" change reason that {@link #resume} would fire for this binding or any
+	 * of its dependents.
+	 *
+	 * @returns {sap.ui.model.ChangeReason|undefined}
+	 *   The "strongest" change reason, or <code>undefined</code>
+	 *
+	 * @private
+	 * @see #getDependentBindings
+	 * @see #setResumeChangeReason
+	 */
+	ODataBinding.prototype.getResumeChangeReason = function () {
+		var sStrongestChangeReason = this.sResumeChangeReason;
+
+		this.getDependentBindings().forEach(function (oDependentBinding) {
+			var sDependentChangeReason = oDependentBinding.getResumeChangeReason();
+
+			if (sDependentChangeReason
+					&& hasPrecedenceOver(sDependentChangeReason, sStrongestChangeReason)) {
+				sStrongestChangeReason = sDependentChangeReason;
+			}
+		});
+
+		return sStrongestChangeReason;
+	};
+
 	/**
 	 * Returns a promise which resolves as soon as this binding is resumed.
 	 *
-	 * @returns {sap.ui.base.SyncPromise}
+	 * @returns {sap.ui.base.SyncPromise|undefined}
 	 *   This binding's current promise for {@link sap.ui.model.odata.v4.ODataParentBinding#resume},
 	 *   or <code>undefined</code> in case it is not currently suspended.
 	 *
@@ -639,7 +746,8 @@ sap.ui.define([
 	 * Returns the root binding of this binding's hierarchy, see binding
 	 * {@link topic:54e0ddf695af4a6c978472cecb01c64d Initialization and Read Requests}.
 	 *
-	 * @returns {sap.ui.model.odata.v4.ODataContextBinding|sap.ui.model.odata.v4.ODataListBinding|sap.ui.model.odata.v4.ODataPropertyBinding}
+	 * @returns {sap.ui.model.odata.v4.ODataContextBinding|sap.ui.model.odata.v4.ODataListBinding|
+	 *      sap.ui.model.odata.v4.ODataPropertyBinding|undefined}
 	 *   The root binding or <code>undefined</code> if this binding is unresolved (see
 	 *   {@link sap.ui.model.Binding#isResolved}).
 	 *
@@ -713,15 +821,23 @@ sap.ui.define([
 	 * parent context path of this binding. If this binding is unresolved (see
 	 * {@link sap.ui.model.Binding#isResolved}), it returns <code>false</code>.
 	 *
+	 * @param {boolean} [bIgnoreKeptAlive]
+	 *   Whether to ignore changes which will not be lost by APIs like
+	 *  {@link sap.ui.model.odata.v4.ODataListBinding#changeParameters changeParameters},
+	 *  {@link sap.ui.model.odata.v4.ODataListBinding#filter filter},
+	 *  {@link sap.ui.model.odata.v4.ODataListBinding#sort sort}, or
+	 *  {@link sap.ui.model.odata.v4.ODataListBinding#suspend suspend} because they relate to a
+	 *  {@link sap.ui.model.odata.v4.Context#setKeepAlive kept-alive} context of this binding.
 	 * @returns {boolean}
 	 *   <code>true</code> if the binding is resolved and has pending changes
 	 *
 	 * @public
 	 * @since 1.39.0
 	 */
-	ODataBinding.prototype.hasPendingChanges = function () {
+	ODataBinding.prototype.hasPendingChanges = function (bIgnoreKeptAlive) {
 		return this.isResolved()
-			&& (this.hasPendingChangesForPath("") || this.hasPendingChangesInDependents());
+			&& (this.hasPendingChangesForPath("", bIgnoreKeptAlive)
+				|| this.hasPendingChangesInDependents(bIgnoreKeptAlive));
 	};
 
 	/**
@@ -730,20 +846,24 @@ sap.ui.define([
 	 *
 	 * @param {string} sPath
 	 *   The path (absolute or relative to this binding)
+	 * @param {boolean} [bIgnoreKeptAlive]
+	 *   Whether to ignore changes which will not be lost by APIs like sort or filter because they
+	 *   relate to a context which is kept alive.
 	 * @returns {boolean}
 	 *   <code>true</code> if there are pending changes for the path
 	 *
 	 * @private
 	 */
-	ODataBinding.prototype.hasPendingChangesForPath = function (sPath) {
-		return this.withCache(function (oCache, sCachePath) {
-				return oCache.hasPendingChangesForPath(sCachePath);
+	ODataBinding.prototype.hasPendingChangesForPath = function (sPath, bIgnoreKeptAlive) {
+		return this.withCache(function (oCache, sCachePath, oBinding) {
+				return oCache.hasPendingChangesForPath(sCachePath, bIgnoreKeptAlive,
+					bIgnoreKeptAlive && oBinding.isRoot()); // Note: implies oBinding === that
 			}, sPath, true).unwrap();
 	};
 
 	/**
 	 * Checks whether there are pending changes in caches stored by resource path at this binding
-	 * which have the given resource path as prefix.
+	 * which have the given resource path as prefix. Called for unresolved bindings only.
 	 *
 	 * @param {string} sResourcePathPrefix
 	 *   The resource path prefix to identify the relevant caches
@@ -769,6 +889,9 @@ sap.ui.define([
 	/**
 	 * Returns whether any dependent binding of this binding has pending changes
 	 *
+	 * @param {boolean} [bIgnoreKeptAlive]
+	 *   Whether to ignore changes which will not be lost by APIs like sort or filter because they
+	 *   relate to a context which is kept alive.
 	 * @returns {boolean}
 	 *   <code>true</code> if this binding has pending changes
 	 *
@@ -781,10 +904,10 @@ sap.ui.define([
 	/**
 	 * Method not supported
 	 *
+	 * @returns {boolean}
 	 * @throws {Error}
 	 *
 	 * @public
-	 * @see sap.ui.model.Binding#isInitial
 	 * @since 1.37.0
 	 */
 	// @override sap.ui.model.Binding#isInitial
@@ -797,7 +920,6 @@ sap.ui.define([
 	 *
 	 * @returns {boolean} - Whether the binding points to metadata
 	 *
-	 *
 	 * @abstract
 	 * @function
 	 * @name sap.ui.model.odata.v4.ODataBinding#isMeta
@@ -867,41 +989,33 @@ sap.ui.define([
 	 * {@link sap.ui.model.odata.v4.ODataModel#resetChanges} to reset the changes before calling
 	 * {@link #refresh}.
 	 *
-	 * @param {string} [sGroupId]
+	 * Use {@link #requestRefresh} if you want to wait for the refresh.
+	 *
+	 * @param {string|boolean} [sGroupId]
 	 *   The group ID to be used for refresh; if not specified, the binding's group ID is used, see
 	 *   {@link #getGroupId}. For suspended bindings, only the binding's group ID is supported
-	 *   because {@link #resume} uses the binding's group ID.
+	 *   because {@link #resume} uses the binding's group ID. A value of type boolean is not
+	 *   accepted and an error will be thrown (a forced refresh is not supported).
 	 *
 	 *   Valid values are <code>undefined</code>, '$auto', '$auto.*', '$direct' or application group
 	 *   IDs as specified in {@link sap.ui.model.odata.v4.ODataModel}.
 	 * @throws {Error}
 	 *   If the given group ID is invalid, the binding has pending changes, refresh on this
-	 *   binding is not supported, or a group ID different from the binding's group ID is specified
-	 *   for a suspended binding.
+	 *   binding is not supported, a group ID different from the binding's group ID is specified
+	 *   for a suspended binding, or a value of type boolean is given.
 	 *
 	 * @public
 	 * @see sap.ui.model.Binding#refresh
 	 * @see #getRootBinding
-	 * @see #hasPendingChanges
-	 * @see #resetChanges
 	 * @see #suspend
 	 * @since 1.37.0
 	 */
 	// @override sap.ui.model.Binding#refresh
 	ODataBinding.prototype.refresh = function (sGroupId) {
-		if (!this.isRoot()) {
-			throw new Error("Refresh on this binding is not supported");
+		if (typeof sGroupId === "boolean") {
+			throw new Error("Unsupported parameter bForceUpdate");
 		}
-		if (this.hasPendingChanges()) {
-			throw new Error("Cannot refresh due to pending changes");
-		}
-		this.oModel.checkGroupId(sGroupId);
-
-		// The actual refresh is specific to the binding and is implemented in each binding class.
-		this.refreshInternal("", sGroupId, true).catch(function () {
-			// Nothing to do here, the error is already logged. The catch however is necessary,
-			// because we drop the promise here, so there is no other code to catch it.
-		});
+		this.requestRefresh(sGroupId).catch(this.oModel.getReporter());
 	};
 
 	/**
@@ -932,41 +1046,49 @@ sap.ui.define([
 	 */
 
 	/**
-	 * Remove this binding's caches and non-persistent messages. Only caches with a deep resource
-	 * path starting with the given resource path prefix and messages with a target path starting
-	 * with the given prefix are removed.
+	 * Refreshes the binding; expects it to be suspended.
+	 *
+	 * @param {string} sGroupId
+	 *   The group ID to be used for the refresh
+	 * @throws {Error}
+	 *   If a group ID different from the binding's group ID is given
+
+	 * @private
+	 */
+	ODataBinding.prototype.refreshSuspended = function (sGroupId) {
+		if (sGroupId && sGroupId !== this.getGroupId()) {
+			throw new Error(this + ": Cannot refresh a suspended binding with group ID '"
+				+ sGroupId + "' (own group ID is '" + this.getGroupId() + "')");
+		}
+		this.setResumeChangeReason(ChangeReason.Refresh);
+	};
+
+	/**
+	 * Remove this binding's caches and non-persistent messages. The binding's active cache removes
+	 * only its own messages. Inactive caches with a deep resource path starting with the given
+	 * resource path prefix are removed and they also remove only their own messages.
 	 *
 	 * @param {string} sResourcePathPrefix
-	 *   The resource path prefix which is used to delete the dependent caches and corresponding
-	 *   messages; may be "" but not <code>undefined</code>
+	 *   The resource path prefix which is used to delete inactive caches and their messages; may be
+	 *   "" but not <code>undefined</code>
 	 * @param {boolean} [bCachesOnly] Whether to keep messages untouched
 	 *
 	 * @private
 	 */
 	ODataBinding.prototype.removeCachesAndMessages = function (sResourcePathPrefix, bCachesOnly) {
-		var oModel = this.oModel,
-			sResolvedPath,
-			that = this;
+		var that = this;
 
-		if (!bCachesOnly) {
-			sResolvedPath = oModel.resolve(this.sPath, this.oContext);
-			if (sResolvedPath) {
-				// The caller of this function replaces the current cache just after this function
-				// call; remove only the related messages
-				oModel.reportBoundMessages(sResolvedPath.slice(1), {});
-			}
+		if (!bCachesOnly && this.oCache) {
+			this.oCache.removeMessages();
 		}
 		if (this.mCacheByResourcePath) {
 			Object.keys(this.mCacheByResourcePath).forEach(function (sResourcePath) {
 				var oCache = that.mCacheByResourcePath[sResourcePath],
-					sDeepResourcePath = that.mCacheByResourcePath[sResourcePath].$deepResourcePath;
+					sDeepResourcePath = oCache.$deepResourcePath;
 
-				if (sResourcePathPrefix === ""
-						|| sDeepResourcePath === sResourcePathPrefix
-						|| sDeepResourcePath.startsWith(sResourcePathPrefix + "/")
-						|| sDeepResourcePath.startsWith(sResourcePathPrefix + "(")) {
+				if (_Helper.hasPathPrefix(sDeepResourcePath, sResourcePathPrefix)) {
 					if (!bCachesOnly) {
-						oModel.reportBoundMessages(oCache.$deepResourcePath, {});
+						oCache.removeMessages();
 					}
 					delete that.mCacheByResourcePath[sResourcePath];
 				}
@@ -974,6 +1096,73 @@ sap.ui.define([
 		}
 	};
 
+	/**
+	 * Requests side effects for the given absolute paths.
+	 *
+	 * @param {string} sGroupId
+	 *   The effective group ID
+	 * @param {string[]} aAbsolutePaths
+	 *   The absolute paths to request side effects for
+	 * @returns {sap.ui.base.SyncPromise|undefined}
+	 *   A promise resolving without a defined result, or rejecting with an error if loading of side
+	 *   effects fails, or <code>undefined</code> if there is nothing to do
+	 *
+	 * @private
+	 */
+	ODataBinding.prototype.requestAbsoluteSideEffects = function (sGroupId, aAbsolutePaths) {
+		var aPaths = [],
+			sMetaPath = _Helper.getMetaPath(this.getResolvedPath());
+
+		aAbsolutePaths.some(function (sAbsolutePath) {
+			var sRelativePath = _Helper.getRelativePath(sAbsolutePath, sMetaPath);
+
+			if (sRelativePath !== undefined) {
+				aPaths.push(sRelativePath);
+			} else if (_Helper.hasPathPrefix(sMetaPath, sAbsolutePath)) {
+				aPaths = [""]; // "refresh"
+				return true; // break
+			}
+		});
+
+		if (aPaths.length) {
+			if (this.requestSideEffects) {
+				return this.requestSideEffects(sGroupId, aPaths);
+			}
+			return this.refreshInternal("", sGroupId, true, true);
+		}
+		// return undefined;
+	};
+
+	/**
+	 * Refreshes the binding and returns a promise to wait for it. See {@link #refresh} for details.
+	 * Use {@link #refresh} if you do not need the promise.
+	 *
+	 * @param {string} [sGroupId]
+	 *   The group ID to be used
+	 * @returns {Promise}
+	 *   A promise which resolves without a defined result when the refresh is finished and rejects
+	 *   with an instance of <code>Error</code> if the refresh failed
+	 * @throws {Error}
+	 *   See {@link #refresh} for details
+	 *
+	 * @public
+	 * @since 1.87.0
+	 */
+	ODataBinding.prototype.requestRefresh = function (sGroupId) {
+		if (!this.isRoot()) {
+			throw new Error("Refresh on this binding is not supported");
+		}
+		if (this.hasPendingChanges()) {
+			throw new Error("Cannot refresh due to pending changes");
+		}
+		this.oModel.checkGroupId(sGroupId);
+
+		// The actual refresh is specific to the binding and is implemented in each binding class.
+		return Promise.resolve(this.refreshInternal("", sGroupId, true)).then(function () {
+			// return undefined
+		});
+	};
+
 	/**
 	 * Resets all pending changes of this binding, see {@link #hasPendingChanges}. Resets also
 	 * invalid user input.
@@ -1039,8 +1228,7 @@ sap.ui.define([
 	 *
 	 * @private
 	 */
-	ODataBinding.prototype.resetInvalidDataState = function () {
-	};
+	ODataBinding.prototype.resetInvalidDataState = function () {};
 
 	/**
 	 * Sets the change reason that {@link #resume} fires. If there are multiple changes, the
@@ -1052,8 +1240,7 @@ sap.ui.define([
 	 * @private
 	 */
 	ODataBinding.prototype.setResumeChangeReason = function (sChangeReason) {
-		if (aChangeReasonPrecedence.indexOf(sChangeReason) >
-				aChangeReasonPrecedence.indexOf(this.sResumeChangeReason)) {
+		if (hasPrecedenceOver(sChangeReason, this.sResumeChangeReason)) {
 			this.sResumeChangeReason = sChangeReason;
 		}
 	};
@@ -1067,7 +1254,7 @@ sap.ui.define([
 	 * @since 1.37.0
 	 */
 	ODataBinding.prototype.toString = function () {
-		return this.getMetadata().getName() + ": " + (this.bRelative  ? this.oContext + "|" : "")
+		return this.getMetadata().getName() + ": " + (this.bRelative ? this.oContext + "|" : "")
 			+ this.sPath;
 	};
 
@@ -1158,16 +1345,14 @@ sap.ui.define([
 		}
 	}
 
-	// #doDeregisterChangeListener is not final, allow for "super" calls
-	asODataBinding.prototype.doDeregisterChangeListener
-		= ODataBinding.prototype.doDeregisterChangeListener;
-	// #destroy is not final, allow for "super" calls
-	asODataBinding.prototype.destroy = ODataBinding.prototype.destroy;
-	// #fetchCache is not final, allow for "super" calls
-	asODataBinding.prototype.fetchCache = ODataBinding.prototype.fetchCache;
-	// #hasPendingChangesForPath is not final, allow for "super" calls
-	asODataBinding.prototype.hasPendingChangesForPath
-		= ODataBinding.prototype.hasPendingChangesForPath;
+	[
+		"adjustPredicate",
+		"destroy",
+		"doDeregisterChangeListener",
+		"hasPendingChangesForPath"
+	].forEach(function (sMethod) { // method not final, allow for "super" calls
+		asODataBinding.prototype[sMethod] = ODataBinding.prototype[sMethod];
+	});
 
 	return asODataBinding;
-}, /* bExport= */ false);
\ No newline at end of file
+}, /* bExport= */ false);
