@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -8,6 +8,7 @@
 sap.ui.define(function () {
 	"use strict";
 
+	// noinspection UnnecessaryLocalVariableJS
 	/**
 	 * Modes to control the use of batch requests for a group ID.
 	 *
@@ -15,28 +16,27 @@ sap.ui.define(function () {
 	 * @public
 	 * @alias sap.ui.model.odata.v4.SubmitMode
 	 */
-	var SubmitMode = {
+	var SubmitMode = { // keep the var for JSDoc generation
 		/**
 		 * Requests associated with the group ID are sent in a batch request via
 		 * {@link sap.ui.model.odata.v4.ODataModel#submitBatch}.
 		 * @public
 		 */
-		API: "API",
+		API : "API",
 
 		/**
 		 * Requests associated with the group ID are sent in a batch request which is triggered
 		 * automatically before rendering.
 		 * @public
 		 */
-		Auto: "Auto",
+		Auto : "Auto",
 
 		/**
 		 * Requests associated with the group ID are sent directly without batch.
 		 * @public
 		 */
-		Direct: "Direct"
+		Direct : "Direct"
 	};
 
 	return SubmitMode;
-
 }, /* bExport= */ true);
