@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -42,72 +42,72 @@ sap.ui.define([], function () {
 		sValue = '(?:[-+:./\\w"]|%2[bB])+',
 		// A Token: either an operator, a delimiter, a GUID (in aMatches[4]), a path (in
 		// aMatches[5]), a value (in aMatches[6]) or a system query option (in aMatches[7])
-		rToken = new RegExp("^(?:" + sOperators +  "|" + sDelimiters + "|(" + sGuid + ")|("
+		rToken = new RegExp("^(?:" + sOperators + "|" + sDelimiters + "|(" + sGuid + ")|("
 			+ sPath + ")|(" + sValue + ")|(" + sSystemQueryOption + "))"),
 		// The two hex digits of a %-escape
 		rEscapeDigits = /^[0-9a-f]{2}$/i,
 		// The list of built-in functions
 		mFunctions = {
-			"ceiling" : {
+			ceiling : {
 				ambiguousParameters : true
 			},
-			"concat" : {
+			concat : {
 				type : "Edm.String"
 			},
-			"contains" : {
+			contains : {
 				type : "Edm.Boolean"
 			},
-			"day" : {
+			day : {
 				type : "Edm.Int32",
 				ambiguousParameters : true
 			},
-			"endswith" : {
+			endswith : {
 				type : "Edm.Boolean"
 			},
-			"floor" : {
+			floor : {
 				ambiguousParameters : true
 			},
-			"hour" : {
+			hour : {
 				type : "Edm.Int32",
 				ambiguousParameters : true
 			},
-			"indexof" : {
+			indexof : {
 				type : "Edm.Int32"
 			},
-			"length" : {
+			length : {
 				type : "Edm.Int32"
 			},
-			"minute" : {
+			minute : {
 				type : "Edm.Int32",
 				ambiguousParameters : true
 			},
-			"month" : {
+			month : {
 				type : "Edm.Int32",
 				ambiguousParameters : true
 			},
-			"round" : {
+			round : {
 				ambiguousParameters : true
 			},
-			"second" : {
+			second : {
 				type : "Edm.Int32",
 				ambiguousParameters : true
 			},
-			"startswith" : {
+			startswith : {
 				type : "Edm.Boolean"
 			},
-			"substring" : {
+			substring : {
 				type : "Edm.String"
 			},
-			"tolower" : {
+			tolower : {
 				type : "Edm.String"
 			},
-			"toupper" : {
+			toupper : {
 				type : "Edm.String"
 			},
-			"trim" : {
+			trim : {
 				type : "Edm.String"
 			},
-			"year" : {
+			year : {
 				type : "Edm.Int32",
 				ambiguousParameters : true
 			}
@@ -141,18 +141,21 @@ sap.ui.define([], function () {
 						this.advanceBws();
 					} while (this.advanceIf(","));
 					this.advanceBws();
-					this.advance(')');
+					this.advance(")");
 					return oLeft;
 				},
 				nud : function () {
+					var oToken;
+
 					this.advanceBws();
-					var oToken = this.expression(0);
+					oToken = this.expression(0);
+
 					this.advanceBws();
-					this.advance(')');
+					this.advance(")");
 					return oToken;
 				}
 			},
-			"not" : {
+			not : {
 				lbp : 7,
 				nud : function (oToken) {
 					oToken.precedence = 7;
@@ -213,19 +216,24 @@ sap.ui.define([], function () {
 	//*****************************************************************************************
 	/**
 	 * The base parser class. Takes care of token and error handling.
+	 *
+	 * @alias sap.ui.model.odata.v4.lib._Parser
+	 * @constructor
 	 */
-	function Parser() {
+	function _Parser() {
 	}
 
 	/**
 	 * Returns the current token and advances to the next one.
 	 *
-	 * @param {string} [sExpectedTokenId] The expected ID of the token or undefined to accept any
-	 *   token
-	 * @returns {object} The current token or undefined if all tokens have been read
-	 * @throws {SyntaxError} If the next token's ID is not as expected
+	 * @param {string} [sExpectedTokenId]
+	 *   The expected ID of the token or <code>undefined</code> to accept any token
+	 * @returns {object|undefined}
+	 *   The current token or <code>undefined</code> if all tokens have been read
+	 * @throws {SyntaxError}
+	 *   If the next token's ID is not as expected
 	 */
-	Parser.prototype.advance = function (sExpectedTokenId) {
+	_Parser.prototype.advance = function (sExpectedTokenId) {
 		var oToken = this.current();
 
 		if (sExpectedTokenId && (!oToken || oToken.id !== sExpectedTokenId)) {
@@ -246,7 +254,7 @@ sap.ui.define([], function () {
 	 * @param {string} sExpectedTokenId The expected id of the next token
 	 * @returns {boolean} True if the token is as expected and the parser has advanced
 	 */
-	Parser.prototype.advanceIf = function (sExpectedTokenId) {
+	_Parser.prototype.advanceIf = function (sExpectedTokenId) {
 		var oToken = this.current();
 
 		if (oToken && oToken.id === sExpectedTokenId) {
@@ -258,9 +266,11 @@ sap.ui.define([], function () {
 
 	/**
 	 * Returns the current token in the array of tokens, but does not advance.
-	 * @returns {object} - the current token or undefined if all tokens have been read
+	 *
+	 * @returns {object|undefined} The current token or <code>undefined</code> if all tokens have
+	 *   been read
 	 */
-	Parser.prototype.current = function () {
+	_Parser.prototype.current = function () {
 		return this.aTokens[this.iCurrentToken];
 	};
 
@@ -268,16 +278,16 @@ sap.ui.define([], function () {
 	 * Throws an error.
 	 *
 	 * @param {string} sMessage The error message
-	 * @param {object} [oToken] The token to report the error for or undefined to indicate end of
-	 *   input
+	 * @param {object} [oToken] The token to report the error for or <code>undefined</code> to
+	 *   indicate end of input
 	 * @throws {SyntaxError} With this error message
 	 */
-	Parser.prototype.error = function (sMessage, oToken) {
+	_Parser.prototype.error = function (sMessage, oToken) {
 		var sValue;
 
 		if (oToken) {
 			sValue = oToken.value;
-			sMessage += "'" + (sValue === " " ?  sValue : sValue.replace(rRws, "")) + "' at "
+			sMessage += "'" + (sValue === " " ? sValue : sValue.replace(rRws, "")) + "' at "
 				+ oToken.at;
 		} else {
 			sMessage += "end of input";
@@ -289,10 +299,11 @@ sap.ui.define([], function () {
 	 * Throws an error that the token was not as expected.
 	 *
 	 * @param {string} sWhat A description what was expected
-	 * @param {object} [oToken] The unexpected token or undefined to indicate end of input
+	 * @param {object} [oToken] The unexpected token or <code>undefined</code> to indicate end of
+	 *   input
 	 * @throws {SyntaxError} An error that the token was not as expected
 	 */
-	Parser.prototype.expected = function (sWhat, oToken) {
+	_Parser.prototype.expected = function (sWhat, oToken) {
 		this.error("Expected " + sWhat + " but instead saw ", oToken);
 	};
 
@@ -301,7 +312,7 @@ sap.ui.define([], function () {
 	 *
 	 * @throws {SyntaxError} If there are unconsumed tokens
 	 */
-	Parser.prototype.finish = function () {
+	_Parser.prototype.finish = function () {
 		if (this.iCurrentToken < this.aTokens.length) {
 			this.expected("end of input", this.aTokens[this.iCurrentToken]);
 		}
@@ -312,7 +323,7 @@ sap.ui.define([], function () {
 	 *
 	 * @param {string} sText The text to parse
 	 */
-	Parser.prototype.init = function (sText) {
+	_Parser.prototype.init = function (sText) {
 		this.sText = sText;
 		this.aTokens = tokenize(sText);
 		this.iCurrentToken = 0;
@@ -322,16 +333,19 @@ sap.ui.define([], function () {
 	/**
 	 * A parser that is able to parse a filter string into a syntax tree which recognizes paths,
 	 * comparison operators, literals and built-in functions (which are identical in V2 and V4).
+	 *
+	 * @alias sap.ui.model.odata.v4.lib._FilterParser
+	 * @constructor
 	 */
-	function FilterParser() {
+	function _FilterParser() {
 	}
 
-	FilterParser.prototype = Object.create(Parser.prototype);
+	_FilterParser.prototype = Object.create(_Parser.prototype);
 
 	/**
 	 * Advances to the next token that is not a whitespace character. (Skips over "bad whitespace".)
 	 */
-	FilterParser.prototype.advanceBws = function () {
+	_FilterParser.prototype.advanceBws = function () {
 		var oToken;
 
 		for (;;) {
@@ -349,7 +363,7 @@ sap.ui.define([], function () {
 	 * @param {number} iRbp A "right binding power"
 	 * @returns {object} The syntax tree for that expression
 	 */
-	FilterParser.prototype.expression = function (iRbp) {
+	_FilterParser.prototype.expression = function (iRbp) {
 		var fnLeft, oLeft, oToken;
 
 		oToken = this.advance();
@@ -377,10 +391,10 @@ sap.ui.define([], function () {
 	 * @param {any} [vDefault] The default value if nothing is found in the symbol table entry
 	 * @returns {any} The value
 	 */
-	FilterParser.prototype.getSymbolValue = function (oToken, sWhat, vDefault) {
+	_FilterParser.prototype.getSymbolValue = function (oToken, sWhat, vDefault) {
 		var oSymbol = mFilterParserSymbols[oToken.id];
 
-		return oSymbol && sWhat in oSymbol ?  oSymbol[sWhat] : vDefault;
+		return oSymbol && sWhat in oSymbol ? oSymbol[sWhat] : vDefault;
 	};
 
 	/**
@@ -390,7 +404,7 @@ sap.ui.define([], function () {
 	 * @returns {object} The syntax tree for the filter
 	 * @throws {SyntaxError} If there is a syntax error
 	 */
-	FilterParser.prototype.parse = function (sFilter) {
+	_FilterParser.prototype.parse = function (sFilter) {
 		var oResult;
 
 		this.init(sFilter);
@@ -402,11 +416,14 @@ sap.ui.define([], function () {
 	//*****************************************************************************************
 	/**
 	 * A parser that is able to parse key predicates.
+	 *
+	 * @alias sap.ui.model.odata.v4.lib._KeyPredicateParser
+	 * @constructor
 	 */
-	function KeyPredicateParser() {
+	function _KeyPredicateParser() {
 	}
 
-	KeyPredicateParser.prototype = Object.create(Parser.prototype);
+	_KeyPredicateParser.prototype = Object.create(_Parser.prototype);
 
 	/**
 	 * Parses a key predicate.
@@ -415,7 +432,7 @@ sap.ui.define([], function () {
 	 * @returns {object} The object representation
 	 * @throws {SyntaxError} If there is a syntax error
 	 */
-	KeyPredicateParser.prototype.parse = function (sKeyPredicate) {
+	_KeyPredicateParser.prototype.parse = function (sKeyPredicate) {
 		var sKey,
 			oKeyProperties = {},
 			sValue;
@@ -441,11 +458,14 @@ sap.ui.define([], function () {
 	/**
 	 * A parser that is able to parse system query strings. It focuses on $select and $expand, all
 	 * other options remain strings, even when embedded into an expand statement.
+	 *
+	 * @alias sap.ui.model.odata.v4.lib._SystemQueryOptionParser
+	 * @constructor
 	 */
-	function SystemQueryOptionParser () {
+	function _SystemQueryOptionParser() {
 	}
 
-	SystemQueryOptionParser.prototype = Object.create(Parser.prototype);
+	_SystemQueryOptionParser.prototype = Object.create(_Parser.prototype);
 
 	/**
 	 * Parses a system query option string.
@@ -454,7 +474,7 @@ sap.ui.define([], function () {
 	 * @returns {object} The object representation
 	 * @throws {SyntaxError} If there is a syntax error
 	 */
-	SystemQueryOptionParser.prototype.parse = function (sOption) {
+	_SystemQueryOptionParser.prototype.parse = function (sOption) {
 		var oResult;
 
 		this.init(sOption);
@@ -473,7 +493,7 @@ sap.ui.define([], function () {
 	 * @returns {object}
 	 *   An object with the value of the starting token as key and the parsed string as value.
 	 */
-	SystemQueryOptionParser.prototype.parseAnythingWithBrackets = function (oStartToken) {
+	_SystemQueryOptionParser.prototype.parseAnythingWithBrackets = function (oStartToken) {
 		var sValue = "",
 			oResult = {},
 			oToken,
@@ -484,7 +504,7 @@ sap.ui.define([], function () {
 		function brackets() {
 			for (;;) {
 				oToken = that.advance();
-				if (!oToken || oToken.id === ';') {
+				if (!oToken || oToken.id === ";") {
 					that.expected("')'", oToken);
 				}
 				sValue += oToken.value;
@@ -521,7 +541,7 @@ sap.ui.define([], function () {
 	 * @returns {object}
 	 *   An object with the described expand structure at the property $expand.
 	 */
-	SystemQueryOptionParser.prototype.parseExpand = function () {
+	_SystemQueryOptionParser.prototype.parseExpand = function () {
 		var oExpand = {},
 			sExpandPath,
 			oQueryOption,
@@ -544,7 +564,7 @@ sap.ui.define([], function () {
 			oExpand[sExpandPath] = vValue;
 		} while (this.advanceIf(","));
 
-		return {"$expand" : oExpand};
+		return {$expand : oExpand};
 	};
 
 	/**
@@ -553,7 +573,7 @@ sap.ui.define([], function () {
 	 * @returns {object}
 	 *   An object with an array of select items at the property $select.
 	 */
-	SystemQueryOptionParser.prototype.parseSelect = function () {
+	_SystemQueryOptionParser.prototype.parseSelect = function () {
 		var sPath,
 			sPrefix,
 			aSelect = [],
@@ -575,7 +595,7 @@ sap.ui.define([], function () {
 			aSelect.push(sPath);
 		} while (this.advanceIf(","));
 
-		return {"$select" : aSelect};
+		return {$select : aSelect};
 	};
 
 	/**
@@ -583,8 +603,8 @@ sap.ui.define([], function () {
 	 *
 	 * @returns {object} An object with "$foo" as key and the parsed value of bar as value.
 	 */
-	SystemQueryOptionParser.prototype.parseSystemQueryOption = function () {
-		var oToken = this.advance('OPTION');
+	_SystemQueryOptionParser.prototype.parseSystemQueryOption = function () {
+		var oToken = this.advance("OPTION");
 
 		switch (oToken.value) {
 			case "$expand":
@@ -634,7 +654,7 @@ sap.ui.define([], function () {
 			return c;
 		}
 
-		for (i = 1; i < sNext.length; ) {
+		for (i = 1; i < sNext.length;) {
 			if (nextChar(true) === "'") {
 				if (nextChar(false) !== "'") {
 					return sNext.slice(0, i);
@@ -675,7 +695,7 @@ sap.ui.define([], function () {
 				if (c === '"') {
 					return sNext.slice(0, i + 1);
 				}
-				bEscaping = c === '\\';
+				bEscaping = c === "\\";
 			}
 		}
 		throw new SyntaxError("Unterminated string at " + iAt + ": " + sOption);
@@ -757,7 +777,6 @@ sap.ui.define([], function () {
 		 * @returns {string} The filter string
 		 */
 		buildFilterString : function (oSyntaxTree) {
-
 			function serialize(oNode, iParentPrecedence) {
 				var sFilter;
 
@@ -823,7 +842,7 @@ sap.ui.define([], function () {
 		 * @returns {object} The syntax tree.
 		 */
 		parseFilter : function (sFilter) {
-			return new FilterParser().parse(sFilter);
+			return new _FilterParser().parse(sFilter);
 		},
 
 		/**
@@ -834,7 +853,7 @@ sap.ui.define([], function () {
 		 * @returns {object} The name/value pairs
 		 */
 		parseKeyPredicate : function (sKeyPredicate) {
-			return new KeyPredicateParser().parse(sKeyPredicate);
+			return new _KeyPredicateParser().parse(sKeyPredicate);
 		},
 
 		/**
@@ -850,7 +869,9 @@ sap.ui.define([], function () {
 		 *
 		 * <b>Example:</b>
 		 *
-		 * <code>$expand=SO_2_BP,SO_2_SOITEM($expand=SOITEM_2_PRODUCT($expand=PRODUCT_2_BP;$select=ID,Name);$select=*;$count=true;$orderby=Name desc)</code> is converted to
+		 * <code>$expand=SO_2_BP,SO_2_SOITEM($expand=SOITEM_2_PRODUCT($expand=PRODUCT_2_BP
+		 * ;$select=ID,Name);$select=*;$count=true;$orderby=Name desc)</code>
+		 * is converted to
 		 * <pre>
 			{
 				"$expand" : {
@@ -877,7 +898,7 @@ sap.ui.define([], function () {
 		 * @throws {SyntaxError} If the string could not be parsed
 		 */
 		parseSystemQueryOption : function (sOption) {
-			return new SystemQueryOptionParser().parse(sOption);
+			return new _SystemQueryOptionParser().parse(sOption);
 		},
 
 		// ABNF rule oDataIdentifier
