@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -22,112 +22,112 @@ sap.ui.define([
 
 		// conversion tables
 		mV2toV4 = {
-			"creatable" : {
-				"property" : "Insertable",
-				"term" : "@Org.OData.Capabilities.V1.InsertRestrictions"
+			creatable : {
+				property : "Insertable",
+				term : "@Org.OData.Capabilities.V1.InsertRestrictions"
 			},
-			"deletable" : {
-				"property" : "Deletable",
-				"term" : "@Org.OData.Capabilities.V1.DeleteRestrictions"
+			deletable : {
+				property : "Deletable",
+				term : "@Org.OData.Capabilities.V1.DeleteRestrictions"
 			},
 			"deletable-path" : {
-				"property" : "Deletable",
-				"term" : "@Org.OData.Capabilities.V1.DeleteRestrictions"
+				property : "Deletable",
+				term : "@Org.OData.Capabilities.V1.DeleteRestrictions"
 			},
 			"field-control" : {
-				"term" : "@com.sap.vocabularies.Common.v1.FieldControl"
+				term : "@com.sap.vocabularies.Common.v1.FieldControl"
 			},
-			"heading" : {
-				"term" : "@com.sap.vocabularies.Common.v1.Heading"
+			heading : {
+				term : "@com.sap.vocabularies.Common.v1.Heading"
 			},
-			"label" : {
-				"term" : "@com.sap.vocabularies.Common.v1.Label"
+			label : {
+				term : "@com.sap.vocabularies.Common.v1.Label"
 			},
-			"precision" : {
-				"term" : "@Org.OData.Measures.V1.Scale"
+			precision : {
+				term : "@Org.OData.Measures.V1.Scale"
 			},
-			"quickinfo" : {
-				"term" : "@com.sap.vocabularies.Common.v1.QuickInfo"
+			quickinfo : {
+				term : "@com.sap.vocabularies.Common.v1.QuickInfo"
 			},
 			"requires-filter" : {
-				"property" : "RequiresFilter",
-				"term" : "@Org.OData.Capabilities.V1.FilterRestrictions"
+				property : "RequiresFilter",
+				term : "@Org.OData.Capabilities.V1.FilterRestrictions"
 			},
-			"searchable" : {
-				"property" : "Searchable",
-				"term" : "@Org.OData.Capabilities.V1.SearchRestrictions"
+			searchable : {
+				property : "Searchable",
+				term : "@Org.OData.Capabilities.V1.SearchRestrictions"
 			},
-			"text" : {
-				"term" : "@com.sap.vocabularies.Common.v1.Text"
+			text : {
+				term : "@com.sap.vocabularies.Common.v1.Text"
 			},
-			"topable" : {
-				"term" : "@Org.OData.Capabilities.V1.TopSupported"
+			topable : {
+				term : "@Org.OData.Capabilities.V1.TopSupported"
 			},
-			"updatable" : {
-				"property" : "Updatable",
-				"term" : "@Org.OData.Capabilities.V1.UpdateRestrictions"
+			updatable : {
+				property : "Updatable",
+				term : "@Org.OData.Capabilities.V1.UpdateRestrictions"
 			},
 			"updatable-path" : {
-				"property" : "Updatable",
-				"term" : "@Org.OData.Capabilities.V1.UpdateRestrictions"
+				property : "Updatable",
+				term : "@Org.OData.Capabilities.V1.UpdateRestrictions"
 			}
 		},
 		mV2toV4ComplexSemantics = {
-			"bday" : {
+			bday : {
 				TermName : "Contact"
 			},
-			"city" : {
+			city : {
 				Path : "adr",
 				TermName : "Contact",
 				V4Attribute : "locality"
 			},
-			"country" : {
+			country : {
 				Path : "adr",
 				TermName : "Contact"
 			},
-			"email" : {
+			email : {
 				Path : "address",
 				TermName : "Contact",
 				V4Attribute : "uri",
 				typeMapping : {
-					"home" : "home",
-					"pref" : "preferred",
-					"work" : "work"
+					home : "home",
+					pref : "preferred",
+					work : "work"
 				},
 				v4EnumType : "com.sap.vocabularies.Communication.v1.ContactInformationType",
 				v4PropertyAnnotation : "@com.sap.vocabularies.Communication.v1.IsEmailAddress"
 			},
-			"familyname" : {
+			familyname : {
 				Path : "n",
 				TermName : "Contact",
 				V4Attribute : "surname"
 			},
-			"givenname" : {
+			givenname : {
 				Path : "n",
 				TermName : "Contact",
 				V4Attribute : "given"
 			},
-			"honorific" : {
+			honorific : {
 				Path : "n",
 				TermName : "Contact",
 				V4Attribute : "prefix"
 			},
-			"middlename" : {
+			middlename : {
 				Path : "n",
 				TermName : "Contact",
 				V4Attribute : "additional"
 			},
-			"name" : {
+			name : {
 				TermName : "Contact",
 				V4Attribute : "fn"
 			},
-			"nickname" : {
+			nickname : {
 				TermName : "Contact"
 			},
-			"note" : {
+			note : {
 				TermName : "Contact"
 			},
-			"org" : {
+			org : {
 				TermName : "Contact"
 			},
 			"org-role" : {
@@ -138,119 +138,119 @@ sap.ui.define([
 				TermName : "Contact",
 				V4Attribute : "orgunit"
 			},
-			"photo" : {
+			photo : {
 				TermName : "Contact"
 			},
-			"pobox" : {
+			pobox : {
 				Path : "adr",
 				TermName : "Contact"
 			},
-			"region" : {
+			region : {
 				Path : "adr",
 				TermName : "Contact"
 			},
-			"street" : {
+			street : {
 				Path : "adr",
 				TermName : "Contact"
 			},
-			"suffix" : {
+			suffix : {
 				Path : "n",
 				TermName : "Contact"
 			},
-			"tel" : {
+			tel : {
 				Path : "tel",
 				TermName : "Contact",
 				V4Attribute : "uri",
 				typeMapping : {
-					"cell" : "cell",
-					"fax" : "fax",
-					"home" : "home",
-					"pref" : "preferred",
-					"video" : "video",
-					"voice" : "voice",
-					"work" : "work"
+					cell : "cell",
+					fax : "fax",
+					home : "home",
+					pref : "preferred",
+					video : "video",
+					voice : "voice",
+					work : "work"
 				},
 				v4EnumType : "com.sap.vocabularies.Communication.v1.PhoneType",
 				v4PropertyAnnotation : "@com.sap.vocabularies.Communication.v1.IsPhoneNumber"
 			},
-			"title" : {
+			title : {
 				TermName : "Contact"
 			},
-			"zip" : {
+			zip : {
 				Path : "adr",
 				TermName : "Contact",
 				V4Attribute : "code"
 			},
 			// event annotations
-			"class" : {
+			class : {
 				TermName : "Event"
 			},
-			"dtend" : {
+			dtend : {
 				TermName : "Event"
 			},
-			"dtstart" : {
+			dtstart : {
 				TermName : "Event"
 			},
-			"duration" : {
+			duration : {
 				TermName : "Event"
 			},
-			"fbtype" : {
+			fbtype : {
 				TermName : "Event"
 			},
-			"location" : {
+			location : {
 				TermName : "Event"
 			},
-			"status" : {
+			status : {
 				TermName : "Event"
 			},
-			"transp" : {
+			transp : {
 				TermName : "Event"
 			},
-			"wholeday" : {
+			wholeday : {
 				TermName : "Event"
 			},
 			// message annotations
-			"body" : {
+			body : {
 				TermName : "Message"
 			},
-			"from" : {
+			from : {
 				TermName : "Message"
 			},
-			"received" : {
+			received : {
 				TermName : "Message"
 			},
-			"sender" : {
+			sender : {
 				TermName : "Message"
 			},
-			"subject" : {
+			subject : {
 				TermName : "Message"
 			},
 			// task annotations
-			"completed" : {
+			completed : {
 				TermName : "Task"
 			},
-			"due" : {
+			due : {
 				TermName : "Task"
 			},
 			"percent-complete" : {
 				TermName : "Task",
 				V4Attribute : "percentcomplete"
 			},
-			"priority" : {
+			priority : {
 				TermName : "Task"
 			}
 		},
 		mV2toV4SimpleSemantics = {
 			// calendar annotations
-			"fiscalyear" : "@com.sap.vocabularies.Common.v1.IsFiscalYear",
-			"fiscalyearperiod" : "@com.sap.vocabularies.Common.v1.IsFiscalYearPeriod",
-			"year" : "@com.sap.vocabularies.Common.v1.IsCalendarYear",
-			"yearmonth" : "@com.sap.vocabularies.Common.v1.IsCalendarYearMonth",
-			"yearmonthday" : "@com.sap.vocabularies.Common.v1.IsCalendarDate",
-			"yearquarter" : "@com.sap.vocabularies.Common.v1.IsCalendarYearQuarter",
-			"yearweek" : "@com.sap.vocabularies.Common.v1.IsCalendarYearWeek",
+			fiscalyear : "@com.sap.vocabularies.Common.v1.IsFiscalYear",
+			fiscalyearperiod : "@com.sap.vocabularies.Common.v1.IsFiscalYearPeriod",
+			year : "@com.sap.vocabularies.Common.v1.IsCalendarYear",
+			yearmonth : "@com.sap.vocabularies.Common.v1.IsCalendarYearMonth",
+			yearmonthday : "@com.sap.vocabularies.Common.v1.IsCalendarDate",
+			yearquarter : "@com.sap.vocabularies.Common.v1.IsCalendarYearQuarter",
+			yearweek : "@com.sap.vocabularies.Common.v1.IsCalendarYearWeek",
 			// OData core annotations
-			"url" : "@Org.OData.Core.V1.IsURL"
+			url : "@Org.OData.Core.V1.IsURL"
 		};
 
 	//*********************************************************************************************
@@ -261,7 +261,7 @@ sap.ui.define([
 	 * Creates an annotatable that is able to consume V2 annotations and set V4 annotations for the
 	 * correct target. It ensures that the target for the annotations is only created when needed.
 	 *
-	 * @param {V2MetadataConverter} oConverter The converter
+	 * @param {sap.ui.model.odata.v4.lib._V2MetadataConverter} oConverter The converter
 	 * @param {string} sTarget
 	 *   The target name to which the V4 annotations shall be added. The target path is constructed
 	 *   from the path of the top annotatable of the stack in oConverter (if there is one yet) and
@@ -296,7 +296,7 @@ sap.ui.define([
 	 * logged for this name afterwards.
 	 *
 	 * @param {string} sName The name
-	 * @returns {string} The value or <code>undefined</code>
+	 * @returns {string|undefined} The value or <code>undefined</code>
 	 */
 	Annotatable.prototype.consume = function (sName) {
 		return this.oConverter.consumeSapAnnotation(sName);
@@ -355,7 +355,7 @@ sap.ui.define([
 	 * Returns the value of the SAP annotation for the given name.
 	 *
 	 * @param {string} sName The name
-	 * @returns {string} The value or <code>undefined</code>
+	 * @returns {string|undefined} The value or <code>undefined</code>
 	 */
 	Annotatable.prototype.peek = function (sName) {
 		return this.oConverter.mSapAnnotations[sName];
@@ -368,9 +368,11 @@ sap.ui.define([
 	/**
 	 * Creates a converter for V2 metadata.
 	 *
+	 * @alias sap.ui.model.odata.v4.lib._V2MetadataConverter
 	 * @constructor
+	 * @extends sap.ui.model.odata.v4.lib._MetadataConverter
 	 */
-	function V2MetadataConverter() {
+	function _V2MetadataConverter() {
 		this.association = null; // the current association
 		this.associations = {}; // maps qualified name -> association
 		this.associationSet = null; // the current associationSet
@@ -393,14 +395,14 @@ sap.ui.define([
 		_MetadataConverter.call(this);
 	}
 
-	V2MetadataConverter.prototype = Object.create(_MetadataConverter.prototype);
+	_V2MetadataConverter.prototype = Object.create(_MetadataConverter.prototype);
 
 	/**
 	 * Collects the element's SAP annotations in the aggregate.
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.collectSapAnnotations = function (oElement) {
+	_V2MetadataConverter.prototype.collectSapAnnotations = function (oElement) {
 		var oAttribute,
 			oAttributeList = oElement.attributes,
 			i, n;
@@ -420,9 +422,9 @@ sap.ui.define([
 	 * Returns the value of the SAP annotation for the given name and removes it from the map.
 	 *
 	 * @param {string} sName The name
-	 * @returns {string} The value or <code>undefined</code>
+	 * @returns {string|undefined} The value or <code>undefined</code>
 	 */
-	V2MetadataConverter.prototype.consumeSapAnnotation = function (sName) {
+	_V2MetadataConverter.prototype.consumeSapAnnotation = function (sName) {
 		var sValue = this.mSapAnnotations[sName];
 
 		delete this.mSapAnnotations[sName];
@@ -435,7 +437,7 @@ sap.ui.define([
 	 * @param {Annotatable} oAnnotatable The annotatable
 	 * @param {string} sName The name of the V2 annotation
 	 */
-	V2MetadataConverter.prototype.convertEntitySetAnnotation = function (oAnnotatable, sName) {
+	_V2MetadataConverter.prototype.convertEntitySetAnnotation = function (oAnnotatable, sName) {
 		var sConflictingV2Annotation, sValue;
 
 		switch (sName) {
@@ -495,7 +497,7 @@ sap.ui.define([
 	 *
 	 * @param {Annotatable} oAnnotatable The annotatable
 	 */
-	V2MetadataConverter.prototype.convertLabel = function (oAnnotatable) {
+	_V2MetadataConverter.prototype.convertLabel = function (oAnnotatable) {
 		oAnnotatable.convert("label", oAnnotatable.consume("label"));
 	};
 
@@ -505,7 +507,7 @@ sap.ui.define([
 	 * @param {Annotatable} oAnnotatable The annotatable
 	 * @param {string} sName The name of the V2 annotation
 	 */
-	V2MetadataConverter.prototype.convertPropertyAnnotation = function (oAnnotatable, sName) {
+	_V2MetadataConverter.prototype.convertPropertyAnnotation = function (oAnnotatable, sName) {
 		var sValue;
 
 		switch (sName) {
@@ -566,7 +568,7 @@ sap.ui.define([
 	 *
 	 * @param {Annotatable} oAnnotatable The annotatable
 	 */
-	V2MetadataConverter.prototype.convertPropertySemanticsAnnotation = function (oAnnotatable) {
+	_V2MetadataConverter.prototype.convertPropertySemanticsAnnotation = function (oAnnotatable) {
 		var oAnnotations,
 			sEnum,
 			oPath,
@@ -583,7 +585,7 @@ sap.ui.define([
 			oAnnotatable.consume("semantics");
 		} else if (oV2toV4ComplexSemantic) {
 			oPath = {
-				"$Path" : this.sPropertyName
+				$Path : this.sPropertyName
 			};
 			oAnnotations = oAnnotatable.oParent.getOrCreateAnnotationRecord(
 				"@com.sap.vocabularies.Communication.v1." + oV2toV4ComplexSemantic.TermName);
@@ -601,6 +603,7 @@ sap.ui.define([
 						sEnum = aValue[1].split("=")[1];
 						sEnum.split(",").forEach(function (sType) {
 							var sTargetType = oV2toV4ComplexSemantic.typeMapping[sType];
+
 							if (sTargetType) {
 								aResult.push(oV2toV4ComplexSemantic.v4EnumType + "/" + sTargetType);
 							} else {
@@ -609,7 +612,7 @@ sap.ui.define([
 							}
 						});
 						if (aResult.length > 0) {
-							oSemantics.type = {"EnumMember" : aResult.join(" ")};
+							oSemantics.type = {EnumMember : aResult.join(" ")};
 						}
 					}
 					oAnnotations[oV2toV4ComplexSemantic.Path] = [oSemantics];
@@ -624,11 +627,10 @@ sap.ui.define([
 	};
 
 	/**
-	 * Finalizes the conversion after having traversed the XML completely.
-	 *
 	 * @override
+	 * @see sap.ui.model.odata.v4.lib._MetadataConverter#finalize
 	 */
-	V2MetadataConverter.prototype.finalize = function () {
+	_V2MetadataConverter.prototype.finalize = function () {
 		this.result.$Version = "4.0"; // The result of the conversion is a V4 streamlined JSON
 
 		this.setDefaultEntityContainer();
@@ -648,7 +650,7 @@ sap.ui.define([
 	 *   Maps annotatable path to a map of V4 annotations; V2 annotations are merged into this
 	 *   object
 	 */
-	V2MetadataConverter.prototype.mergeAnnotations = function (mConvertedV2Annotations,
+	_V2MetadataConverter.prototype.mergeAnnotations = function (mConvertedV2Annotations,
 			mV4Annotations) {
 		var sAnnotatablePath;
 
@@ -666,10 +668,10 @@ sap.ui.define([
 	/**
 	 * Post-processing of an Schema element.
 	 *
-	 * @param {Element} oElement The element
-	 * @param {any[]} aResult The results from child elements
+	 * @param {Element} _oElement The element
+	 * @param {any[]} _aResult The results from child elements
 	 */
-	V2MetadataConverter.prototype.postProcessSchema = function (oElement, aResult) {
+	_V2MetadataConverter.prototype.postProcessSchema = function (_oElement, _aResult) {
 		var mAnnotations,
 			oEntityContainer,
 			sEntityContainerName,
@@ -708,7 +710,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processAssociation = function (oElement) {
+	_V2MetadataConverter.prototype.processAssociation = function (oElement) {
 		var sName = this.namespace + oElement.getAttribute("Name");
 
 		this.associations[sName] = this.association = {
@@ -722,7 +724,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processAssociationEnd = function (oElement) {
+	_V2MetadataConverter.prototype.processAssociationEnd = function (oElement) {
 		var sName = oElement.getAttribute("Role");
 
 		this.association.roles[sName] = {
@@ -737,7 +739,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processAssociationSet = function (oElement) {
+	_V2MetadataConverter.prototype.processAssociationSet = function (oElement) {
 		var oAssociationSet = {
 				associationName : this.resolveAlias(oElement.getAttribute("Association")),
 				ends : [],
@@ -757,7 +759,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processAssociationSetEnd = function (oElement) {
+	_V2MetadataConverter.prototype.processAssociationSetEnd = function (oElement) {
 		this.associationSet.ends.push({
 			entitySetName : oElement.getAttribute("EntitySet"),
 			roleName : oElement.getAttribute("Role")
@@ -769,8 +771,8 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processComplexType = function (oElement) {
-		this.processType(oElement, {"$kind" : "ComplexType"});
+	_V2MetadataConverter.prototype.processComplexType = function (oElement) {
+		this.processType(oElement, {$kind : "ComplexType"});
 	};
 
 	/**
@@ -778,7 +780,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processDataServices = function (oElement) {
+	_V2MetadataConverter.prototype.processDataServices = function (oElement) {
 		if (oElement.getAttributeNS(sMicrosoftNamespace, "DataServiceVersion") !== "2.0") {
 			throw new Error(this.url + ": expected DataServiceVersion=\"2.0\": "
 				+ serializeSingleElement(oElement));
@@ -790,7 +792,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processDependent = function (oElement) {
+	_V2MetadataConverter.prototype.processDependent = function (oElement) {
 		var oConstraint = this.association.referentialConstraint;
 
 		this.constraintRole = oConstraint.dependent = {
@@ -805,7 +807,8 @@ sap.ui.define([
 	 * @param {Element} oElement The element
 	 * @param {function} [fnProcessor] The processor
 	 */
-	V2MetadataConverter.prototype.processElement = function (oElement, fnProcessor) {
+	// @override sap.ui.model.odata.v4.lib._MetadataConverter#processElement
+	_V2MetadataConverter.prototype.processElement = function (oElement, fnProcessor) {
 		this.collectSapAnnotations(oElement);
 		if (fnProcessor) {
 			fnProcessor.call(this, oElement);
@@ -818,11 +821,11 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processEntityContainer = function (oElement) {
+	_V2MetadataConverter.prototype.processEntityContainer = function (oElement) {
 		var sQualifiedName = this.namespace + oElement.getAttribute("Name");
 
 		this.mEntityContainersOfSchema[sQualifiedName]
-			= this.entityContainer = {"$kind" : "EntityContainer"};
+			= this.entityContainer = {$kind : "EntityContainer"};
 		this.addToResult(sQualifiedName, this.entityContainer);
 		if (oElement.getAttributeNS(sMicrosoftNamespace, "IsDefaultEntityContainer") === "true") {
 			this.defaultEntityContainer = sQualifiedName;
@@ -835,7 +838,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processEntitySet = function (oElement) {
+	_V2MetadataConverter.prototype.processEntitySet = function (oElement) {
 		var oAnnotatable,
 			sName = oElement.getAttribute("Name");
 
@@ -862,7 +865,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processEntityType = function (oElement) {
+	_V2MetadataConverter.prototype.processEntityType = function (oElement) {
 		var oType = {
 				$kind : "EntityType"
 			},
@@ -870,8 +873,8 @@ sap.ui.define([
 
 		this.processType(oElement, oType);
 		this.processAttributes(oElement, oType, {
-			"Abstract" : this.setIfTrue,
-			"BaseType" : function (sType) {
+			Abstract : this.setIfTrue,
+			BaseType : function (sType) {
 				return sType ? that.resolveAlias(sType) : undefined;
 			}
 		});
@@ -884,7 +887,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processEntityTypeKeyPropertyRef = function (oElement) {
+	_V2MetadataConverter.prototype.processEntityTypeKeyPropertyRef = function (oElement) {
 		var sName = oElement.getAttribute("Name");
 
 		this.getOrCreateArray(this.type, "$Key").push(sName);
@@ -897,18 +900,18 @@ sap.ui.define([
 	 * @param {Element} oElement The element
 	 * @param {object} oResult The result object to fill
 	 */
-	V2MetadataConverter.prototype.processFacetAttributes = function (oElement, oResult) {
+	_V2MetadataConverter.prototype.processFacetAttributes = function (oElement, oResult) {
 		var that = this;
 
 		this.processAttributes(oElement, oResult, {
-			"DefaultValue" : this.setValue,
-			"MaxLength" :  function (sValue) {
+			DefaultValue : this.setValue,
+			MaxLength : function (sValue) {
 				return sValue === "Max" ? undefined : that.setNumber(sValue);
 			},
-			"Nullable" : this.setIfFalse,
-			"Precision" : this.setNumber,
-			"Scale" :  this.setNumber,
-			"Unicode" : this.setIfFalse
+			Nullable : this.setIfFalse,
+			Precision : this.setNumber,
+			Scale : this.setNumber,
+			Unicode : this.setIfFalse
 		});
 		if (oElement.getAttribute("FixedLength") === "false") {
 			oResult.$Scale = "variable";
@@ -920,7 +923,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processFunctionImport = function (oElement) {
+	_V2MetadataConverter.prototype.processFunctionImport = function (oElement) {
 		var sAnnotationActionFor,
 			sHttpMethod = oElement.getAttributeNS(sMicrosoftNamespace, "HttpMethod"),
 			sKind = sHttpMethod !== "GET" ? "Action" : "Function",
@@ -938,7 +941,7 @@ sap.ui.define([
 
 		oOperationImport["$" + sKind] = sQualifiedName;
 		this.processAttributes(oElement, oOperationImport, {
-			"EntitySet" : this.setValue
+			EntitySet : this.setValue
 		});
 		if (sReturnType) {
 			oOperation.$ReturnType = oReturnType = {};
@@ -962,9 +965,9 @@ sap.ui.define([
 			if (sAnnotationActionFor) {
 				oOperation.$IsBound = true;
 				oOperation.$Parameter = [{
-					"$Name" : null,
-					"$Nullable" : false,
-					"$Type" : this.resolveAlias(sAnnotationActionFor)
+					$Name : null,
+					$Nullable : false,
+					$Type : this.resolveAlias(sAnnotationActionFor)
 				}];
 				this.aBoundOperations.push(oOperation);
 				this.consumeSapAnnotation("applicable-path");
@@ -992,7 +995,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processParameter = function (oElement) {
+	_V2MetadataConverter.prototype.processParameter = function (oElement) {
 		var sLabel,
 			oOperation = this.oOperation,
 			oParameter = {
@@ -1015,7 +1018,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processPrincipal = function (oElement) {
+	_V2MetadataConverter.prototype.processPrincipal = function (oElement) {
 		var oConstraint = this.association.referentialConstraint;
 
 		this.constraintRole = oConstraint.principal = {
@@ -1026,9 +1029,9 @@ sap.ui.define([
 	/**
 	 * Processes an End element below an Association element.
 	 *
-	 * @param {Element} oElement The element
+	 * @param {Element} _oElement The element
 	 */
-	V2MetadataConverter.prototype.processReferentialConstraint = function (oElement) {
+	_V2MetadataConverter.prototype.processReferentialConstraint = function (_oElement) {
 		this.association.referentialConstraint = {};
 	};
 
@@ -1037,7 +1040,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processReferentialConstraintPropertyRef = function (oElement) {
+	_V2MetadataConverter.prototype.processReferentialConstraintPropertyRef = function (oElement) {
 		this.constraintRole.propertyRef = oElement.getAttribute("Name");
 	};
 
@@ -1046,11 +1049,11 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processSchema = function (oElement) {
+	_V2MetadataConverter.prototype.processSchema = function (oElement) {
 		var sSchemaVersion = this.consumeSapAnnotation("schema-version");
 
 		this.namespace = oElement.getAttribute("Namespace") + ".";
-		this.schema = {"$kind" : "Schema"};
+		this.schema = {$kind : "Schema"};
 		this.addToResult(this.namespace, this.schema);
 		if (sSchemaVersion) {
 			this.schema["@Org.Odata.Core.V1.SchemaVersion"] = sSchemaVersion;
@@ -1063,7 +1066,7 @@ sap.ui.define([
 	 * @param {Element} oElement The element
 	 * @param {object} oType The initial typed result object
 	 */
-	V2MetadataConverter.prototype.processType = function (oElement, oType) {
+	_V2MetadataConverter.prototype.processType = function (oElement, oType) {
 		var sQualifiedName = this.namespace + oElement.getAttribute("Name");
 
 		this.sTypeName = sQualifiedName;
@@ -1079,7 +1082,7 @@ sap.ui.define([
 	 * @param {string} sType The type attribute from the Element
 	 * @param {object} oProperty The property attribute in the JSON
 	 */
-	V2MetadataConverter.prototype.processTypedCollection = function (sType, oProperty) {
+	_V2MetadataConverter.prototype.processTypedCollection = function (sType, oProperty) {
 		var aMatches = this.rCollection.exec(sType);
 
 		if (aMatches) {
@@ -1087,7 +1090,7 @@ sap.ui.define([
 			sType = aMatches[1];
 		}
 		// according to the XSD simple types do not (necessarily) have the namespace "Edm."
-		if (sType.indexOf(".") < 0) {
+		if (!sType.includes(".")) {
 			sType = "Edm." + sType;
 		}
 		switch (sType) {
@@ -1119,7 +1122,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processTypeNavigationProperty = function (oElement) {
+	_V2MetadataConverter.prototype.processTypeNavigationProperty = function (oElement) {
 		var sCreatable = this.consumeSapAnnotation("creatable"),
 			sCreatablePath = this.consumeSapAnnotation("creatable-path"),
 			sFilterable = this.consumeSapAnnotation("filterable"),
@@ -1159,7 +1162,7 @@ sap.ui.define([
 		this.v2annotatable(sName);
 
 		if (sCreatable) {
-			oNavigationPropertyPath = {"$NavigationPropertyPath" : sName};
+			oNavigationPropertyPath = {$NavigationPropertyPath : sName};
 			if (sCreatablePath) {
 				Log.warning("Inconsistent metadata in '" + this.url + "'",
 					"Use either 'sap:creatable' or 'sap:creatable-path' at navigation property '"
@@ -1169,10 +1172,10 @@ sap.ui.define([
 			}
 		} else if (sCreatablePath) {
 			oNavigationPropertyPath = {
-				"$If" : [{
-					"$Not" : {"$Path" : sCreatablePath}
+				$If : [{
+					$Not : {$Path : sCreatablePath}
 				}, {
-					"$NavigationPropertyPath" : sName
+					$NavigationPropertyPath : sName
 				}]
 			};
 		}
@@ -1182,11 +1185,11 @@ sap.ui.define([
 		}
 		if (sFilterable === "false") {
 			oFilterablePath = {
-				"NavigationProperty" : {
-					"$NavigationPropertyPath" : sName
+				NavigationProperty : {
+					$NavigationPropertyPath : sName
 				},
-				"FilterRestrictions" : {
-					"Filterable" : false
+				FilterRestrictions : {
+					Filterable : false
 				}
 			};
 			pushPropertyPath("@Org.OData.Capabilities.V1.NavigationRestrictions",
@@ -1199,14 +1202,14 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.processTypeProperty = function (oElement) {
+	_V2MetadataConverter.prototype.processTypeProperty = function (oElement) {
 		var oAnnotatable,
 			sEnumMember,
 			sFilterRestriction,
 			vHere,
 			sName = oElement.getAttribute("Name"),
 			oProperty = {
-				"$kind" : "Property"
+				$kind : "Property"
 			},
 			that = this;
 
@@ -1222,7 +1225,7 @@ sap.ui.define([
 					that.mEntityType2EntitySetAnnotation, that.sTypeName);
 				vHere = that.getOrCreateObject(vHere, sTerm);
 				vHere = that.getOrCreateArray(vHere, sProperty);
-				vHere.push({"$PropertyPath" : sName});
+				vHere.push({$PropertyPath : sName});
 			} else {
 				Log.warning("Unsupported SAP annotation at a complex type in '"
 					+ that.url + "'", "sap:" + sAnnotation + " at property '" + oAnnotatable.sPath
@@ -1272,11 +1275,11 @@ sap.ui.define([
 					vHere = this.getOrCreateArray(
 						vHere, "@com.sap.vocabularies.Common.v1.FilterExpressionRestrictions");
 					vHere.push({
-						"AllowedExpressions" : {
-							"EnumMember" : "com.sap.vocabularies.Common.v1.FilterExpressionType/"
+						AllowedExpressions : {
+							EnumMember : "com.sap.vocabularies.Common.v1.FilterExpressionType/"
 								+ sEnumMember
 						},
-						"Property" : {"$PropertyPath" : sName}
+						Property : {$PropertyPath : sName}
 					});
 				} else {
 					Log.warning("Unsupported SAP annotation at a complex type in '"
@@ -1298,7 +1301,7 @@ sap.ui.define([
 	/**
 	 * Post-processing of all bound operations: key properties are removed from parameters.
 	 */
-	V2MetadataConverter.prototype.processBoundOperations = function () {
+	_V2MetadataConverter.prototype.processBoundOperations = function () {
 		var that = this;
 
 		this.aBoundOperations.forEach(function (oOperation) {
@@ -1322,7 +1325,7 @@ sap.ui.define([
 	 * sap:semantics="currency-code". The unit property can be in a different type thus the
 	 * conversion can only happen in pass 3.
 	 */
-	V2MetadataConverter.prototype.processUnitConversion = function () {
+	_V2MetadataConverter.prototype.processUnitConversion = function () {
 		var that = this;
 
 		Object.keys(this.mProperty2Unit).forEach(function (sPropertyPath) {
@@ -1365,7 +1368,7 @@ sap.ui.define([
 				that.result[_Helper.namespace(sPropertyPath) + "."], "$Annotations");
 			vHere = that.getOrCreateObject(vHere, sPropertyPath);
 			if (!(sUnitAnnotation in vHere)) { // existing V4 annotations won't be overridden
-				vHere[sUnitAnnotation] = {"$Path" : sUnitPath};
+				vHere[sUnitAnnotation] = {$Path : sUnitPath};
 			}
 		});
 	};
@@ -1394,7 +1397,7 @@ sap.ui.define([
 	/**
 	 * Sets $EntityContainer to the default entity container (or the only one).
 	 */
-	V2MetadataConverter.prototype.setDefaultEntityContainer = function () {
+	_V2MetadataConverter.prototype.setDefaultEntityContainer = function () {
 		var sDefaultEntityContainer = this.defaultEntityContainer,
 			aEntityContainers,
 			oResult = this.result;
@@ -1417,7 +1420,7 @@ sap.ui.define([
 	 * from the associations. Iterates over the aggregated association set and tries to create
 	 * navigation property bindings for both directions.
 	 */
-	V2MetadataConverter.prototype.updateNavigationPropertiesAndCreateBindings = function () {
+	_V2MetadataConverter.prototype.updateNavigationPropertiesAndCreateBindings = function () {
 		var that = this;
 
 		this.navigationProperties.forEach(function (oNavigationPropertyData) {
@@ -1484,7 +1487,7 @@ sap.ui.define([
 	 * @returns {Annotatable}
 	 *   The created annotatable
 	 */
-	V2MetadataConverter.prototype.v2annotatable = function (sName, fnProcessV2Annotatable) {
+	_V2MetadataConverter.prototype.v2annotatable = function (sName, fnProcessV2Annotatable) {
 		var oAnnotatable = new Annotatable(this, sName);
 
 		this.oAnnotatable = oAnnotatable;
@@ -1503,7 +1506,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	V2MetadataConverter.prototype.warnUnsupportedSapAnnotations = function (oElement) {
+	_V2MetadataConverter.prototype.warnUnsupportedSapAnnotations = function (oElement) {
 		Object.keys(this.mSapAnnotations).forEach(function (sName) {
 			Log.warning("Unsupported annotation 'sap:" + sName + "'",
 				serializeSingleElement(oElement), sClassName);
@@ -1522,84 +1525,84 @@ sap.ui.define([
 		$$.sRootNamespace = sEdmxNamespace;
 
 		$$.oAliasConfig = {
-			"Reference" : {
+			Reference : {
 				__xmlns : _MetadataConverter.sEdmxNamespace,
-				"Include" : {
+				Include : {
 					__processor : $$.processAlias
 				}
 			},
-			"DataServices" : {
-				"Schema" : {
+			DataServices : {
+				Schema : {
 					__processor : $$.processAlias
 				}
 			}
 		};
 
 		oStructuredTypeConfig = {
-			"NavigationProperty" : {
+			NavigationProperty : {
 				__processor : $$.processTypeNavigationProperty
 			},
-			"Property" : {
+			Property : {
 				__processor : $$.processTypeProperty
 			}
 		};
 
 		$$.oFullConfig = {
 			__include : [$$.oReferenceInclude],
-			"DataServices" : {
+			DataServices : {
 				__processor : $$.processDataServices,
-				"Schema" : {
+				Schema : {
 					__postProcessor : $$.postProcessSchema,
 					__processor : $$.processSchema,
 					__include : [$$.oAnnotationsConfig],
-					"Association" : {
+					Association : {
 						__processor : $$.processAssociation,
-						"End" : {
+						End : {
 							__processor : $$.processAssociationEnd
 						},
-						"ReferentialConstraint" : {
+						ReferentialConstraint : {
 							__processor : $$.processReferentialConstraint,
-							"Dependent" : {
+							Dependent : {
 								__processor : $$.processDependent,
-								"PropertyRef" : {
+								PropertyRef : {
 									__processor : $$.processReferentialConstraintPropertyRef
 								}
 							},
-							"Principal" : {
+							Principal : {
 								__processor : $$.processPrincipal,
-								"PropertyRef" : {
+								PropertyRef : {
 									__processor : $$.processReferentialConstraintPropertyRef
 								}
 							}
 						}
 					},
-					"ComplexType" : {
+					ComplexType : {
 						__processor : $$.processComplexType,
 						__include : [oStructuredTypeConfig]
 					},
-					"EntityContainer" : {
+					EntityContainer : {
 						__processor : $$.processEntityContainer,
-						"AssociationSet" : {
+						AssociationSet : {
 							__processor : $$.processAssociationSet,
-							"End" : {
+							End : {
 								__processor : $$.processAssociationSetEnd
 							}
 						},
-						"EntitySet" : {
+						EntitySet : {
 							__processor : $$.processEntitySet
 						},
-						"FunctionImport" : {
+						FunctionImport : {
 							__processor : $$.processFunctionImport,
-							"Parameter" : {
+							Parameter : {
 								__processor : $$.processParameter
 							}
 						}
 					},
-					"EntityType" : {
+					EntityType : {
 						__processor : $$.processEntityType,
 						__include : [oStructuredTypeConfig],
-						"Key" : {
-							"PropertyRef" : {
+						Key : {
+							PropertyRef : {
 								__processor : $$.processEntityTypeKeyPropertyRef
 							}
 						}
@@ -1607,8 +1610,7 @@ sap.ui.define([
 				}
 			}
 		};
+	})(_V2MetadataConverter.prototype);
 
-	})(V2MetadataConverter.prototype);
-
-	return V2MetadataConverter;
-}, /* bExport= */false);
\ No newline at end of file
+	return _V2MetadataConverter;
+}, /* bExport= */false);
