@@ -1,36 +1,42 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([
 	"sap/ui/thirdparty/jquery",
+	"sap/ui/fl/write/api/FieldExtensibility",
 	"sap/ui/fl/Utils",
 	"sap/ui/fl/Layer",
 	"sap/ui/fl/LayerUtils",
-	"sap/ui/fl/registry/Settings",
 	"sap/ui/dt/OverlayUtil",
 	"sap/ui/dt/DOMUtil",
+	"sap/ui/dt/ElementUtil",
+	"sap/ui/dt/MetadataPropagationUtil",
+	"sap/ui/rta/util/hasStableId",
 	"sap/m/MessageBox",
 	"sap/ui/rta/util/BindingsExtractor",
-	"sap/base/Log",
-	"sap/base/util/UriParameters",
-	"sap/base/util/restricted/_omit"
+	"sap/base/util/restricted/_omit",
+	"sap/ui/model/json/JSONModel",
+	"sap/ui/core/Fragment"
 ],
 function(
 	jQuery,
+	FieldExtensibility,
 	FlexUtils,
 	Layer,
 	FlexLayerUtils,
-	Settings,
 	OverlayUtil,
 	DOMUtil,
+	ElementUtil,
+	MetadataPropagationUtil,
+	hasStableId,
 	MessageBox,
 	BindingsExtractor,
-	Log,
-	UriParameters,
-	_omit
+	_omit,
+	JSONModel,
+	Fragment
 ) {
 	"use strict";
 
@@ -40,7 +46,7 @@ function(
 	 * @class Utility functionality to work with controls, e.g. iterate through aggregations, find parents, etc.
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 *
 	 * @private
 	 * @static
@@ -80,25 +86,6 @@ function(
 		}
 	};
 
-	/**
-	 * Utility function to check if extensibility is enabled in the current system
-	 *
-	 * @param {sap.ui.core.Control} oControl - Control to be checked
-	 * @returns {Promise} resolves a boolean
-	 */
-	Utils.isExtensibilityEnabledInSystem = function(oControl) {
-		var sComponentName = FlexUtils.getComponentClassName(oControl);
-		if (!sComponentName || sComponentName === "") {
-			return Promise.resolve(false);
-		}
-		return Settings.getInstance(sComponentName).then(function(oSettings) {
-			if (oSettings.isModelS) {
-				return oSettings.isModelS();
-			}
-			return false;
-		});
-	};
-
 	/**
 	 * Utility function to check if the OData service is updated in the meantime
 	 *
@@ -106,108 +93,22 @@ function(
 	 * @returns {Promise} resolves if service is up to date, rejects otherwise
 	 */
 	Utils.isServiceUpToDate = function(oControl) {
-		return this.isExtensibilityEnabledInSystem(oControl)
-
-		.then(function(bEnabled) {
+		return FieldExtensibility.isExtensibilityEnabled(oControl).then(function(bEnabled) {
 			if (bEnabled) {
-				return new Promise(function(fnResolve, fnReject) {
-					sap.ui.require([
-						"sap/ui/fl/fieldExt/Access"
-					], function(Access) {
-						var oModel = oControl.getModel();
-						if (oModel) {
-							var bServiceOutdated = Access.isServiceOutdated(oModel.sServiceUrl);
-							if (bServiceOutdated) {
-								Access.setServiceValid(oModel.sServiceUrl);
-								//needs FLP to trigger UI restart popup
-								sap.ui.getCore().getEventBus().publish("sap.ui.core.UnrecoverableClientStateCorruption", "RequestReload", {});
-								return fnReject();
-							}
+				var oModel = oControl.getModel();
+				if (oModel && oModel.sServiceUrl) {
+					return FieldExtensibility.isServiceOutdated(oModel.sServiceUrl).then(function(bServiceOutdated) {
+						if (bServiceOutdated) {
+							FieldExtensibility.setServiceValid(oModel.sServiceUrl);
+							//needs FLP to trigger UI restart popup
+							sap.ui.getCore().getEventBus().publish("sap.ui.core.UnrecoverableClientStateCorruption", "RequestReload", {});
 						}
-						return fnResolve();
 					});
-				});
+				}
 			}
 		});
 	};
 
-	/**
-	 * Fetching entity metadata by specified path.
-	 * @param {sap.ui.model.Model} oModel - Model
-	 * @param {string} sPath Path to resolve
-	 * @returns {object|null} Plain object with entity description
-	 */
-	function getEntityTypeByPath (oModel, sPath) {
-		return oModel.oMetadata && oModel.oMetadata._getEntityTypeByPath(sPath);
-	}
-	/**
-	 * Get the entity type based on the binding of a control
-	 *
-	 * @param {sap.ui.core.Element} oElement - Any Object
-	 * @param {sap.ui.model.odata.ODataModel} oModel - Data model
-	 * @returns{object} Entity type without namespace
-	 */
-	function getBoundEntityType(oElement, oModel) {
-		oModel || (oModel = oElement.getModel());
-
-		var oBindingContext = oElement.getBindingContext();
-
-		if (oBindingContext) {
-			return getEntityTypeByPath(oModel, oBindingContext.getPath()) || {};
-		}
-		return {};
-	}
-	/**
-	 * Utility function to check via backend calls if the custom field button shall be enabled or not
-	 *
-	 * @param {sap.ui.core.Control} oControl - Control to be checked
-	 * @returns {Promise} Returns <boolean> value - true if CustomFieldCreation functionality is to be enabled, false if not
-	 */
-	Utils.isCustomFieldAvailable = function(oControl) {
-		return this.isExtensibilityEnabledInSystem(oControl)
-
-		.then(function(bShowCreateExtFieldButton) {
-			if (!bShowCreateExtFieldButton || !oControl.getModel()) {
-				return false;
-			}
-
-			return new Promise(function(fnResolve, fnReject) {
-				sap.ui.require([
-					"sap/ui/fl/fieldExt/Access"
-				], function(Access) {
-					var sServiceUrl = oControl.getModel().sServiceUrl;
-					var sEntityType = getBoundEntityType(oControl).name;
-					var $Deferred;
-					try {
-						$Deferred = Access.getBusinessContexts(sServiceUrl, sEntityType);
-					} catch (oError) {
-						Log.error("exception occured in sap.ui.fl.fieldExt.Access.getBusinessContexts", oError);
-						fnResolve(false);
-					}
-
-					return Promise.resolve($Deferred)
-					.then(function(oResult) {
-						if (oResult && Array.isArray(oResult.BusinessContexts) && oResult.BusinessContexts.length > 0) {
-							oResult.EntityType = sEntityType;
-							return fnResolve(oResult);
-						}
-						return fnResolve(false);
-					})
-					.catch(function(oError) {
-						if (oError) {
-							if (Array.isArray(oError.errorMessages)) {
-								for (var i = 0; i < oError.errorMessages.length; i++) {
-									Log.error(oError.errorMessages[i].text);
-								}
-							}
-						}
-						return fnResolve(false);
-					});
-				}, fnReject);
-			});
-		});
-	};
-
 	/**
 	 * Opens a confirmation dialog indicating mandatory fields if necessary.
 	 *
@@ -224,13 +125,13 @@ function(
 
 				// create some dummy JSON data and create a Model from it
 				var data = {
-					messageText : sText,
-					titleText : sTitle,
-					icon : "sap-icon://question-mark",
-					removeText : oTextResources.getText("BTN_FREP_REMOVE"),
-					cancelText : oTextResources.getText("BTN_FREP_CANCEL")
+					messageText: sText,
+					titleText: sTitle,
+					icon: "sap-icon://question-mark",
+					removeText: oTextResources.getText("BTN_FREP_REMOVE"),
+					cancelText: oTextResources.getText("BTN_FREP_CANCEL")
 				};
-				var oModel = new sap.ui.model.json.JSONModel();
+				var oModel = new JSONModel();
 				oModel.setData(data);
 
 				var oFragmentDialog;
@@ -244,11 +145,11 @@ function(
 
 				// create a controller for the action in the Dialog
 				var oFragmentController = {
-					removeField : function() {
+					removeField: function() {
 						fnCleanUp();
 						resolve(true);
 					},
-					closeDialog : function() {
+					closeDialog: function() {
 						fnCleanUp();
 						resolve(false);
 					}
@@ -256,11 +157,19 @@ function(
 
 				// instantiate the Fragment if not done yet
 				if (!oFragmentDialog) {
-					oFragmentDialog = sap.ui.xmlfragment("sap.ui.rta.view.RemoveElementDialog", oFragmentController);
-					oFragmentDialog.setModel(oModel);
+					Fragment.load({
+						name: "sap.ui.rta.view.RemoveElementDialog",
+						controller: oFragmentController
+					}).then(function(oFragmentDialogT) {
+						oFragmentDialog = oFragmentDialogT;
+						oFragmentDialog.setModel(oModel);
+						oFragmentDialog.addStyleClass(Utils.getRtaStyleClassName());
+						oFragmentDialog.open();
+					});
+				} else {
+					oFragmentDialog.addStyleClass(Utils.getRtaStyleClassName());
+					oFragmentDialog.open();
 				}
-				oFragmentDialog.addStyleClass(Utils.getRtaStyleClassName());
-				oFragmentDialog.open();
 			}
 		);
 	};
@@ -470,16 +379,6 @@ function(
 		return (oParentControl.getId() + "_" + sEntityType + "_" + sBindingPath).replace("/", "_");
 	};
 
-
-	/**
-	 * Allow window.open to be stubbed in tests
-	 *
-	 * @param {string} sUrl - url string
-	 */
-	Utils.openNewWindow = function(sUrl) {
-		window.open(sUrl, "_blank");
-	};
-
 	/**
 	 * Function to find the binding paths of a given UI5 Element
 	 *
@@ -492,17 +391,24 @@ function(
 		if (oElement.mBindingInfos) {
 			for (var oInfo in oElement.mBindingInfos) {
 				var sPath = oElement.mBindingInfos[oInfo].parts[0].path
-						? oElement.mBindingInfos[oInfo].parts[0].path
-						: "";
+					? oElement.mBindingInfos[oInfo].parts[0].path
+					: "";
 				sPath = sPath.split("/")[sPath.split("/").length - 1];
 				aPaths[sPath] = {
-					valueProperty : oInfo
+					valueProperty: oInfo
 				};
 			}
 		}
 		return aPaths;
 	};
 
+	Utils.isOriginalFioriToolbarAccessible = function () {
+		var oRenderer = Utils.getFiori2Renderer();
+		return oRenderer
+			&& oRenderer.getRootControl
+			&& oRenderer.getRootControl().getOUnifiedShell().getHeader();
+	};
+
 	/**
 	 * Function to get the Fiori2 Renderer
 	 *
@@ -530,11 +436,11 @@ function(
 		for (var sSourceProperty in mSource) {
 			if (mSource.hasOwnProperty(sSourceProperty)) {
 				if (fnCustomizer(
-						mDestination[sSourceProperty],
-						mSource[sSourceProperty],
-						sSourceProperty,
-						mDestination,
-						mSource)
+					mDestination[sSourceProperty],
+					mSource[sSourceProperty],
+					sSourceProperty,
+					mDestination,
+					mSource)
 				) {
 					mDestination[sSourceProperty] = mSource[sSourceProperty];
 				}
@@ -579,7 +485,7 @@ function(
 		.then(function(oResourceBundle) {
 			mPropertyBag = mPropertyBag || {};
 			var sMessage = oResourceBundle.getText(sMessageKey, mPropertyBag.error ? [mPropertyBag.error.userMessage || mPropertyBag.error.message || mPropertyBag.error] : undefined);
-			var sTitle = oResourceBundle.getText(mPropertyBag.titleKey);
+			var sTitle = mPropertyBag.titleKey && oResourceBundle.getText(mPropertyBag.titleKey);
 
 			var mOptions = _omit(mPropertyBag, ["titleKey", "error"]);
 			mOptions.title = sTitle;
@@ -653,5 +559,71 @@ function(
 		}, {});
 	};
 
+	/**
+	 * Checks drop ability for aggregation overlays
+	 * @param {sap.ui.dt.Overlay} oAggregationOverlay Aggregation overlay object
+	 * @param {sap.ui.dt.ElementOverlay} oMovedOverlay Overlay being moved/added
+	 * @param {sap.ui.rta.Plugin} oPlugin RTA plugin calling this method
+	 * @param {boolean} [bOverlayNotInDom] Flag defining if overlay is not in DOM
+	 * @return {Promise.<boolean>} Promise with true value if overlay can be added to the aggregation overlay or false value if not.
+	 * @override
+	 */
+	Utils.checkTargetZone = function(oAggregationOverlay, oMovedOverlay, oPlugin, bOverlayNotInDom) {
+		function fnHasMoveAction(oAggregationOverlay, oElement, oRelevantContainer, oPlugin) {
+			var oAggregationDTMetadata = oAggregationOverlay.getDesignTimeMetadata();
+			var oMoveAction = oAggregationDTMetadata.getAction("move", oElement);
+			if (!oMoveAction) {
+				return Promise.resolve(false);
+			}
+			// moveChangeHandler information is always located on the relevant container
+			return oPlugin.hasChangeHandler(oMoveAction.changeType, oRelevantContainer);
+		}
+
+		return ElementUtil.checkTargetZone(oAggregationOverlay, oMovedOverlay, bOverlayNotInDom)
+			.then(function(bTargetZone) {
+				if (!bTargetZone) {
+					return false;
+				}
+
+				var oMovedElement = oMovedOverlay.getElement();
+				var oTargetOverlay = oAggregationOverlay.getParent();
+				var oMovedRelevantContainer = oMovedOverlay.getRelevantContainer();
+
+				// the element or the parent overlay might be destroyed or not available
+				if (!oMovedElement || !oTargetOverlay) {
+					return false;
+				}
+
+				var oTargetElement = oTargetOverlay.getElement();
+				var oAggregationDtMetadata = oAggregationOverlay.getDesignTimeMetadata();
+
+				// determine target relevantContainer
+				var vTargetRelevantContainerAfterMove = MetadataPropagationUtil.getRelevantContainerForPropagation(oAggregationDtMetadata.getData(), oMovedElement);
+				vTargetRelevantContainerAfterMove = vTargetRelevantContainerAfterMove || oTargetElement;
+
+				// check for same relevantContainer
+				if (
+					!oMovedRelevantContainer
+					|| !vTargetRelevantContainerAfterMove
+					|| !hasStableId(oTargetOverlay)
+					|| oMovedRelevantContainer !== vTargetRelevantContainerAfterMove
+				) {
+					return false;
+				}
+
+				// check if binding context is the same
+				if (
+					// binding context is not relevant if the element is being moved inside its parent
+					oMovedOverlay.getParent().getElement() !== oTargetElement
+					&& !Utils.checkSourceTargetBindingCompatibility(oMovedElement, oTargetElement)
+				) {
+					return false;
+				}
+
+				// check if movedOverlay is movable into the target aggregation
+				return fnHasMoveAction(oAggregationOverlay, oMovedElement, vTargetRelevantContainerAfterMove, oPlugin);
+			});
+	};
+
 	return Utils;
 }, /* bExport= */true);
