@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -22,7 +22,7 @@ function(jQuery) {
 		if (!($element instanceof jQuery)) {
 			throw new Error('$element should be wrapped into jQuery object');
 		}
-		if (!jQuery.isFunction(fnCallback)) {
+		if (typeof fnCallback !== "function") {
 			throw new Error('fnCallback should be a function');
 		}
 
