@@ -1,12 +1,10 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
-/* global Map */
 sap.ui.define([
-	"sap/ui/thirdparty/jquery",
 	"sap/ui/base/ManagedObject",
 	"sap/m/InstanceManager",
 	"sap/ui/dt/Overlay",
@@ -18,9 +16,7 @@ sap.ui.define([
 	"sap/m/Dialog",
 	"sap/m/Popover",
 	"sap/base/util/restricted/_curry"
-],
-function (
-	jQuery,
+], function(
 	ManagedObject,
 	InstanceManager,
 	Overlay,
@@ -44,7 +40,7 @@ function (
 	 * Constructor for a new sap.ui.rta.util.PopupManager
 	 * @extends sap.ui.base.ManagedObject
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @constructor
 	 * @private
 	 * @since 1.48
@@ -53,30 +49,30 @@ function (
 	 *               be changed in future.
 	 */
 	var PopupManager = ManagedObject.extend("sap.ui.rta.util.PopupManager", {
-		metadata : {
-			properties : {
-				rta:  "any"
+		metadata: {
+			properties: {
+				rta: "any"
 			},
-			associations : {
+			associations: {
 				/**
 				 * To set the associated controls as an autoCloseArea for all Popover/Dialog open in RTA mode.
 				 * Needs to be filled before the popup is open.
 				 */
-				autoCloseAreas : {type : "sap.ui.core.Control", multiple : true, singularName : "autoCloseArea"}
+				autoCloseAreas: {type: "sap.ui.core.Control", multiple: true, singularName: "autoCloseArea"}
 			},
-			events : {
+			events: {
 				open: {
-					parameters : {
-						oControl : {type : "sap.ui.core.Control"}
+					parameters: {
+						oControl: {type: "sap.ui.core.Control"}
 					}
 				},
 				close: {
-					parameters : {
-						oControl : {type : "sap.ui.core.Control"}
+					parameters: {
+						oControl: {type: "sap.ui.core.Control"}
 					}
 				}
 			},
-			library : "sap.ui.rta"
+			library: "sap.ui.rta"
 		}
 	});
 
@@ -159,7 +155,7 @@ function (
 				aAllSupportedPopups.push(oPopupElement);
 				return true;
 			} else if (oPopupElement instanceof Dialog) {
-					// all modal type popups are supported for which modal property is later turned true, when in Adaptation mode
+				// all modal type popups are supported for which modal property is later turned true, when in Adaptation mode
 				aAllSupportedPopups.push(oPopupElement);
 			}
 		}.bind(this));
@@ -179,7 +175,7 @@ function (
 	 */
 	PopupManager.prototype._isComponentInsidePopup = function(oPopup) {
 		//check if root RTA component is directly inside a popupElement
-		return jQuery.isArray(oPopup.getContent())
+		return Array.isArray(oPopup.getContent())
 			? oPopup.getContent().some(
 				function(oContent) {
 					if (oContent instanceof ComponentContainer) {
@@ -246,7 +242,7 @@ function (
 
 	/**
 	 * Apply focus events to all open popups and set focus on the first.
-	 * @param {function} fnFocusEvent Function to apply to open popups
+	 * @param {function} fnEvent - Function to apply to open popups
 	 * @private
 	 */
 	PopupManager.prototype._applyPatchesToOpenPopups = function(fnEvent) {
@@ -259,7 +255,7 @@ function (
 
 	/**
 	 * Remove focus events from all open popups.
-	 * @param {function} fnFocusEvent Function to apply to open popups
+	 * @param {function} fnEvent - Function to apply to open popups
 	 * @private
 	 */
 	PopupManager.prototype._removePatchesToOpenPopups = function(fnEvent) {
@@ -340,13 +336,6 @@ function (
 		}
 	};
 
-	/**
-	 * Applies the passed function to the relevant open popups.
-	 *
-	 * @param {function} fnPopupMethod specifies function to be applied
-	 * @param {boolean} bFocus Set to true if the popup is in focus
-	 * @private
-	 */
 	PopupManager.prototype._applyPopupAttributes = function(mPropertyBag) {
 		//check if popups are open
 		var oRelevantPopups = this.getCategorizedOpenPopups();
@@ -591,7 +580,10 @@ function (
 			return false;
 		}
 		var oPopupAppComponent = this._getAppComponentForControl(oPopupElement);
-		if (this.oRtaRootAppComponent === oPopupAppComponent || this._isComponentInsidePopup(oPopupElement)) {
+		if (
+			(oPopupAppComponent && this.oRtaRootAppComponent === oPopupAppComponent)
+			|| this._isComponentInsidePopup(oPopupElement)
+		) {
 			return checkPopupAncestorsAdaptation(oPopupElement.getParent());
 		}
 		return false;
