@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -18,7 +18,7 @@ sap.ui.define([
 	 * Note: Do not access the functions of this helper directly, but via <code>sap.ui.table.utils.TableUtils.Column...</code>
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @namespace
 	 * @alias sap.ui.table.utils._ColumnUtils
 	 * @private
@@ -729,39 +729,6 @@ sap.ui.define([
 			}
 		},
 
-		/**
-		 * Returns the number of fixed columns depending on the parameter <code>bConsiderVisibility</code>.
-		 *
-		 * @param {sap.ui.table.Table} oTable Instance of the table.
-		 * @param {boolean} bConsiderVisibility If <code>false</code> the result of the <code>getComputedFixedColumnCount</code> function of the
-		 *                                      table is returned. If <code>true</code> the visibility is included into the determination of the
-		 *                                      count.
-		 * @returns {int} Returns the number of fixed columns depending on the parameter <code>bConsiderVisibility</code>.
-		 */
-		getFixedColumnCount: function(oTable, bConsiderVisibility) {
-			var iFixed = oTable.getComputedFixedColumnCount();
-
-			if (!bConsiderVisibility) {
-				return iFixed;
-			}
-
-			if (iFixed <= 0 || oTable._bIgnoreFixedColumnCount) {
-				return 0;
-			}
-
-			var aColumns = oTable.getColumns();
-			var iVisibleFixedColumnCount = 0;
-			iFixed = Math.min(iFixed, aColumns.length);
-
-			for (var i = 0; i < iFixed; i++) {
-				if (aColumns[i].shouldRender()) {
-					iVisibleFixedColumnCount++;
-				}
-			}
-
-			return iVisibleFixedColumnCount;
-		},
-
 		/**
 		 * Returns one of the following starting with highest priority:
 		 * <ul>
