@@ -1,93 +1,172 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 // Provides helper sap.ui.table.utils._GroupingUtils.
 sap.ui.define([
-	"sap/ui/core/Element",
 	"sap/ui/model/Sorter",
 	"sap/ui/Device",
-	"../library",
 	"sap/ui/thirdparty/jquery"
-], function(Element, Sorter, Device, library, jQuery) {
+], function(Sorter, Device, jQuery) {
 	"use strict";
 
+	/**
+	 * Map from table to its hierarchy mode.
+	 */
+	var TableToHierarchyModeMap = new window.WeakMap();
+
 	/**
 	 * Static collection of utility functions related to grouping of sap.ui.table.Table, ...
 	 *
 	 * Note: Do not access the functions of this helper directly, but via <code>sap.ui.table.utils.TableUtils.Grouping...</code>
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @namespace
 	 * @alias sap.ui.table.utils._GroupingUtils
 	 * @private
 	 */
 	var GroupingUtils = {
-
 		TableUtils: null, // Avoid cyclic dependency. Will be filled by TableUtils
 
 		/**
-		 * Resets the tree/group mode of the given table.
+		 * The visual appearance of the table is influenced by the chosen hierarchy mode, which influences how the state of rows is interpreted.
 		 *
-		 * @param {sap.ui.table.Table} oTable Instance of the table.
-		 * @private
+		 * @enum {string}
+		 * @alias sap.ui.table.utils.TableUtils.Grouping.HierarchyMode
 		 */
-		clearMode: function(oTable) {
-			oTable._mode = null;
+		HierarchyMode: {
+			/**
+			 * Default mode.
+			 * The data is presented in a non-hierarchical, flat list of rows. The row type "GroupHeader" and hierarchy information such as
+			 * "level" and "expandable" are ignored.
+			 */
+			Flat: "Flat",
+
+			/**
+			 * Default group mode.
+			 * Visualization for grouped data. The row type "GroupHeader" and hierarchy information are taken into account.
+			 */
+			Group: "Group",
+
+			/**
+			 * Default tree mode.
+			 * Visualization for tree data. The row type "GroupHeader" is ignored and hierarchy information are taken into account.
+			 */
+			Tree: "Tree",
+
+			/**
+			 * Visualization for tree data as a grouped structure. The row type "GroupHeader" and hierarchy information are taken into account.
+			 * Basically, the same indentation rules apply as for the default group mode. With the exception that leaf rows are not aligned with their
+			 * group headers, but are indented deeper to take into account the structure of tree data.
+			 */
+			GroupedTree: "GroupedTree"
 		},
 
 		/**
-		 * Sets the given table into group mode.
+		 * Sets the hierarchy mode of the table.
 		 *
 		 * @param {sap.ui.table.Table} oTable Instance of the table.
+		 * @param {sap.ui.table.utils.TableUtils.Grouping.HierarchyMode} sMode The hierarchy mode.
 		 */
-		setGroupMode: function(oTable) {
-			oTable._mode = "Group";
+		setHierarchyMode: function(oTable, sMode) {
+			if (!GroupingUtils.TableUtils.isA(oTable, "sap.ui.table.Table") || !(sMode in GroupingUtils.HierarchyMode)) {
+				return;
+			}
+
+			var sCurrentHierarchyMode = GroupingUtils.getHierarchyMode(oTable);
+
+			if (sCurrentHierarchyMode !== sMode) {
+				TableToHierarchyModeMap.set(oTable, sMode);
+				oTable.invalidate();
+			}
 		},
 
 		/**
-		 * Checks whether the given table is in group mode.
+		 * Gets the hierarchy mode of the table.
 		 *
 		 * @param {sap.ui.table.Table} oTable Instance of the table.
-		 * @returns {boolean} Whether the table is in group mode.
+		 * @returns {sap.ui.table.utils.TableUtils.Grouping.HierarchyMode | null} The hierarchy mode of the table.
 		 */
-		isGroupMode: function(oTable) {
-			return oTable ? oTable._mode === "Group" : false;
+		getHierarchyMode: function(oTable) {
+			return GroupingUtils.TableUtils.isA(oTable, "sap.ui.table.Table")
+				   ? TableToHierarchyModeMap.get(oTable) || GroupingUtils.HierarchyMode.Flat
+				   : null;
 		},
 
 		/**
-		 * Sets the given table into tree mode.
+		 * Sets the hierarchy mode of the table to the default non-hierarchical (flat) mode.
 		 *
 		 * @param {sap.ui.table.Table} oTable Instance of the table.
 		 */
-		setTreeMode: function(oTable) {
-			oTable._mode = "Tree";
+		setToDefaultFlatMode: function(oTable) {
+			GroupingUtils.setHierarchyMode(oTable, GroupingUtils.HierarchyMode.Flat);
 		},
 
 		/**
-		 * Checks whether the given table is in tree mode.
+		 * Sets the hierarchy mode of the table to the default group mode.
 		 *
 		 * @param {sap.ui.table.Table} oTable Instance of the table.
-		 * @returns {boolean} Whether the table is in tree mode.
 		 */
-		isTreeMode: function(oTable) {
-			return oTable ? oTable._mode === "Tree" : false;
+		setToDefaultGroupMode: function(oTable) {
+			GroupingUtils.setHierarchyMode(oTable, GroupingUtils.HierarchyMode.Group);
 		},
 
 		/**
-		 * Returns the CSS class which belongs to the mode of the given table or <code>null</code> if no CSS class is relevant.
+		 * Sets the hierarchy mode of the table to the default tree mode.
+		 *
+		 * @param {sap.ui.table.Table} oTable Instance of the table.
+		 */
+		setToDefaultTreeMode: function(oTable) {
+			GroupingUtils.setHierarchyMode(oTable, GroupingUtils.HierarchyMode.Tree);
+		},
+
+		/**
+		 * Check whether the table is in a non-hierarchical (flat) mode.
+		 *
+		 * @param {sap.ui.table.Table} oTable Instance of the table.
+		 * @returns {boolean} Whether the table is in a flat mode.
+		 */
+		isInFlatMode: function(oTable) {
+			return GroupingUtils.getHierarchyMode(oTable) === GroupingUtils.HierarchyMode.Flat;
+		},
+
+		/**
+		 * Check whether the table is in a group mode.
+		 *
+		 * @param {sap.ui.table.Table} oTable Instance of the table.
+		 * @returns {boolean} Whether the table is in a group mode.
+		 */
+		isInGroupMode: function(oTable) {
+			var sHierarchyMode = GroupingUtils.getHierarchyMode(oTable);
+			return sHierarchyMode === GroupingUtils.HierarchyMode.Group || sHierarchyMode === GroupingUtils.HierarchyMode.GroupedTree;
+		},
+
+		/**
+		 * Check whether the table is in a tree mode.
+		 *
+		 * @param {sap.ui.table.Table} oTable Instance of the table.
+		 * @returns {boolean} Whether the table is in a tree mode.
+		 */
+		isInTreeMode: function(oTable) {
+			return GroupingUtils.getHierarchyMode(oTable) === GroupingUtils.HierarchyMode.Tree;
+		},
+
+		/**
+		 * Returns the CSS class which belongs toupdateTableRowForGrouping the hierarchy mode of the given table or <code>null</code> if no CSS class
+		 * is relevant.
 		 *
 		 * @param {sap.ui.table.Table} oTable Instance of the table.
 		 * @returns {string | null} The mode specific CSS class.
 		 */
 		getModeCssClass: function(oTable) {
-			switch (oTable._mode) {
-				case "Group":
+			switch (GroupingUtils.getHierarchyMode(oTable)) {
+				case GroupingUtils.HierarchyMode.Group:
+				case GroupingUtils.HierarchyMode.GroupedTree:
 					return "sapUiTableGroupMode";
-				case "Tree":
+				case GroupingUtils.HierarchyMode.Tree:
 					return "sapUiTableTreeMode";
 				default:
 					return null;
@@ -101,119 +180,10 @@ sap.ui.define([
 		 * @returns {boolean} Whether the group menu button should be shown.
 		 */
 		showGroupMenuButton: function(oTable) {
+			// TODO: This should depend on the hierarchy mode. Consider this when reworking the group menu buttons for mobile.
 			return !Device.system.desktop && GroupingUtils.TableUtils.isA(oTable, "sap.ui.table.AnalyticalTable");
 		},
 
-		/**
-		 * Toggles or sets the expanded state of a single or multiple rows. Toggling only works for a single row.
-		 *
-		 * @param {sap.ui.table.Table} oTable Instance of the table.
-		 * @param {int | int[]} vRowIndex A single index, or an array of indices of the rows to expand or collapse.
-		 * @param {boolean} [bExpand] If defined, instead of toggling the desired state is set.
-		 * @returns {boolean | null} The new expanded state in case an action was performed, otherwise <code>null</code>.
-		 */
-		toggleGroupHeader: function(oTable, vRowIndex, bExpand) {
-			var aIndices = [];
-			var oBinding = oTable ? oTable.getBinding("rows") : null;
-
-			if (!oTable || !oBinding || !oBinding.expand || vRowIndex == null) {
-				return null;
-			}
-
-			if (typeof vRowIndex === "number") {
-				aIndices = [vRowIndex];
-			} else if (Array.isArray(vRowIndex)) {
-				if (bExpand == null && vRowIndex.length > 1) {
-					// Toggling the expanded state of multiple rows seems to be an absurd task. Therefore we assume this is unintentional and
-					// prevent the execution.
-					return null;
-				}
-				aIndices = vRowIndex;
-			}
-
-			// The cached binding length cannot be used here. In the synchronous execution after re-binding the rows, the cached binding length is
-			// invalid. The table will validate it in its next update cycle, which happens asynchronously.
-			// As of now, this is the required behavior for some features, but leads to failure here. Therefore, the length is requested from the
-			// binding directly.
-			var iTotalRowCount = oTable._getTotalRowCount();
-
-			var aValidSortedIndices = aIndices.filter(function(iIndex) {
-				// Only indices of existing, expandable/collapsible nodes must be considered. Otherwise there might be no change event on the final
-				// expand/collapse.
-				var bIsExpanded = oBinding.isExpanded(iIndex);
-				var bIsLeaf = true; // If the node state cannot be determined, we assume it is a leaf.
-
-				if (oBinding.nodeHasChildren) {
-					if (oBinding.getNodeByIndex) {
-						bIsLeaf = !oBinding.nodeHasChildren(oBinding.getNodeByIndex(iIndex));
-					} else {
-						// The sap.ui.model.TreeBindingCompatibilityAdapter has no #getNodeByIndex function and #nodeHasChildren always returns true.
-						bIsLeaf = false;
-					}
-				}
-
-				return iIndex >= 0 && iIndex < iTotalRowCount
-					   && !bIsLeaf
-					   && bExpand !== bIsExpanded;
-			}).sort(function(a, b) { return a - b; });
-
-			if (aValidSortedIndices.length === 0) {
-				return null;
-			}
-
-			// Operations need to be performed from the highest index to the lowest. This ensures correct results with OData bindings. The indices
-			// are sorted ascending, so the array is iterated backwards.
-
-			// Expand/Collapse all nodes except the first, and suppress the change event.
-			for (var i = aValidSortedIndices.length - 1; i > 0; i--) {
-				if (bExpand) {
-					oBinding.expand(aValidSortedIndices[i], true);
-				} else {
-					oBinding.collapse(aValidSortedIndices[i], true);
-				}
-			}
-
-			// Expand/Collapse the first node without suppressing the change event.
-			if (bExpand === true) {
-				oBinding.expand(aValidSortedIndices[0], false);
-			} else if (bExpand === false) {
-				oBinding.collapse(aValidSortedIndices[0], false);
-			} else {
-				oBinding.toggleIndex(aValidSortedIndices[0]);
-			}
-
-			return oBinding.isExpanded(aValidSortedIndices[0]);
-		},
-
-		/**
-		 * Toggles the expand / collapse state of the group which contains the given DOM element.
-		 *
-		 * @param {sap.ui.table.Table} oTable Instance of the table.
-		 * @param {jQuery|HTMLElement} oRef DOM reference of an element within the table group header
-		 * @param {boolean} [bExpand] If defined instead of toggling the desired state is set.
-		 * @returns {boolean} Whether the operation was performed.
-		 */
-		toggleGroupHeaderByRef: function(oTable, oRef, bExpand) {
-			var oCell = GroupingUtils.TableUtils.getCell(oTable, oRef);
-			var oCellInfo = GroupingUtils.TableUtils.getCellInfo(oCell);
-			var oRow = oTable.getRows()[oCellInfo.rowIndex];
-			var oBinding = oTable.getBinding("rows");
-
-			if (oRow && oRow.isExpandable() && oBinding) {
-				var iAbsoluteRowIndex = oRow.getIndex();
-				var bIsExpanded = GroupingUtils.toggleGroupHeader(oTable, iAbsoluteRowIndex, bExpand);
-				var bChanged = bIsExpanded === true || bIsExpanded === false;
-
-				if (bChanged && oTable._onGroupHeaderChanged) {
-					oTable._onGroupHeaderChanged(iAbsoluteRowIndex, bIsExpanded);
-				}
-
-				return bChanged;
-			}
-
-			return false;
-		},
-
 		/**
 		 * Whether the cell is in a group header row. Returns <code>false</code> if it is not a cell.
 		 *
@@ -254,11 +224,19 @@ sap.ui.define([
 		 * @private
 		 */
 		calcGroupIndent: function(oRow) {
-			var iLevel = oRow.getLevel();
+			var bTreeIndentation = GroupingUtils.getHierarchyMode(oRow.getTable()) === GroupingUtils.HierarchyMode.GroupedTree;
+			var bReduceIndentation = !bTreeIndentation && !oRow.isGroupHeader() && !oRow.isTotalSummary();
+			var iLevel = oRow.getLevel() - (bReduceIndentation ? 1 : 0);
 			var iIndent = 0;
 
 			for (var i = 1; i < iLevel; i++) {
-				iIndent += i <= 2 ? 12 : 8;
+				if (i === 1) {
+					iIndent = 24;
+				} else if (i === 2) {
+					iIndent += 12;
+				} else {
+					iIndent += 8;
+				}
 			}
 
 			return iIndent;
@@ -295,12 +273,14 @@ sap.ui.define([
 				$RowHdr.css(bRTL ? "right" : "left", "");
 				$Shield.css("width", "").css(bRTL ? "margin-right" : "margin-left", "");
 				$FirstCellContentInRow.css(bRTL ? "padding-right" : "padding-left", "");
+				$Row.css("--CalculatedGroupIndent", "0");
 			} else {
 				// Apply indent on table row
 				$RowHdr.css(bRTL ? "right" : "left", iIndent + "px");
 				$Shield.css("width", iIndent + "px").css(bRTL ? "margin-right" : "margin-left", ((-1) * iIndent) + "px");
 				$FirstCellContentInRow.css(bRTL ? "padding-right" : "padding-left",
 					(iIndent + 8/* +8px standard padding .sapUiTableCellInner */) + "px");
+				$Row.css("--CalculatedGroupIndent", iIndent + "px");
 			}
 		},
 
@@ -329,16 +309,12 @@ sap.ui.define([
 			var oTable = oRow.getTable();
 			var oDomRefs = oRow.getDomRefs(true);
 			var $Row = oDomRefs.row;
-			var iLevel = oRow.getLevel();
 			var bIsExpanded = oRow.isExpanded();
 			var bIsExpandable = oRow.isExpandable();
 
-			$Row.attr({"data-sap-ui-level": iLevel})
-				.data("sap-ui-level", iLevel)
-				.toggleClass("sapUiTableSummaryRow", oRow.isSummary())
-				.toggleClass("sapUiTableGroupHeaderRow", oRow.isGroupHeader());
+			$Row.toggleClass("sapUiTableSummaryRow", oRow.isSummary());
 
-			if (GroupingUtils.isGroupMode(oTable)) {
+			if (GroupingUtils.isInGroupMode(oTable)) {
 				var sTitle = oRow.getTitle();
 				var iIndent = GroupingUtils.calcGroupIndent(oRow);
 
@@ -348,38 +324,35 @@ sap.ui.define([
 					.attr("title", oTable._getShowStandardTooltips() && sTitle ? sTitle : null)
 					.text(sTitle);
 				GroupingUtils.setGroupIndent(oRow, iIndent);
-				$Row.toggleClass("sapUiTableRowIndented", iIndent > 0);
+				$Row.toggleClass("sapUiTableRowIndented", iIndent > 0)
+					.toggleClass("sapUiTableGroupHeaderRow", oRow.isGroupHeader());
+
+				if (GroupingUtils.showGroupMenuButton(oTable)) {
+					var $Table = oTable.$();
+					var iScrollbarWidth = $Table.hasClass("sapUiTableVScr") ? $Table.find(".sapUiTableVSb").width() : 0;
+					var $GroupHeaderMenuButton = oDomRefs.rowHeaderPart.find(".sapUiTableGroupMenuButton");
+					var iMenuButtonOffset = $Table.width() - $GroupHeaderMenuButton.width() - iScrollbarWidth - 5 - iIndent;
+
+					$GroupHeaderMenuButton.css(oTable._bRtlMode ? "right" : "left", iMenuButtonOffset + "px");
+				}
 			}
 
-			if (GroupingUtils.isTreeMode(oTable)) {
+			if (GroupingUtils.isInTreeMode(oTable)) {
 				var $TreeIcon = $Row.find(".sapUiTableTreeIcon");
 
+				if (!bIsExpandable && document.activeElement === $TreeIcon[0]) {
+					GroupingUtils.TableUtils.getParentCell(oTable, $TreeIcon[0]).trigger("focus");
+				}
+
 				$TreeIcon.toggleClass("sapUiTableTreeIconLeaf", !bIsExpandable)
 						 .toggleClass("sapUiTableTreeIconNodeOpen", bIsExpandable && bIsExpanded)
 						 .toggleClass("sapUiTableTreeIconNodeClosed", bIsExpandable && !bIsExpanded);
 				GroupingUtils.setTreeIndent(oRow, GroupingUtils.calcTreeIndent(oRow));
 			}
 
-			if (GroupingUtils.showGroupMenuButton(oTable)) {
-				// Update the GroupMenuButton
-				var $RowHdr = oDomRefs.rowHeaderPart;
-				var iScrollbarOffset = 0;
-				var $Table = oTable.$();
-				if ($Table.hasClass("sapUiTableVScr")) {
-					iScrollbarOffset += $Table.find(".sapUiTableVSb").width();
-				}
-				var $GroupHeaderMenuButton = $RowHdr.find(".sapUiTableGroupMenuButton");
-
-				if (oTable._bRtlMode) {
-					$GroupHeaderMenuButton.css("right",
-						($Table.width() - $GroupHeaderMenuButton.width() + $RowHdr.position().left - iScrollbarOffset - 5) + "px");
-				} else {
-					$GroupHeaderMenuButton.css("left",
-						($Table.width() - $GroupHeaderMenuButton.width() - $RowHdr.position().left - iScrollbarOffset - 5) + "px");
-				}
+			if (!GroupingUtils.isInFlatMode(oTable)) {
+				oTable._getAccExtension().updateAriaExpandAndLevelState(oRow);
 			}
-
-			oTable._getAccExtension().updateAriaExpandAndLevelState(oRow);
 		},
 
 		/**
@@ -392,10 +365,7 @@ sap.ui.define([
 			var oTable = oRow.getTable();
 			var oDomRefs = oRow.getDomRefs(true);
 
-			oDomRefs.row.removeAttr("data-sap-ui-level");
-			oDomRefs.row.removeData("sap-ui-level");
-
-			if (GroupingUtils.isGroupMode(oTable)) {
+			if (GroupingUtils.isInGroupMode(oTable)) {
 				oDomRefs.row.removeClass("sapUiTableGroupHeaderRow sapUiTableSummaryRow sapUiTableRowIndented");
 				oRow.$("groupHeader")
 					.removeClass("sapUiTableGroupIconOpen", "sapUiTableGroupIconClosed")
@@ -404,7 +374,7 @@ sap.ui.define([
 				GroupingUtils.setGroupIndent(oRow, 0);
 			}
 
-			if (GroupingUtils.isTreeMode(oTable)) {
+			if (GroupingUtils.isInTreeMode(oTable)) {
 				oDomRefs.row.find(".sapUiTableTreeIcon")
 						.removeClass("sapUiTableTreeIconLeaf")
 						.removeClass("sapUiTableTreeIconNodeOpen")
@@ -422,19 +392,15 @@ sap.ui.define([
 		 * @see GroupingUtils.updateTableRowForGrouping
 		 * @see GroupingUtils.cleanupTableRowForGrouping
 		 */
-		updateGroups: function(oTable) {
-			if (GroupingUtils.isGroupMode(oTable) || GroupingUtils.isTreeMode(oTable)) {
-				var oBinding = oTable.getBinding("rows");
-
-				if (oBinding) {
-					oTable.getRows().forEach(function(oRow) {
-						GroupingUtils.updateTableRowForGrouping(oRow);
-					});
-				} else {
-					oTable.getRows().forEach(function(oRow) {
-						GroupingUtils.cleanupTableRowForGrouping(oRow);
-					});
-				}
+		updateGroups: function(oTable) { // TODO: Move rendering parts to Table or an extension (Grouping/Hierarchy/WhateverExtension)
+			if (oTable.getBinding()) {
+				oTable.getRows().forEach(function(oRow) {
+					GroupingUtils.updateTableRowForGrouping(oRow);
+				});
+			} else {
+				oTable.getRows().forEach(function(oRow) {
+					GroupingUtils.cleanupTableRowForGrouping(oRow);
+				});
 			}
 		},
 
@@ -466,7 +432,7 @@ sap.ui.define([
 				return;
 			}
 
-			var oBinding = Element.prototype.getBinding.call(oTable, "rows");
+			var oBinding = oTable.getBinding();
 
 			// check for grouping being supported or not (only for client ListBindings!!)
 			var oGroupBy = sap.ui.getCore().byId(oTable.getGroupBy());
@@ -482,7 +448,7 @@ sap.ui.define([
 			oBinding._modified = true;
 
 			// set the table into grouping mode
-			GroupingUtils.setGroupMode(oTable);
+			GroupingUtils.setToDefaultGroupMode(oTable);
 
 			// we use sorting finally to sort the values and afterwards group them
 			var sPropertyName = oGroupBy.getSortProperty();
@@ -535,57 +501,14 @@ sap.ui.define([
 				},
 				getContexts: function(iStartIndex, iLength) {
 					return aContexts.slice(iStartIndex, iStartIndex + iLength);
-				},
-				isGroupHeader: function(iIndex) {
-					var oContext = aContexts[iIndex];
-					return (oContext && oContext.__groupInfo && oContext.__groupInfo.groupHeader) === true;
-				},
-				getTitle: function(iIndex) {
-					var oContext = aContexts[iIndex];
-					return oContext && oContext.__groupInfo && oContext.__groupInfo.name + " - " + oContext.__groupInfo.count;
-				},
-				isExpanded: function(iIndex) {
-					var oContext = aContexts[iIndex];
-					return this.isGroupHeader(iIndex) && oContext.__groupInfo && oContext.__groupInfo.expanded;
-				},
-				expand: function(iIndex) {
-					if (this.isGroupHeader(iIndex) && !aContexts[iIndex].__groupInfo.expanded) {
-						for (var i = 0; i < aContexts[iIndex].__childs.length; i++) {
-							aContexts.splice(iIndex + 1 + i, 0, aContexts[iIndex].__childs[i]);
-						}
-						delete aContexts[iIndex].__childs;
-						aContexts[iIndex].__groupInfo.expanded = true;
-						this._fireChange();
-					}
-				},
-				collapse: function(iIndex) {
-					if (this.isGroupHeader(iIndex) && aContexts[iIndex].__groupInfo.expanded) {
-						aContexts[iIndex].__childs = aContexts.splice(iIndex + 1, aContexts[iIndex].__groupInfo.count);
-						aContexts[iIndex].__groupInfo.expanded = false;
-						this._fireChange();
-					}
-				},
-				toggleIndex: function(iIndex) {
-					if (this.isExpanded(iIndex)) {
-						this.collapse(iIndex);
-					} else {
-						this.expand(iIndex);
-					}
-				},
-
-				// For compatibility with TreeBinding adapters.
-				nodeHasChildren: function(oContext) {
-					if (!oContext || !oContext.__groupInfo) {
-						return false;
-					} else {
-						return oContext.__groupInfo.groupHeader === true;
-					}
-				},
-				getNodeByIndex: function(iIndex) {
-					return aContexts[iIndex];
 				}
 			});
 
+			function isGroupHeader(iIndex) {
+				var oContext = aContexts[iIndex];
+				return (oContext && oContext.__groupInfo && oContext.__groupInfo.groupHeader) === true;
+			}
+
 			oTable._experimentalGroupingRowState = function(oState) {
 				var oContext = oState.context;
 
@@ -599,7 +522,31 @@ sap.ui.define([
 				oState.contentHidden = oState.expandable;
 			};
 
-			GroupingUtils.TableUtils.Hook.register(oTable, GroupingUtils.TableUtils.Hook.Keys.Row.UpdateState, oTable._experimentalGroupingRowState, oTable);
+			oTable._experimentalGroupingExpand = function(oRow) {
+				var iRowIndex = oRow.getIndex();
+				if (isGroupHeader(iRowIndex) && !aContexts[iRowIndex].__groupInfo.expanded) {
+					for (var i = 0; i < aContexts[iRowIndex].__childs.length; i++) {
+						aContexts.splice(iRowIndex + 1 + i, 0, aContexts[iRowIndex].__childs[i]);
+					}
+					delete aContexts[iRowIndex].__childs;
+					aContexts[iRowIndex].__groupInfo.expanded = true;
+					oBinding._fireChange();
+				}
+			};
+
+			oTable._experimentalGroupingCollapse = function(oRow) {
+				var iRowIndex = oRow.getIndex();
+				if (isGroupHeader(iRowIndex) && aContexts[iRowIndex].__groupInfo.expanded) {
+					aContexts[iRowIndex].__childs = aContexts.splice(iRowIndex + 1, aContexts[iRowIndex].__groupInfo.count);
+					aContexts[iRowIndex].__groupInfo.expanded = false;
+					oBinding._fireChange();
+				}
+			};
+
+			var Hook = GroupingUtils.TableUtils.Hook;
+			Hook.register(oTable, Hook.Keys.Row.UpdateState, oTable._experimentalGroupingRowState);
+			Hook.register(oTable, Hook.Keys.Row.Expand, oTable._experimentalGroupingExpand);
+			Hook.register(oTable, Hook.Keys.Row.Collapse, oTable._experimentalGroupingCollapse);
 
 			// the table need to fetch the updated/changed contexts again, therefore requires the binding to fire a change event
 			oTable._mTimeouts.groupingFireBindingChange = oTable._mTimeouts.groupingFireBindingChange || window.setTimeout(
@@ -612,14 +559,20 @@ sap.ui.define([
 		 * @param {sap.ui.table.Table} oTable Instance of the table.
 		 */
 		resetExperimentalGrouping: function(oTable) {
-			var oBinding = oTable.getBinding("rows");
+			var oBinding = oTable.getBinding();
+			var Hook = GroupingUtils.TableUtils.Hook;
+
 			if (oBinding && oBinding._modified) {
-				GroupingUtils.clearMode(oTable);
-				var oBindingInfo = oTable.getBindingInfo("rows");
-				oTable.unbindRows();
-				oTable.bindRows(oBindingInfo);
+				GroupingUtils.setToDefaultFlatMode(oTable);
+				oTable.bindRows(oTable.getBindingInfo("rows"));
 			}
-			GroupingUtils.TableUtils.Hook.deregister(oTable, GroupingUtils.TableUtils.Hook.Keys.Row.UpdateState, oTable._experimentalGroupingRowState, oTable);
+
+			Hook.deregister(oTable, Hook.Keys.Row.UpdateState, oTable._experimentalGroupingRowState);
+			Hook.deregister(oTable, Hook.Keys.Row.Expand, oTable._experimentalGroupingExpand);
+			Hook.deregister(oTable, Hook.Keys.Row.Collapse, oTable._experimentalGroupingCollapse);
+			delete oTable._experimentalGroupingRowState;
+			delete oTable._experimentalGroupingExpand;
+			delete oTable._experimentalGroupingCollapse;
 		}
 	};
 
