@@ -1,12 +1,28 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
-sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppointment', 'sap/ui/unified/CalendarLegendRenderer',
-		'sap/ui/Device', 'sap/ui/unified/library', 'sap/ui/core/InvisibleText', "sap/base/Log"],
-	function (UniversalDate, CalendarAppointment, CalendarLegendRenderer, Device, library, InvisibleText, Log) {
+sap.ui.define([
+	'sap/ui/core/date/UniversalDate',
+	'sap/ui/unified/CalendarAppointment',
+	'sap/ui/unified/CalendarLegendRenderer',
+	'sap/ui/Device',
+	'sap/ui/unified/library',
+	'sap/ui/core/IconPool',
+	'sap/ui/core/InvisibleText',
+	"sap/base/Log"
+	],
+	function (
+		UniversalDate,
+		CalendarAppointment,
+		CalendarLegendRenderer,
+		Device,
+		library,
+		IconPool,
+		InvisibleText,
+		Log) {
 		"use strict";
 
 
@@ -147,6 +163,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 			case CalendarIntervalType.Day:
 			case CalendarIntervalType.Week:
 			case CalendarIntervalType.OneMonth:
+			case "OneMonth":
 				aNonWorkingItems = oRow._getNonWorkingDays();
 				iStartOffset = oStartDate.getUTCDay();
 				iNonWorkingMax = 7;
@@ -187,6 +204,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 					case CalendarIntervalType.Day:
 					case CalendarIntervalType.Week:
 					case CalendarIntervalType.OneMonth:
+					case "OneMonth":
 						oIntervalNextStartDate.setUTCDate(oIntervalNextStartDate.getUTCDate() + 1);
 						if (oIntervalNextStartDate.getUTCDate() == 1) {
 							bLastOfType = true;
@@ -194,6 +212,8 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 						break;
 
 					case CalendarIntervalType.Month:
+						iSubStartOffset = oIntervalNextStartDate.getUTCDay();
+
 						oIntervalNextStartDate.setUTCMonth(oIntervalNextStartDate.getUTCMonth() + 1);
 						if (oIntervalNextStartDate.getUTCMonth() == 0) {
 							bLastOfType = true;
@@ -209,10 +229,12 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 
 			this.renderIntervalHeaders(oRm, oRow, iWidth, aIntervalHeaders, iIntervals);
 
-			oRm.openStart("div", oRow.getId() + "-Now");
-			oRm.class("sapUiCalendarRowNow");
-			oRm.openEnd();
-			oRm.close("div");
+			if (!(oRow._getRelativeInfo && oRow._getRelativeInfo().bIsRelative)) {
+				oRm.openStart("div", oRow.getId() + "-Now");
+				oRm.class("sapUiCalendarRowNow");
+				oRm.openEnd();
+				oRm.close("div");
+			}
 
 			for (i = 0; i < aAppointments.length; i++) {
 				var oAppointmentInfo = aAppointments[i];
@@ -249,7 +271,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 		}
 		oRm.style("width", iWidth + "%");
 
-		if (iInterval >= iDaysLength && oRow.getIntervalType() === CalendarIntervalType.OneMonth){
+		if (iInterval >= iDaysLength && (oRow.getIntervalType() === CalendarIntervalType.OneMonth || oRow.getIntervalType() === "OneMonth")){
 			oRm.class("sapUiCalItemOtherMonth");
 		}
 		for (i = 0; i < aNonWorkingItems.length; i++) {
@@ -293,6 +315,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 			case CalendarIntervalType.Day:
 			case CalendarIntervalType.Week:
 			case CalendarIntervalType.OneMonth:
+			case "OneMonth":
 				iSubIntervals = 24;
 				break;
 
@@ -417,7 +440,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 		oRm.openEnd();
 
 		if (oArrowValues.appTimeUnitsDifRowStart > 0) {
-			oRm.icon("sap-icon://arrow-left", ["sapUiCalendarAppArrowIconLeft"], { title: null });
+			oRm.icon("sap-icon://arrow-left", ["sapUiCalendarAppArrowIconLeft"], { title: null, role: "img" });
 		}
 
 		var sIcon = oIntervalHeader.appointment.getIcon();
@@ -427,6 +450,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 
 			mAttributes["id"] = sId + "-Icon";
 			mAttributes["title"] = null;
+			mAttributes["role"] = "img";
 			oRm.icon(sIcon, aClasses, mAttributes);
 		}
 
@@ -449,7 +473,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 		}
 
 		if (oArrowValues.appTimeUnitsDifRowEnd > 0) {
-			oRm.icon("sap-icon://arrow-right",["sapUiCalendarAppArrowIconRight"], { title: null });
+			oRm.icon("sap-icon://arrow-right",["sapUiCalendarAppArrowIconRight"], { title: null, role: "img" });
 		}
 
 		// ARIA information about start and end
@@ -573,71 +597,73 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 
 		oRm.openEnd(); // div element
 
-		if (oArrowValues.appTimeUnitsDifRowStart > 0) {
-			oRm.icon("sap-icon://arrow-left", ["sapUiCalendarAppArrowIconLeft"], { title: null });
-		}
-
-		if (sIcon) {
-			var aClasses = ["sapUiCalendarAppIcon"];
-			var mAttributes = {};
-
-			mAttributes["id"] = sId + "-Icon";
-			mAttributes["title"] = null;
-			oRm.icon(sIcon, aClasses, mAttributes);
-		}
-
-		oRm.openStart("div");
-		oRm.class("sapUiCalendarAppTitleWrapper");
-		oRm.openEnd();
-
-		if (sTitle) {
-			oRm.openStart("span", sId + "-Title");
-			oRm.class("sapUiCalendarAppTitle");
-			oRm.openEnd(); // span element
-			oRm.text(sTitle);
-			oRm.close("span");
-		}
-
-		if (sText && oAppointmentInfo.size !== CalendarAppointmentHeight.HalfSize) {
-			oRm.openStart("span", sId + "-Text");
-			oRm.class("sapUiCalendarAppText");
-			oRm.openEnd(); // span element
-			oRm.text(sText);
-			oRm.close("span");
-		}
-
-		if (sDescription && oAppointmentInfo.size !== CalendarAppointmentHeight.HalfSize && (oAppointmentInfo.size !== CalendarAppointmentHeight.Regular || !sText ) ) {
-			oRm.openStart("span", sId + "-Info");
-			oRm.class("sapUiCalendarAppDescription");
+		if (oAppointment.getCustomContent().length) {
+			oAppointment.getCustomContent().forEach(function (oContent) {
+				oRm.renderControl(oContent);
+			});
+		} else {
+			if (oArrowValues.appTimeUnitsDifRowStart > 0) {
+				oRm.icon("sap-icon://arrow-left", ["sapUiCalendarAppArrowIconLeft"], { title: null, role: "img" });
+			}
+			if (sIcon) {
+				var aClasses = ["sapUiCalendarAppIcon"];
+				var mAttributes = {};
+				mAttributes["id"] = sId + "-Icon";
+				mAttributes["title"] = null;
+				mAttributes["role"] = "img";
+				oRm.icon(sIcon, aClasses, mAttributes);
+			}
+			oRm.openStart("div");
+			oRm.class("sapUiCalendarAppTitleWrapper");
 			oRm.openEnd();
-			oRm.text(sDescription);
-			oRm.close("span");
-		}
-
-		oRm.close("div");
-
-		if (oArrowValues.appTimeUnitsDifRowEnd > 0) {
-			oRm.icon("sap-icon://arrow-right", ["sapUiCalendarAppArrowIconRight"], { title: null });
+			if (sTitle) {
+				oRm.openStart("span", sId + "-Title");
+				oRm.class("sapUiCalendarAppTitle");
+				oRm.openEnd(); // span element
+				oRm.text(sTitle);
+				oRm.close("span");
+			}
+			if (sText && oAppointmentInfo.size !== CalendarAppointmentHeight.HalfSize) {
+				oRm.openStart("span", sId + "-Text");
+				oRm.class("sapUiCalendarAppText");
+				oRm.openEnd(); // span element
+				oRm.text(sText);
+				oRm.close("span");
+			}
+			if (sDescription && oAppointmentInfo.size !== CalendarAppointmentHeight.HalfSize && (oAppointmentInfo.size !== CalendarAppointmentHeight.Regular || !sText)) {
+				oRm.openStart("span", sId + "-Info");
+				oRm.class("sapUiCalendarAppDescription");
+				oRm.openEnd();
+				oRm.text(sDescription);
+				oRm.close("span");
+			}
+			oRm.close("div");
+			if (oArrowValues.appTimeUnitsDifRowEnd > 0) {
+				oRm.icon("sap-icon://arrow-right", ["sapUiCalendarAppArrowIconRight"], { title: null, role: "img" });
+			}
 		}
 
 		// ARIA information about start and end
 		var sAriaText = oRow._oRb.getText("CALENDAR_START_TIME") + ": " + oRow._oFormatAria.format(oAppointment.getStartDate());
 		sAriaText = sAriaText + "; " + oRow._oRb.getText("CALENDAR_END_TIME") + ": " + oRow._oFormatAria.format(oAppointment.getEndDate());
-
+		if (oRow._getRelativeInfo && oRow._getRelativeInfo().bIsRelative) {
+			var oRelativeInfo = oRow._getRelativeInfo();
+			sAriaText = oRow._oRb.getText("CALENDAR_START_TIME") + ": " + oRelativeInfo.intervalLabelFormatter(oRelativeInfo._getIndexFromDate(oAppointment.getStartDate()));
+			sAriaText = sAriaText + "; " + oRow._oRb.getText("CALENDAR_END_TIME") + ": " + oRelativeInfo.intervalLabelFormatter(oRelativeInfo._getIndexFromDate(oAppointment.getEndDate()));
+		}
 		if (sType && sType != CalendarDayType.None) {
-
 			sAriaText = sAriaText + "; " + this.getAriaTextForType(sType, aTypes);
 		}
-
 		oRm.openStart("span", sId + "-Descr");
 		oRm.class("sapUiInvisibleText");
 		oRm.openEnd();
 		oRm.text(sAriaText);
 		oRm.close("span");
+
+		//app content
 		oRm.close("div");
 
 		this.renderResizeHandle(oRm, oRow, oAppointment);
-
 		oRm.close("div");
 	};
 
@@ -647,7 +673,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 			sId = oRow.getId() + "-AppsInt" + iInterval,
 			i,
 			bShowIntervalHeaders = oRow.getShowIntervalHeaders() && (oRow.getShowEmptyIntervalHeaders() || aIntervalHeaders.length > 0),
-			oRowStartDate = oRow.getStartDate(),
+			oRowStartDate = new Date(oRow.getStartDate()),
 			iMonth = oRowStartDate.getMonth(),
 			iDaysLength = new Date(oRowStartDate.getFullYear(), iMonth + 1, 0).getDate(),
 			sNoAppointments,
@@ -678,7 +704,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 		oRm.class("sapUiCalendarMonthRowAppsS");
 		oRm.style("width", iWidth + "%");
 
-		if (iInterval >= iDaysLength && oRow.getIntervalType() === CalendarIntervalType.OneMonth){
+		if (iInterval >= iDaysLength && (oRow.getIntervalType() === CalendarIntervalType.OneMonth || oRow.getIntervalType() === "OneMonth")){
 			oRm.class("sapUiCalItemOtherMonth");
 		}
 
@@ -762,9 +788,13 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 			oRm.text(sNoAppointments);
 			oRm.close("div");
 		}
-		oRm.openStart("div", oRow.getId() + "-Now");
-		oRm.class("sapUiCalendarRowNow");
-		oRm.openEnd();
+
+		if (!(oRow._getRelativeInfo && oRow._getRelativeInfo().bIsRelative)) {
+			oRm.openStart("div", oRow.getId() + "-Now");
+			oRm.class("sapUiCalendarRowNow");
+			oRm.openEnd();
+		}
+
 		oRm.close("div");
 
 		// render dummy appointment for size calculation
@@ -789,6 +819,7 @@ sap.ui.define(['sap/ui/core/date/UniversalDate', 'sap/ui/unified/CalendarAppoint
 				case CalendarIntervalType.Day:
 				case CalendarIntervalType.Week:
 				case CalendarIntervalType.OneMonth:
+				case "OneMonth":
 					iSubIntervals = 24;
 					break;
 
